/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleApigeeDnsZoneConfig extends cdktf.TerraformMetaArguments {
    /**
    * Description for the zone.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_apigee_dns_zone#description GoogleApigeeDnsZone#description}
    */
    readonly description: string;
    /**
    * ID of the dns zone.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_apigee_dns_zone#dns_zone_id GoogleApigeeDnsZone#dns_zone_id}
    */
    readonly dnsZoneId: string;
    /**
    * Doamin for the zone.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_apigee_dns_zone#domain GoogleApigeeDnsZone#domain}
    */
    readonly domain: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_apigee_dns_zone#id GoogleApigeeDnsZone#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The Apigee Organization associated with the Apigee instance,
    * in the format 'organizations/{{org_name}}'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_apigee_dns_zone#org_id GoogleApigeeDnsZone#org_id}
    */
    readonly orgId: string;
    /**
    * peering_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_apigee_dns_zone#peering_config GoogleApigeeDnsZone#peering_config}
    */
    readonly peeringConfig: GoogleApigeeDnsZonePeeringConfig;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_apigee_dns_zone#timeouts GoogleApigeeDnsZone#timeouts}
    */
    readonly timeouts?: GoogleApigeeDnsZoneTimeouts;
}
export interface GoogleApigeeDnsZonePeeringConfig {
    /**
    * The name of the producer VPC network.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_apigee_dns_zone#target_network_id GoogleApigeeDnsZone#target_network_id}
    */
    readonly targetNetworkId: string;
    /**
    * The ID of the project that contains the producer VPC network.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_apigee_dns_zone#target_project_id GoogleApigeeDnsZone#target_project_id}
    */
    readonly targetProjectId: string;
}
export declare function googleApigeeDnsZonePeeringConfigToTerraform(struct?: GoogleApigeeDnsZonePeeringConfigOutputReference | GoogleApigeeDnsZonePeeringConfig): any;
export declare function googleApigeeDnsZonePeeringConfigToHclTerraform(struct?: GoogleApigeeDnsZonePeeringConfigOutputReference | GoogleApigeeDnsZonePeeringConfig): any;
export declare class GoogleApigeeDnsZonePeeringConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleApigeeDnsZonePeeringConfig | undefined;
    set internalValue(value: GoogleApigeeDnsZonePeeringConfig | undefined);
    private _targetNetworkId?;
    get targetNetworkId(): string;
    set targetNetworkId(value: string);
    get targetNetworkIdInput(): string | undefined;
    private _targetProjectId?;
    get targetProjectId(): string;
    set targetProjectId(value: string);
    get targetProjectIdInput(): string | undefined;
}
export interface GoogleApigeeDnsZoneTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_apigee_dns_zone#create GoogleApigeeDnsZone#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_apigee_dns_zone#delete GoogleApigeeDnsZone#delete}
    */
    readonly delete?: string;
}
export declare function googleApigeeDnsZoneTimeoutsToTerraform(struct?: GoogleApigeeDnsZoneTimeouts | cdktf.IResolvable): any;
export declare function googleApigeeDnsZoneTimeoutsToHclTerraform(struct?: GoogleApigeeDnsZoneTimeouts | cdktf.IResolvable): any;
export declare class GoogleApigeeDnsZoneTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleApigeeDnsZoneTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleApigeeDnsZoneTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_apigee_dns_zone google_apigee_dns_zone}
*/
export declare class GoogleApigeeDnsZone extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_apigee_dns_zone";
    /**
    * Generates CDKTF code for importing a GoogleApigeeDnsZone resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleApigeeDnsZone to import
    * @param importFromId The id of the existing GoogleApigeeDnsZone that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_apigee_dns_zone#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleApigeeDnsZone to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_apigee_dns_zone google_apigee_dns_zone} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleApigeeDnsZoneConfig
    */
    constructor(scope: Construct, id: string, config: GoogleApigeeDnsZoneConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    get descriptionInput(): string | undefined;
    private _dnsZoneId?;
    get dnsZoneId(): string;
    set dnsZoneId(value: string);
    get dnsZoneIdInput(): string | undefined;
    private _domain?;
    get domain(): string;
    set domain(value: string);
    get domainInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get name(): string;
    private _orgId?;
    get orgId(): string;
    set orgId(value: string);
    get orgIdInput(): string | undefined;
    private _peeringConfig;
    get peeringConfig(): GoogleApigeeDnsZonePeeringConfigOutputReference;
    putPeeringConfig(value: GoogleApigeeDnsZonePeeringConfig): void;
    get peeringConfigInput(): GoogleApigeeDnsZonePeeringConfig | undefined;
    private _timeouts;
    get timeouts(): GoogleApigeeDnsZoneTimeoutsOutputReference;
    putTimeouts(value: GoogleApigeeDnsZoneTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleApigeeDnsZoneTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
