/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleApigeeSecurityProfileV2Config extends cdktf.TerraformMetaArguments {
    /**
    * Description of the security profile.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_apigee_security_profile_v2#description GoogleApigeeSecurityProfileV2#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_apigee_security_profile_v2#id GoogleApigeeSecurityProfileV2#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The Apigee Organization associated with the Apigee Security Profile V2,
    * in the format 'organizations/{{org_name}}'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_apigee_security_profile_v2#org_id GoogleApigeeSecurityProfileV2#org_id}
    */
    readonly orgId: string;
    /**
    * Resource ID of the security profile.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_apigee_security_profile_v2#profile_id GoogleApigeeSecurityProfileV2#profile_id}
    */
    readonly profileId: string;
    /**
    * profile_assessment_configs block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_apigee_security_profile_v2#profile_assessment_configs GoogleApigeeSecurityProfileV2#profile_assessment_configs}
    */
    readonly profileAssessmentConfigs: GoogleApigeeSecurityProfileV2ProfileAssessmentConfigs[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_apigee_security_profile_v2#timeouts GoogleApigeeSecurityProfileV2#timeouts}
    */
    readonly timeouts?: GoogleApigeeSecurityProfileV2Timeouts;
}
export interface GoogleApigeeSecurityProfileV2ProfileAssessmentConfigs {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_apigee_security_profile_v2#assessment GoogleApigeeSecurityProfileV2#assessment}
    */
    readonly assessment: string;
    /**
    * The weight of the assessment. Possible values: ["MINOR", "MODERATE", "MAJOR"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_apigee_security_profile_v2#weight GoogleApigeeSecurityProfileV2#weight}
    */
    readonly weight: string;
}
export declare function googleApigeeSecurityProfileV2ProfileAssessmentConfigsToTerraform(struct?: GoogleApigeeSecurityProfileV2ProfileAssessmentConfigs | cdktf.IResolvable): any;
export declare function googleApigeeSecurityProfileV2ProfileAssessmentConfigsToHclTerraform(struct?: GoogleApigeeSecurityProfileV2ProfileAssessmentConfigs | cdktf.IResolvable): any;
export declare class GoogleApigeeSecurityProfileV2ProfileAssessmentConfigsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleApigeeSecurityProfileV2ProfileAssessmentConfigs | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleApigeeSecurityProfileV2ProfileAssessmentConfigs | cdktf.IResolvable | undefined);
    private _assessment?;
    get assessment(): string;
    set assessment(value: string);
    get assessmentInput(): string | undefined;
    private _weight?;
    get weight(): string;
    set weight(value: string);
    get weightInput(): string | undefined;
}
export declare class GoogleApigeeSecurityProfileV2ProfileAssessmentConfigsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleApigeeSecurityProfileV2ProfileAssessmentConfigs[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleApigeeSecurityProfileV2ProfileAssessmentConfigsOutputReference;
}
export interface GoogleApigeeSecurityProfileV2Timeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_apigee_security_profile_v2#create GoogleApigeeSecurityProfileV2#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_apigee_security_profile_v2#delete GoogleApigeeSecurityProfileV2#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_apigee_security_profile_v2#update GoogleApigeeSecurityProfileV2#update}
    */
    readonly update?: string;
}
export declare function googleApigeeSecurityProfileV2TimeoutsToTerraform(struct?: GoogleApigeeSecurityProfileV2Timeouts | cdktf.IResolvable): any;
export declare function googleApigeeSecurityProfileV2TimeoutsToHclTerraform(struct?: GoogleApigeeSecurityProfileV2Timeouts | cdktf.IResolvable): any;
export declare class GoogleApigeeSecurityProfileV2TimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleApigeeSecurityProfileV2Timeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleApigeeSecurityProfileV2Timeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_apigee_security_profile_v2 google_apigee_security_profile_v2}
*/
export declare class GoogleApigeeSecurityProfileV2 extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_apigee_security_profile_v2";
    /**
    * Generates CDKTF code for importing a GoogleApigeeSecurityProfileV2 resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleApigeeSecurityProfileV2 to import
    * @param importFromId The id of the existing GoogleApigeeSecurityProfileV2 that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_apigee_security_profile_v2#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleApigeeSecurityProfileV2 to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_apigee_security_profile_v2 google_apigee_security_profile_v2} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleApigeeSecurityProfileV2Config
    */
    constructor(scope: Construct, id: string, config: GoogleApigeeSecurityProfileV2Config);
    get createTime(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get name(): string;
    private _orgId?;
    get orgId(): string;
    set orgId(value: string);
    get orgIdInput(): string | undefined;
    private _profileId?;
    get profileId(): string;
    set profileId(value: string);
    get profileIdInput(): string | undefined;
    get updateTime(): string;
    private _profileAssessmentConfigs;
    get profileAssessmentConfigs(): GoogleApigeeSecurityProfileV2ProfileAssessmentConfigsList;
    putProfileAssessmentConfigs(value: GoogleApigeeSecurityProfileV2ProfileAssessmentConfigs[] | cdktf.IResolvable): void;
    get profileAssessmentConfigsInput(): cdktf.IResolvable | GoogleApigeeSecurityProfileV2ProfileAssessmentConfigs[] | undefined;
    private _timeouts;
    get timeouts(): GoogleApigeeSecurityProfileV2TimeoutsOutputReference;
    putTimeouts(value: GoogleApigeeSecurityProfileV2Timeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleApigeeSecurityProfileV2Timeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
