/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleBeyondcorpApplicationConfig extends cdktf.TerraformMetaArguments {
    /**
    * Optional. User-settable Application resource ID.
    * * Must start with a letter.
    * * Must contain between 4-63 characters from '/a-z-/'.
    * * Must end with a number or letter.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_beyondcorp_application#application_id GoogleBeyondcorpApplication#application_id}
    */
    readonly applicationId: string;
    /**
    * Optional. An arbitrary user-provided name for the Application resource.
    * Cannot exceed 64 characters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_beyondcorp_application#display_name GoogleBeyondcorpApplication#display_name}
    */
    readonly displayName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_beyondcorp_application#id GoogleBeyondcorpApplication#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_beyondcorp_application#project GoogleBeyondcorpApplication#project}
    */
    readonly project?: string;
    /**
    * Part of 'parent'. See documentation of 'projectsId'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_beyondcorp_application#security_gateways_id GoogleBeyondcorpApplication#security_gateways_id}
    */
    readonly securityGatewaysId: string;
    /**
    * endpoint_matchers block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_beyondcorp_application#endpoint_matchers GoogleBeyondcorpApplication#endpoint_matchers}
    */
    readonly endpointMatchers: GoogleBeyondcorpApplicationEndpointMatchers[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_beyondcorp_application#timeouts GoogleBeyondcorpApplication#timeouts}
    */
    readonly timeouts?: GoogleBeyondcorpApplicationTimeouts;
    /**
    * upstreams block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_beyondcorp_application#upstreams GoogleBeyondcorpApplication#upstreams}
    */
    readonly upstreams?: GoogleBeyondcorpApplicationUpstreams[] | cdktf.IResolvable;
}
export interface GoogleBeyondcorpApplicationEndpointMatchers {
    /**
    * Required. Hostname of the application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_beyondcorp_application#hostname GoogleBeyondcorpApplication#hostname}
    */
    readonly hostname: string;
    /**
    * Optional. Ports of the application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_beyondcorp_application#ports GoogleBeyondcorpApplication#ports}
    */
    readonly ports?: number[];
}
export declare function googleBeyondcorpApplicationEndpointMatchersToTerraform(struct?: GoogleBeyondcorpApplicationEndpointMatchers | cdktf.IResolvable): any;
export declare function googleBeyondcorpApplicationEndpointMatchersToHclTerraform(struct?: GoogleBeyondcorpApplicationEndpointMatchers | cdktf.IResolvable): any;
export declare class GoogleBeyondcorpApplicationEndpointMatchersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleBeyondcorpApplicationEndpointMatchers | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleBeyondcorpApplicationEndpointMatchers | cdktf.IResolvable | undefined);
    private _hostname?;
    get hostname(): string;
    set hostname(value: string);
    get hostnameInput(): string | undefined;
    private _ports?;
    get ports(): number[];
    set ports(value: number[]);
    resetPorts(): void;
    get portsInput(): number[] | undefined;
}
export declare class GoogleBeyondcorpApplicationEndpointMatchersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleBeyondcorpApplicationEndpointMatchers[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleBeyondcorpApplicationEndpointMatchersOutputReference;
}
export interface GoogleBeyondcorpApplicationTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_beyondcorp_application#create GoogleBeyondcorpApplication#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_beyondcorp_application#delete GoogleBeyondcorpApplication#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_beyondcorp_application#update GoogleBeyondcorpApplication#update}
    */
    readonly update?: string;
}
export declare function googleBeyondcorpApplicationTimeoutsToTerraform(struct?: GoogleBeyondcorpApplicationTimeouts | cdktf.IResolvable): any;
export declare function googleBeyondcorpApplicationTimeoutsToHclTerraform(struct?: GoogleBeyondcorpApplicationTimeouts | cdktf.IResolvable): any;
export declare class GoogleBeyondcorpApplicationTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleBeyondcorpApplicationTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleBeyondcorpApplicationTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
export interface GoogleBeyondcorpApplicationUpstreamsEgressPolicy {
    /**
    * Required. List of regions where the application sends traffic to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_beyondcorp_application#regions GoogleBeyondcorpApplication#regions}
    */
    readonly regions: string[];
}
export declare function googleBeyondcorpApplicationUpstreamsEgressPolicyToTerraform(struct?: GoogleBeyondcorpApplicationUpstreamsEgressPolicyOutputReference | GoogleBeyondcorpApplicationUpstreamsEgressPolicy): any;
export declare function googleBeyondcorpApplicationUpstreamsEgressPolicyToHclTerraform(struct?: GoogleBeyondcorpApplicationUpstreamsEgressPolicyOutputReference | GoogleBeyondcorpApplicationUpstreamsEgressPolicy): any;
export declare class GoogleBeyondcorpApplicationUpstreamsEgressPolicyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleBeyondcorpApplicationUpstreamsEgressPolicy | undefined;
    set internalValue(value: GoogleBeyondcorpApplicationUpstreamsEgressPolicy | undefined);
    private _regions?;
    get regions(): string[];
    set regions(value: string[]);
    get regionsInput(): string[] | undefined;
}
export interface GoogleBeyondcorpApplicationUpstreamsNetwork {
    /**
    * Required. Network name is of the format:
    * 'projects/{project}/global/networks/{network}'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_beyondcorp_application#name GoogleBeyondcorpApplication#name}
    */
    readonly name: string;
}
export declare function googleBeyondcorpApplicationUpstreamsNetworkToTerraform(struct?: GoogleBeyondcorpApplicationUpstreamsNetworkOutputReference | GoogleBeyondcorpApplicationUpstreamsNetwork): any;
export declare function googleBeyondcorpApplicationUpstreamsNetworkToHclTerraform(struct?: GoogleBeyondcorpApplicationUpstreamsNetworkOutputReference | GoogleBeyondcorpApplicationUpstreamsNetwork): any;
export declare class GoogleBeyondcorpApplicationUpstreamsNetworkOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleBeyondcorpApplicationUpstreamsNetwork | undefined;
    set internalValue(value: GoogleBeyondcorpApplicationUpstreamsNetwork | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
}
export interface GoogleBeyondcorpApplicationUpstreams {
    /**
    * egress_policy block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_beyondcorp_application#egress_policy GoogleBeyondcorpApplication#egress_policy}
    */
    readonly egressPolicy?: GoogleBeyondcorpApplicationUpstreamsEgressPolicy;
    /**
    * network block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_beyondcorp_application#network GoogleBeyondcorpApplication#network}
    */
    readonly network?: GoogleBeyondcorpApplicationUpstreamsNetwork;
}
export declare function googleBeyondcorpApplicationUpstreamsToTerraform(struct?: GoogleBeyondcorpApplicationUpstreams | cdktf.IResolvable): any;
export declare function googleBeyondcorpApplicationUpstreamsToHclTerraform(struct?: GoogleBeyondcorpApplicationUpstreams | cdktf.IResolvable): any;
export declare class GoogleBeyondcorpApplicationUpstreamsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleBeyondcorpApplicationUpstreams | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleBeyondcorpApplicationUpstreams | cdktf.IResolvable | undefined);
    private _egressPolicy;
    get egressPolicy(): GoogleBeyondcorpApplicationUpstreamsEgressPolicyOutputReference;
    putEgressPolicy(value: GoogleBeyondcorpApplicationUpstreamsEgressPolicy): void;
    resetEgressPolicy(): void;
    get egressPolicyInput(): GoogleBeyondcorpApplicationUpstreamsEgressPolicy | undefined;
    private _network;
    get network(): GoogleBeyondcorpApplicationUpstreamsNetworkOutputReference;
    putNetwork(value: GoogleBeyondcorpApplicationUpstreamsNetwork): void;
    resetNetwork(): void;
    get networkInput(): GoogleBeyondcorpApplicationUpstreamsNetwork | undefined;
}
export declare class GoogleBeyondcorpApplicationUpstreamsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleBeyondcorpApplicationUpstreams[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleBeyondcorpApplicationUpstreamsOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_beyondcorp_application google_beyondcorp_application}
*/
export declare class GoogleBeyondcorpApplication extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_beyondcorp_application";
    /**
    * Generates CDKTF code for importing a GoogleBeyondcorpApplication resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleBeyondcorpApplication to import
    * @param importFromId The id of the existing GoogleBeyondcorpApplication that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_beyondcorp_application#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleBeyondcorpApplication to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_beyondcorp_application google_beyondcorp_application} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleBeyondcorpApplicationConfig
    */
    constructor(scope: Construct, id: string, config: GoogleBeyondcorpApplicationConfig);
    private _applicationId?;
    get applicationId(): string;
    set applicationId(value: string);
    get applicationIdInput(): string | undefined;
    get createTime(): string;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _securityGatewaysId?;
    get securityGatewaysId(): string;
    set securityGatewaysId(value: string);
    get securityGatewaysIdInput(): string | undefined;
    get updateTime(): string;
    private _endpointMatchers;
    get endpointMatchers(): GoogleBeyondcorpApplicationEndpointMatchersList;
    putEndpointMatchers(value: GoogleBeyondcorpApplicationEndpointMatchers[] | cdktf.IResolvable): void;
    get endpointMatchersInput(): cdktf.IResolvable | GoogleBeyondcorpApplicationEndpointMatchers[] | undefined;
    private _timeouts;
    get timeouts(): GoogleBeyondcorpApplicationTimeoutsOutputReference;
    putTimeouts(value: GoogleBeyondcorpApplicationTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleBeyondcorpApplicationTimeouts | undefined;
    private _upstreams;
    get upstreams(): GoogleBeyondcorpApplicationUpstreamsList;
    putUpstreams(value: GoogleBeyondcorpApplicationUpstreams[] | cdktf.IResolvable): void;
    resetUpstreams(): void;
    get upstreamsInput(): cdktf.IResolvable | GoogleBeyondcorpApplicationUpstreams[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
