/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleBigtableLogicalViewConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_bigtable_logical_view#id GoogleBigtableLogicalView#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The name of the instance to create the logical view within.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_bigtable_logical_view#instance GoogleBigtableLogicalView#instance}
    */
    readonly instance?: string;
    /**
    * The unique name of the logical view in the form '[_a-zA-Z0-9][-_.a-zA-Z0-9]*'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_bigtable_logical_view#logical_view_id GoogleBigtableLogicalView#logical_view_id}
    */
    readonly logicalViewId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_bigtable_logical_view#project GoogleBigtableLogicalView#project}
    */
    readonly project?: string;
    /**
    * The logical view's select query.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_bigtable_logical_view#query GoogleBigtableLogicalView#query}
    */
    readonly query: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_bigtable_logical_view#timeouts GoogleBigtableLogicalView#timeouts}
    */
    readonly timeouts?: GoogleBigtableLogicalViewTimeouts;
}
export interface GoogleBigtableLogicalViewTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_bigtable_logical_view#create GoogleBigtableLogicalView#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_bigtable_logical_view#delete GoogleBigtableLogicalView#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_bigtable_logical_view#update GoogleBigtableLogicalView#update}
    */
    readonly update?: string;
}
export declare function googleBigtableLogicalViewTimeoutsToTerraform(struct?: GoogleBigtableLogicalViewTimeouts | cdktf.IResolvable): any;
export declare function googleBigtableLogicalViewTimeoutsToHclTerraform(struct?: GoogleBigtableLogicalViewTimeouts | cdktf.IResolvable): any;
export declare class GoogleBigtableLogicalViewTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleBigtableLogicalViewTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleBigtableLogicalViewTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_bigtable_logical_view google_bigtable_logical_view}
*/
export declare class GoogleBigtableLogicalView extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_bigtable_logical_view";
    /**
    * Generates CDKTF code for importing a GoogleBigtableLogicalView resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleBigtableLogicalView to import
    * @param importFromId The id of the existing GoogleBigtableLogicalView that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_bigtable_logical_view#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleBigtableLogicalView to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_bigtable_logical_view google_bigtable_logical_view} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleBigtableLogicalViewConfig
    */
    constructor(scope: Construct, id: string, config: GoogleBigtableLogicalViewConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _instance?;
    get instance(): string;
    set instance(value: string);
    resetInstance(): void;
    get instanceInput(): string | undefined;
    private _logicalViewId?;
    get logicalViewId(): string;
    set logicalViewId(value: string);
    get logicalViewIdInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _query?;
    get query(): string;
    set query(value: string);
    get queryInput(): string | undefined;
    private _timeouts;
    get timeouts(): GoogleBigtableLogicalViewTimeoutsOutputReference;
    putTimeouts(value: GoogleBigtableLogicalViewTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleBigtableLogicalViewTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
