/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleChronicleReferenceListConfig extends cdktf.TerraformMetaArguments {
    /**
    * Required. A user-provided description of the reference list.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_chronicle_reference_list#description GoogleChronicleReferenceList#description}
    */
    readonly description: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_chronicle_reference_list#id GoogleChronicleReferenceList#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The unique identifier for the Chronicle instance, which is the same as the customer ID.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_chronicle_reference_list#instance GoogleChronicleReferenceList#instance}
    */
    readonly instance: string;
    /**
    * The location of the resource. This is the geographical region where the Chronicle instance resides, such as "us" or "europe-west2".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_chronicle_reference_list#location GoogleChronicleReferenceList#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_chronicle_reference_list#project GoogleChronicleReferenceList#project}
    */
    readonly project?: string;
    /**
    * Required. The ID to use for the reference list. This is also the display name for
    * the reference list. It must satisfy the following requirements:
    * - Starts with letter.
    * - Contains only letters, numbers and underscore.
    * - Has length < 256.
    * - Must be unique.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_chronicle_reference_list#reference_list_id GoogleChronicleReferenceList#reference_list_id}
    */
    readonly referenceListId: string;
    /**
    * Possible values:
    * REFERENCE_LIST_SYNTAX_TYPE_PLAIN_TEXT_STRING
    * REFERENCE_LIST_SYNTAX_TYPE_REGEX
    * REFERENCE_LIST_SYNTAX_TYPE_CIDR
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_chronicle_reference_list#syntax_type GoogleChronicleReferenceList#syntax_type}
    */
    readonly syntaxType: string;
    /**
    * entries block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_chronicle_reference_list#entries GoogleChronicleReferenceList#entries}
    */
    readonly entries: GoogleChronicleReferenceListEntries[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_chronicle_reference_list#timeouts GoogleChronicleReferenceList#timeouts}
    */
    readonly timeouts?: GoogleChronicleReferenceListTimeouts;
}
export interface GoogleChronicleReferenceListScopeInfoReferenceListScope {
}
export declare function googleChronicleReferenceListScopeInfoReferenceListScopeToTerraform(struct?: GoogleChronicleReferenceListScopeInfoReferenceListScope): any;
export declare function googleChronicleReferenceListScopeInfoReferenceListScopeToHclTerraform(struct?: GoogleChronicleReferenceListScopeInfoReferenceListScope): any;
export declare class GoogleChronicleReferenceListScopeInfoReferenceListScopeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleChronicleReferenceListScopeInfoReferenceListScope | undefined;
    set internalValue(value: GoogleChronicleReferenceListScopeInfoReferenceListScope | undefined);
    get scopeNames(): string[];
}
export declare class GoogleChronicleReferenceListScopeInfoReferenceListScopeList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleChronicleReferenceListScopeInfoReferenceListScopeOutputReference;
}
export interface GoogleChronicleReferenceListScopeInfo {
}
export declare function googleChronicleReferenceListScopeInfoToTerraform(struct?: GoogleChronicleReferenceListScopeInfo): any;
export declare function googleChronicleReferenceListScopeInfoToHclTerraform(struct?: GoogleChronicleReferenceListScopeInfo): any;
export declare class GoogleChronicleReferenceListScopeInfoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleChronicleReferenceListScopeInfo | undefined;
    set internalValue(value: GoogleChronicleReferenceListScopeInfo | undefined);
    private _referenceListScope;
    get referenceListScope(): GoogleChronicleReferenceListScopeInfoReferenceListScopeList;
}
export declare class GoogleChronicleReferenceListScopeInfoList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleChronicleReferenceListScopeInfoOutputReference;
}
export interface GoogleChronicleReferenceListEntries {
    /**
    * Required. The value of the entry. Maximum length is 512 characters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_chronicle_reference_list#value GoogleChronicleReferenceList#value}
    */
    readonly value: string;
}
export declare function googleChronicleReferenceListEntriesToTerraform(struct?: GoogleChronicleReferenceListEntries | cdktf.IResolvable): any;
export declare function googleChronicleReferenceListEntriesToHclTerraform(struct?: GoogleChronicleReferenceListEntries | cdktf.IResolvable): any;
export declare class GoogleChronicleReferenceListEntriesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleChronicleReferenceListEntries | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleChronicleReferenceListEntries | cdktf.IResolvable | undefined);
    private _value?;
    get value(): string;
    set value(value: string);
    get valueInput(): string | undefined;
}
export declare class GoogleChronicleReferenceListEntriesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleChronicleReferenceListEntries[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleChronicleReferenceListEntriesOutputReference;
}
export interface GoogleChronicleReferenceListTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_chronicle_reference_list#create GoogleChronicleReferenceList#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_chronicle_reference_list#delete GoogleChronicleReferenceList#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_chronicle_reference_list#update GoogleChronicleReferenceList#update}
    */
    readonly update?: string;
}
export declare function googleChronicleReferenceListTimeoutsToTerraform(struct?: GoogleChronicleReferenceListTimeouts | cdktf.IResolvable): any;
export declare function googleChronicleReferenceListTimeoutsToHclTerraform(struct?: GoogleChronicleReferenceListTimeouts | cdktf.IResolvable): any;
export declare class GoogleChronicleReferenceListTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleChronicleReferenceListTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleChronicleReferenceListTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_chronicle_reference_list google_chronicle_reference_list}
*/
export declare class GoogleChronicleReferenceList extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_chronicle_reference_list";
    /**
    * Generates CDKTF code for importing a GoogleChronicleReferenceList resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleChronicleReferenceList to import
    * @param importFromId The id of the existing GoogleChronicleReferenceList that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_chronicle_reference_list#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleChronicleReferenceList to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_chronicle_reference_list google_chronicle_reference_list} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleChronicleReferenceListConfig
    */
    constructor(scope: Construct, id: string, config: GoogleChronicleReferenceListConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    get descriptionInput(): string | undefined;
    get displayName(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _instance?;
    get instance(): string;
    set instance(value: string);
    get instanceInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _referenceListId?;
    get referenceListId(): string;
    set referenceListId(value: string);
    get referenceListIdInput(): string | undefined;
    get revisionCreateTime(): string;
    get ruleAssociationsCount(): number;
    get rules(): string[];
    private _scopeInfo;
    get scopeInfo(): GoogleChronicleReferenceListScopeInfoList;
    private _syntaxType?;
    get syntaxType(): string;
    set syntaxType(value: string);
    get syntaxTypeInput(): string | undefined;
    private _entries;
    get entries(): GoogleChronicleReferenceListEntriesList;
    putEntries(value: GoogleChronicleReferenceListEntries[] | cdktf.IResolvable): void;
    get entriesInput(): cdktf.IResolvable | GoogleChronicleReferenceListEntries[] | undefined;
    private _timeouts;
    get timeouts(): GoogleChronicleReferenceListTimeoutsOutputReference;
    putTimeouts(value: GoogleChronicleReferenceListTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleChronicleReferenceListTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
