/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleChronicleRetrohuntConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_chronicle_retrohunt#id GoogleChronicleRetrohunt#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The unique identifier for the Chronicle instance, which is the same as the customer ID.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_chronicle_retrohunt#instance GoogleChronicleRetrohunt#instance}
    */
    readonly instance: string;
    /**
    * The location of the resource. This is the geographical region where the Chronicle instance resides, such as "us" or "europe-west2".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_chronicle_retrohunt#location GoogleChronicleRetrohunt#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_chronicle_retrohunt#project GoogleChronicleRetrohunt#project}
    */
    readonly project?: string;
    /**
    * The retrohunt ID of the Retrohunt. A retrohunt is an execution of a Rule over a time range in the past.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_chronicle_retrohunt#retrohunt GoogleChronicleRetrohunt#retrohunt}
    */
    readonly retrohunt?: string;
    /**
    * The Rule ID of the rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_chronicle_retrohunt#rule GoogleChronicleRetrohunt#rule}
    */
    readonly rule: string;
    /**
    * process_interval block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_chronicle_retrohunt#process_interval GoogleChronicleRetrohunt#process_interval}
    */
    readonly processInterval: GoogleChronicleRetrohuntProcessInterval;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_chronicle_retrohunt#timeouts GoogleChronicleRetrohunt#timeouts}
    */
    readonly timeouts?: GoogleChronicleRetrohuntTimeouts;
}
export interface GoogleChronicleRetrohuntExecutionInterval {
}
export declare function googleChronicleRetrohuntExecutionIntervalToTerraform(struct?: GoogleChronicleRetrohuntExecutionInterval): any;
export declare function googleChronicleRetrohuntExecutionIntervalToHclTerraform(struct?: GoogleChronicleRetrohuntExecutionInterval): any;
export declare class GoogleChronicleRetrohuntExecutionIntervalOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleChronicleRetrohuntExecutionInterval | undefined;
    set internalValue(value: GoogleChronicleRetrohuntExecutionInterval | undefined);
    get endTime(): string;
    get startTime(): string;
}
export declare class GoogleChronicleRetrohuntExecutionIntervalList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleChronicleRetrohuntExecutionIntervalOutputReference;
}
export interface GoogleChronicleRetrohuntProcessInterval {
    /**
    * Exclusive end of the interval.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_chronicle_retrohunt#end_time GoogleChronicleRetrohunt#end_time}
    */
    readonly endTime: string;
    /**
    * Inclusive start of the interval.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_chronicle_retrohunt#start_time GoogleChronicleRetrohunt#start_time}
    */
    readonly startTime: string;
}
export declare function googleChronicleRetrohuntProcessIntervalToTerraform(struct?: GoogleChronicleRetrohuntProcessIntervalOutputReference | GoogleChronicleRetrohuntProcessInterval): any;
export declare function googleChronicleRetrohuntProcessIntervalToHclTerraform(struct?: GoogleChronicleRetrohuntProcessIntervalOutputReference | GoogleChronicleRetrohuntProcessInterval): any;
export declare class GoogleChronicleRetrohuntProcessIntervalOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleChronicleRetrohuntProcessInterval | undefined;
    set internalValue(value: GoogleChronicleRetrohuntProcessInterval | undefined);
    private _endTime?;
    get endTime(): string;
    set endTime(value: string);
    get endTimeInput(): string | undefined;
    private _startTime?;
    get startTime(): string;
    set startTime(value: string);
    get startTimeInput(): string | undefined;
}
export interface GoogleChronicleRetrohuntTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_chronicle_retrohunt#create GoogleChronicleRetrohunt#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_chronicle_retrohunt#delete GoogleChronicleRetrohunt#delete}
    */
    readonly delete?: string;
}
export declare function googleChronicleRetrohuntTimeoutsToTerraform(struct?: GoogleChronicleRetrohuntTimeouts | cdktf.IResolvable): any;
export declare function googleChronicleRetrohuntTimeoutsToHclTerraform(struct?: GoogleChronicleRetrohuntTimeouts | cdktf.IResolvable): any;
export declare class GoogleChronicleRetrohuntTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleChronicleRetrohuntTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleChronicleRetrohuntTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_chronicle_retrohunt google_chronicle_retrohunt}
*/
export declare class GoogleChronicleRetrohunt extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_chronicle_retrohunt";
    /**
    * Generates CDKTF code for importing a GoogleChronicleRetrohunt resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleChronicleRetrohunt to import
    * @param importFromId The id of the existing GoogleChronicleRetrohunt that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_chronicle_retrohunt#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleChronicleRetrohunt to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_chronicle_retrohunt google_chronicle_retrohunt} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleChronicleRetrohuntConfig
    */
    constructor(scope: Construct, id: string, config: GoogleChronicleRetrohuntConfig);
    private _executionInterval;
    get executionInterval(): GoogleChronicleRetrohuntExecutionIntervalList;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _instance?;
    get instance(): string;
    set instance(value: string);
    get instanceInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    get progressPercentage(): number;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _retrohunt?;
    get retrohunt(): string;
    set retrohunt(value: string);
    resetRetrohunt(): void;
    get retrohuntInput(): string | undefined;
    private _rule?;
    get rule(): string;
    set rule(value: string);
    get ruleInput(): string | undefined;
    get state(): string;
    private _processInterval;
    get processInterval(): GoogleChronicleRetrohuntProcessIntervalOutputReference;
    putProcessInterval(value: GoogleChronicleRetrohuntProcessInterval): void;
    get processIntervalInput(): GoogleChronicleRetrohuntProcessInterval | undefined;
    private _timeouts;
    get timeouts(): GoogleChronicleRetrohuntTimeoutsOutputReference;
    putTimeouts(value: GoogleChronicleRetrohuntTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleChronicleRetrohuntTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
