/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleColabNotebookExecutionConfig extends cdktf.TerraformMetaArguments {
    /**
    * Required. The display name of the Notebook Execution.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_notebook_execution#display_name GoogleColabNotebookExecution#display_name}
    */
    readonly displayName: string;
    /**
    * Max running time of the execution job in seconds (default 86400s / 24 hrs).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_notebook_execution#execution_timeout GoogleColabNotebookExecution#execution_timeout}
    */
    readonly executionTimeout?: string;
    /**
    * The user email to run the execution as.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_notebook_execution#execution_user GoogleColabNotebookExecution#execution_user}
    */
    readonly executionUser?: string;
    /**
    * The Cloud Storage location to upload the result to. Format:'gs://bucket-name'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_notebook_execution#gcs_output_uri GoogleColabNotebookExecution#gcs_output_uri}
    */
    readonly gcsOutputUri: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_notebook_execution#id GoogleColabNotebookExecution#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The location for the resource: https://cloud.google.com/colab/docs/locations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_notebook_execution#location GoogleColabNotebookExecution#location}
    */
    readonly location: string;
    /**
    * User specified ID for the Notebook Execution Job
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_notebook_execution#notebook_execution_job_id GoogleColabNotebookExecution#notebook_execution_job_id}
    */
    readonly notebookExecutionJobId?: string;
    /**
    * The NotebookRuntimeTemplate to source compute configuration from.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_notebook_execution#notebook_runtime_template_resource_name GoogleColabNotebookExecution#notebook_runtime_template_resource_name}
    */
    readonly notebookRuntimeTemplateResourceName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_notebook_execution#project GoogleColabNotebookExecution#project}
    */
    readonly project?: string;
    /**
    * The service account to run the execution as.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_notebook_execution#service_account GoogleColabNotebookExecution#service_account}
    */
    readonly serviceAccount?: string;
    /**
    * dataform_repository_source block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_notebook_execution#dataform_repository_source GoogleColabNotebookExecution#dataform_repository_source}
    */
    readonly dataformRepositorySource?: GoogleColabNotebookExecutionDataformRepositorySource;
    /**
    * direct_notebook_source block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_notebook_execution#direct_notebook_source GoogleColabNotebookExecution#direct_notebook_source}
    */
    readonly directNotebookSource?: GoogleColabNotebookExecutionDirectNotebookSource;
    /**
    * gcs_notebook_source block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_notebook_execution#gcs_notebook_source GoogleColabNotebookExecution#gcs_notebook_source}
    */
    readonly gcsNotebookSource?: GoogleColabNotebookExecutionGcsNotebookSource;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_notebook_execution#timeouts GoogleColabNotebookExecution#timeouts}
    */
    readonly timeouts?: GoogleColabNotebookExecutionTimeouts;
}
export interface GoogleColabNotebookExecutionDataformRepositorySource {
    /**
    * The commit SHA to read repository with. If unset, the file will be read at HEAD.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_notebook_execution#commit_sha GoogleColabNotebookExecution#commit_sha}
    */
    readonly commitSha?: string;
    /**
    * The resource name of the Dataform Repository.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_notebook_execution#dataform_repository_resource_name GoogleColabNotebookExecution#dataform_repository_resource_name}
    */
    readonly dataformRepositoryResourceName: string;
}
export declare function googleColabNotebookExecutionDataformRepositorySourceToTerraform(struct?: GoogleColabNotebookExecutionDataformRepositorySourceOutputReference | GoogleColabNotebookExecutionDataformRepositorySource): any;
export declare function googleColabNotebookExecutionDataformRepositorySourceToHclTerraform(struct?: GoogleColabNotebookExecutionDataformRepositorySourceOutputReference | GoogleColabNotebookExecutionDataformRepositorySource): any;
export declare class GoogleColabNotebookExecutionDataformRepositorySourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleColabNotebookExecutionDataformRepositorySource | undefined;
    set internalValue(value: GoogleColabNotebookExecutionDataformRepositorySource | undefined);
    private _commitSha?;
    get commitSha(): string;
    set commitSha(value: string);
    resetCommitSha(): void;
    get commitShaInput(): string | undefined;
    private _dataformRepositoryResourceName?;
    get dataformRepositoryResourceName(): string;
    set dataformRepositoryResourceName(value: string);
    get dataformRepositoryResourceNameInput(): string | undefined;
}
export interface GoogleColabNotebookExecutionDirectNotebookSource {
    /**
    * The base64-encoded contents of the input notebook file.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_notebook_execution#content GoogleColabNotebookExecution#content}
    */
    readonly content: string;
}
export declare function googleColabNotebookExecutionDirectNotebookSourceToTerraform(struct?: GoogleColabNotebookExecutionDirectNotebookSourceOutputReference | GoogleColabNotebookExecutionDirectNotebookSource): any;
export declare function googleColabNotebookExecutionDirectNotebookSourceToHclTerraform(struct?: GoogleColabNotebookExecutionDirectNotebookSourceOutputReference | GoogleColabNotebookExecutionDirectNotebookSource): any;
export declare class GoogleColabNotebookExecutionDirectNotebookSourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleColabNotebookExecutionDirectNotebookSource | undefined;
    set internalValue(value: GoogleColabNotebookExecutionDirectNotebookSource | undefined);
    private _content?;
    get content(): string;
    set content(value: string);
    get contentInput(): string | undefined;
}
export interface GoogleColabNotebookExecutionGcsNotebookSource {
    /**
    * The version of the Cloud Storage object to read. If unset, the current version of the object is read. See https://cloud.google.com/storage/docs/metadata#generation-number.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_notebook_execution#generation GoogleColabNotebookExecution#generation}
    */
    readonly generation?: string;
    /**
    * The Cloud Storage uri pointing to the ipynb file.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_notebook_execution#uri GoogleColabNotebookExecution#uri}
    */
    readonly uri: string;
}
export declare function googleColabNotebookExecutionGcsNotebookSourceToTerraform(struct?: GoogleColabNotebookExecutionGcsNotebookSourceOutputReference | GoogleColabNotebookExecutionGcsNotebookSource): any;
export declare function googleColabNotebookExecutionGcsNotebookSourceToHclTerraform(struct?: GoogleColabNotebookExecutionGcsNotebookSourceOutputReference | GoogleColabNotebookExecutionGcsNotebookSource): any;
export declare class GoogleColabNotebookExecutionGcsNotebookSourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleColabNotebookExecutionGcsNotebookSource | undefined;
    set internalValue(value: GoogleColabNotebookExecutionGcsNotebookSource | undefined);
    private _generation?;
    get generation(): string;
    set generation(value: string);
    resetGeneration(): void;
    get generationInput(): string | undefined;
    private _uri?;
    get uri(): string;
    set uri(value: string);
    get uriInput(): string | undefined;
}
export interface GoogleColabNotebookExecutionTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_notebook_execution#create GoogleColabNotebookExecution#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_notebook_execution#delete GoogleColabNotebookExecution#delete}
    */
    readonly delete?: string;
}
export declare function googleColabNotebookExecutionTimeoutsToTerraform(struct?: GoogleColabNotebookExecutionTimeouts | cdktf.IResolvable): any;
export declare function googleColabNotebookExecutionTimeoutsToHclTerraform(struct?: GoogleColabNotebookExecutionTimeouts | cdktf.IResolvable): any;
export declare class GoogleColabNotebookExecutionTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleColabNotebookExecutionTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleColabNotebookExecutionTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_notebook_execution google_colab_notebook_execution}
*/
export declare class GoogleColabNotebookExecution extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_colab_notebook_execution";
    /**
    * Generates CDKTF code for importing a GoogleColabNotebookExecution resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleColabNotebookExecution to import
    * @param importFromId The id of the existing GoogleColabNotebookExecution that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_notebook_execution#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleColabNotebookExecution to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_notebook_execution google_colab_notebook_execution} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleColabNotebookExecutionConfig
    */
    constructor(scope: Construct, id: string, config: GoogleColabNotebookExecutionConfig);
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    private _executionTimeout?;
    get executionTimeout(): string;
    set executionTimeout(value: string);
    resetExecutionTimeout(): void;
    get executionTimeoutInput(): string | undefined;
    private _executionUser?;
    get executionUser(): string;
    set executionUser(value: string);
    resetExecutionUser(): void;
    get executionUserInput(): string | undefined;
    private _gcsOutputUri?;
    get gcsOutputUri(): string;
    set gcsOutputUri(value: string);
    get gcsOutputUriInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _notebookExecutionJobId?;
    get notebookExecutionJobId(): string;
    set notebookExecutionJobId(value: string);
    resetNotebookExecutionJobId(): void;
    get notebookExecutionJobIdInput(): string | undefined;
    private _notebookRuntimeTemplateResourceName?;
    get notebookRuntimeTemplateResourceName(): string;
    set notebookRuntimeTemplateResourceName(value: string);
    resetNotebookRuntimeTemplateResourceName(): void;
    get notebookRuntimeTemplateResourceNameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _serviceAccount?;
    get serviceAccount(): string;
    set serviceAccount(value: string);
    resetServiceAccount(): void;
    get serviceAccountInput(): string | undefined;
    private _dataformRepositorySource;
    get dataformRepositorySource(): GoogleColabNotebookExecutionDataformRepositorySourceOutputReference;
    putDataformRepositorySource(value: GoogleColabNotebookExecutionDataformRepositorySource): void;
    resetDataformRepositorySource(): void;
    get dataformRepositorySourceInput(): GoogleColabNotebookExecutionDataformRepositorySource | undefined;
    private _directNotebookSource;
    get directNotebookSource(): GoogleColabNotebookExecutionDirectNotebookSourceOutputReference;
    putDirectNotebookSource(value: GoogleColabNotebookExecutionDirectNotebookSource): void;
    resetDirectNotebookSource(): void;
    get directNotebookSourceInput(): GoogleColabNotebookExecutionDirectNotebookSource | undefined;
    private _gcsNotebookSource;
    get gcsNotebookSource(): GoogleColabNotebookExecutionGcsNotebookSourceOutputReference;
    putGcsNotebookSource(value: GoogleColabNotebookExecutionGcsNotebookSource): void;
    resetGcsNotebookSource(): void;
    get gcsNotebookSourceInput(): GoogleColabNotebookExecutionGcsNotebookSource | undefined;
    private _timeouts;
    get timeouts(): GoogleColabNotebookExecutionTimeoutsOutputReference;
    putTimeouts(value: GoogleColabNotebookExecutionTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleColabNotebookExecutionTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
