/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleColabRuntimeConfig extends cdktf.TerraformMetaArguments {
    /**
    * Triggers an upgrade anytime the runtime is started if it is upgradable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_runtime#auto_upgrade GoogleColabRuntime#auto_upgrade}
    */
    readonly autoUpgrade?: boolean | cdktf.IResolvable;
    /**
    * The description of the Runtime.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_runtime#description GoogleColabRuntime#description}
    */
    readonly description?: string;
    /**
    * Desired state of the Colab Runtime. Set this field to 'RUNNING' to start the runtime, and 'STOPPED' to stop it.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_runtime#desired_state GoogleColabRuntime#desired_state}
    */
    readonly desiredState?: string;
    /**
    * Required. The display name of the Runtime.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_runtime#display_name GoogleColabRuntime#display_name}
    */
    readonly displayName: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_runtime#id GoogleColabRuntime#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The location for the resource: https://cloud.google.com/colab/docs/locations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_runtime#location GoogleColabRuntime#location}
    */
    readonly location: string;
    /**
    * The resource name of the Runtime
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_runtime#name GoogleColabRuntime#name}
    */
    readonly name?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_runtime#project GoogleColabRuntime#project}
    */
    readonly project?: string;
    /**
    * The user email of the NotebookRuntime.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_runtime#runtime_user GoogleColabRuntime#runtime_user}
    */
    readonly runtimeUser: string;
    /**
    * notebook_runtime_template_ref block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_runtime#notebook_runtime_template_ref GoogleColabRuntime#notebook_runtime_template_ref}
    */
    readonly notebookRuntimeTemplateRef?: GoogleColabRuntimeNotebookRuntimeTemplateRef;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_runtime#timeouts GoogleColabRuntime#timeouts}
    */
    readonly timeouts?: GoogleColabRuntimeTimeouts;
}
export interface GoogleColabRuntimeNotebookRuntimeTemplateRef {
    /**
    * The resource name of the NotebookRuntimeTemplate based on which a NotebookRuntime will be created.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_runtime#notebook_runtime_template GoogleColabRuntime#notebook_runtime_template}
    */
    readonly notebookRuntimeTemplate: string;
}
export declare function googleColabRuntimeNotebookRuntimeTemplateRefToTerraform(struct?: GoogleColabRuntimeNotebookRuntimeTemplateRefOutputReference | GoogleColabRuntimeNotebookRuntimeTemplateRef): any;
export declare function googleColabRuntimeNotebookRuntimeTemplateRefToHclTerraform(struct?: GoogleColabRuntimeNotebookRuntimeTemplateRefOutputReference | GoogleColabRuntimeNotebookRuntimeTemplateRef): any;
export declare class GoogleColabRuntimeNotebookRuntimeTemplateRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleColabRuntimeNotebookRuntimeTemplateRef | undefined;
    set internalValue(value: GoogleColabRuntimeNotebookRuntimeTemplateRef | undefined);
    private _notebookRuntimeTemplate?;
    get notebookRuntimeTemplate(): string;
    set notebookRuntimeTemplate(value: string);
    get notebookRuntimeTemplateInput(): string | undefined;
}
export interface GoogleColabRuntimeTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_runtime#create GoogleColabRuntime#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_runtime#delete GoogleColabRuntime#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_runtime#update GoogleColabRuntime#update}
    */
    readonly update?: string;
}
export declare function googleColabRuntimeTimeoutsToTerraform(struct?: GoogleColabRuntimeTimeouts | cdktf.IResolvable): any;
export declare function googleColabRuntimeTimeoutsToHclTerraform(struct?: GoogleColabRuntimeTimeouts | cdktf.IResolvable): any;
export declare class GoogleColabRuntimeTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleColabRuntimeTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleColabRuntimeTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_runtime google_colab_runtime}
*/
export declare class GoogleColabRuntime extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_colab_runtime";
    /**
    * Generates CDKTF code for importing a GoogleColabRuntime resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleColabRuntime to import
    * @param importFromId The id of the existing GoogleColabRuntime that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_runtime#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleColabRuntime to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_colab_runtime google_colab_runtime} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleColabRuntimeConfig
    */
    constructor(scope: Construct, id: string, config: GoogleColabRuntimeConfig);
    private _autoUpgrade?;
    get autoUpgrade(): boolean | cdktf.IResolvable;
    set autoUpgrade(value: boolean | cdktf.IResolvable);
    resetAutoUpgrade(): void;
    get autoUpgradeInput(): boolean | cdktf.IResolvable | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _desiredState?;
    get desiredState(): string;
    set desiredState(value: string);
    resetDesiredState(): void;
    get desiredStateInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    get expirationTime(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get isUpgradable(): cdktf.IResolvable;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    get notebookRuntimeType(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _runtimeUser?;
    get runtimeUser(): string;
    set runtimeUser(value: string);
    get runtimeUserInput(): string | undefined;
    get state(): string;
    private _notebookRuntimeTemplateRef;
    get notebookRuntimeTemplateRef(): GoogleColabRuntimeNotebookRuntimeTemplateRefOutputReference;
    putNotebookRuntimeTemplateRef(value: GoogleColabRuntimeNotebookRuntimeTemplateRef): void;
    resetNotebookRuntimeTemplateRef(): void;
    get notebookRuntimeTemplateRefInput(): GoogleColabRuntimeNotebookRuntimeTemplateRef | undefined;
    private _timeouts;
    get timeouts(): GoogleColabRuntimeTimeoutsOutputReference;
    putTimeouts(value: GoogleColabRuntimeTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleColabRuntimeTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
