/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleDataprocGdcServiceInstanceConfig extends cdktf.TerraformMetaArguments {
    /**
    * User-provided human-readable name to be used in user interfaces.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_dataproc_gdc_service_instance#display_name GoogleDataprocGdcServiceInstance#display_name}
    */
    readonly displayName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_dataproc_gdc_service_instance#id GoogleDataprocGdcServiceInstance#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The labels to associate with this service instance. Labels may be used for filtering and billing tracking.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_dataproc_gdc_service_instance#labels GoogleDataprocGdcServiceInstance#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Location of the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_dataproc_gdc_service_instance#location GoogleDataprocGdcServiceInstance#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_dataproc_gdc_service_instance#project GoogleDataprocGdcServiceInstance#project}
    */
    readonly project?: string;
    /**
    * Requested service account to associate with ServiceInstance.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_dataproc_gdc_service_instance#service_account GoogleDataprocGdcServiceInstance#service_account}
    */
    readonly serviceAccount?: string;
    /**
    * Id of the service instance.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_dataproc_gdc_service_instance#service_instance_id GoogleDataprocGdcServiceInstance#service_instance_id}
    */
    readonly serviceInstanceId: string;
    /**
    * gdce_cluster block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_dataproc_gdc_service_instance#gdce_cluster GoogleDataprocGdcServiceInstance#gdce_cluster}
    */
    readonly gdceCluster?: GoogleDataprocGdcServiceInstanceGdceCluster;
    /**
    * spark_service_instance_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_dataproc_gdc_service_instance#spark_service_instance_config GoogleDataprocGdcServiceInstance#spark_service_instance_config}
    */
    readonly sparkServiceInstanceConfig?: GoogleDataprocGdcServiceInstanceSparkServiceInstanceConfig;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_dataproc_gdc_service_instance#timeouts GoogleDataprocGdcServiceInstance#timeouts}
    */
    readonly timeouts?: GoogleDataprocGdcServiceInstanceTimeouts;
}
export interface GoogleDataprocGdcServiceInstanceGdceCluster {
    /**
    * Gdce cluster resource id.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_dataproc_gdc_service_instance#gdce_cluster GoogleDataprocGdcServiceInstance#gdce_cluster}
    */
    readonly gdceCluster: string;
}
export declare function googleDataprocGdcServiceInstanceGdceClusterToTerraform(struct?: GoogleDataprocGdcServiceInstanceGdceClusterOutputReference | GoogleDataprocGdcServiceInstanceGdceCluster): any;
export declare function googleDataprocGdcServiceInstanceGdceClusterToHclTerraform(struct?: GoogleDataprocGdcServiceInstanceGdceClusterOutputReference | GoogleDataprocGdcServiceInstanceGdceCluster): any;
export declare class GoogleDataprocGdcServiceInstanceGdceClusterOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataprocGdcServiceInstanceGdceCluster | undefined;
    set internalValue(value: GoogleDataprocGdcServiceInstanceGdceCluster | undefined);
    private _gdceCluster?;
    get gdceCluster(): string;
    set gdceCluster(value: string);
    get gdceClusterInput(): string | undefined;
}
export interface GoogleDataprocGdcServiceInstanceSparkServiceInstanceConfig {
}
export declare function googleDataprocGdcServiceInstanceSparkServiceInstanceConfigToTerraform(struct?: GoogleDataprocGdcServiceInstanceSparkServiceInstanceConfigOutputReference | GoogleDataprocGdcServiceInstanceSparkServiceInstanceConfig): any;
export declare function googleDataprocGdcServiceInstanceSparkServiceInstanceConfigToHclTerraform(struct?: GoogleDataprocGdcServiceInstanceSparkServiceInstanceConfigOutputReference | GoogleDataprocGdcServiceInstanceSparkServiceInstanceConfig): any;
export declare class GoogleDataprocGdcServiceInstanceSparkServiceInstanceConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataprocGdcServiceInstanceSparkServiceInstanceConfig | undefined;
    set internalValue(value: GoogleDataprocGdcServiceInstanceSparkServiceInstanceConfig | undefined);
}
export interface GoogleDataprocGdcServiceInstanceTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_dataproc_gdc_service_instance#create GoogleDataprocGdcServiceInstance#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_dataproc_gdc_service_instance#delete GoogleDataprocGdcServiceInstance#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_dataproc_gdc_service_instance#update GoogleDataprocGdcServiceInstance#update}
    */
    readonly update?: string;
}
export declare function googleDataprocGdcServiceInstanceTimeoutsToTerraform(struct?: GoogleDataprocGdcServiceInstanceTimeouts | cdktf.IResolvable): any;
export declare function googleDataprocGdcServiceInstanceTimeoutsToHclTerraform(struct?: GoogleDataprocGdcServiceInstanceTimeouts | cdktf.IResolvable): any;
export declare class GoogleDataprocGdcServiceInstanceTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataprocGdcServiceInstanceTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleDataprocGdcServiceInstanceTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_dataproc_gdc_service_instance google_dataproc_gdc_service_instance}
*/
export declare class GoogleDataprocGdcServiceInstance extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_dataproc_gdc_service_instance";
    /**
    * Generates CDKTF code for importing a GoogleDataprocGdcServiceInstance resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleDataprocGdcServiceInstance to import
    * @param importFromId The id of the existing GoogleDataprocGdcServiceInstance that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_dataproc_gdc_service_instance#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleDataprocGdcServiceInstance to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_dataproc_gdc_service_instance google_dataproc_gdc_service_instance} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleDataprocGdcServiceInstanceConfig
    */
    constructor(scope: Construct, id: string, config: GoogleDataprocGdcServiceInstanceConfig);
    get createTime(): string;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    get effectiveServiceAccount(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get reconciling(): cdktf.IResolvable;
    get requestedState(): string;
    private _serviceAccount?;
    get serviceAccount(): string;
    set serviceAccount(value: string);
    resetServiceAccount(): void;
    get serviceAccountInput(): string | undefined;
    private _serviceInstanceId?;
    get serviceInstanceId(): string;
    set serviceInstanceId(value: string);
    get serviceInstanceIdInput(): string | undefined;
    get state(): string;
    get stateMessage(): string;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get uid(): string;
    get updateTime(): string;
    private _gdceCluster;
    get gdceCluster(): GoogleDataprocGdcServiceInstanceGdceClusterOutputReference;
    putGdceCluster(value: GoogleDataprocGdcServiceInstanceGdceCluster): void;
    resetGdceCluster(): void;
    get gdceClusterInput(): GoogleDataprocGdcServiceInstanceGdceCluster | undefined;
    private _sparkServiceInstanceConfig;
    get sparkServiceInstanceConfig(): GoogleDataprocGdcServiceInstanceSparkServiceInstanceConfigOutputReference;
    putSparkServiceInstanceConfig(value: GoogleDataprocGdcServiceInstanceSparkServiceInstanceConfig): void;
    resetSparkServiceInstanceConfig(): void;
    get sparkServiceInstanceConfigInput(): GoogleDataprocGdcServiceInstanceSparkServiceInstanceConfig | undefined;
    private _timeouts;
    get timeouts(): GoogleDataprocGdcServiceInstanceTimeoutsOutputReference;
    putTimeouts(value: GoogleDataprocGdcServiceInstanceTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleDataprocGdcServiceInstanceTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
