/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleEventarcGoogleApiSourceConfig extends cdktf.TerraformMetaArguments {
    /**
    * Resource annotations.
    *
    * **Note**: This field is non-authoritative, and will only manage the annotations present in your configuration.
    * Please refer to the field 'effective_annotations' for all of the annotations present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_google_api_source#annotations GoogleEventarcGoogleApiSource#annotations}
    */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
    * Resource name of a KMS crypto key (managed by the user) used to
    * encrypt/decrypt their event data.
    *
    * It must match the pattern
    * 'projects/* /locations/* /keyRings/* /cryptoKeys/*'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_google_api_source#crypto_key_name GoogleEventarcGoogleApiSource#crypto_key_name}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly cryptoKeyName?: string;
    /**
    * Destination is the message bus that the GoogleApiSource is delivering to.
    * It must be point to the full resource name of a MessageBus. Format:
    * "projects/{PROJECT_ID}/locations/{region}/messagesBuses/{MESSAGE_BUS_ID)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_google_api_source#destination GoogleEventarcGoogleApiSource#destination}
    */
    readonly destination: string;
    /**
    * Resource display name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_google_api_source#display_name GoogleEventarcGoogleApiSource#display_name}
    */
    readonly displayName?: string;
    /**
    * The user-provided ID to be assigned to the GoogleApiSource. It should match
    * the format '^[a-z]([a-z0-9-]{0,61}[a-z0-9])?$'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_google_api_source#google_api_source_id GoogleEventarcGoogleApiSource#google_api_source_id}
    */
    readonly googleApiSourceId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_google_api_source#id GoogleEventarcGoogleApiSource#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Resource labels.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_google_api_source#labels GoogleEventarcGoogleApiSource#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Resource ID segment making up resource 'name'. It identifies the resource within its parent collection as described in https://google.aip.dev/122.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_google_api_source#location GoogleEventarcGoogleApiSource#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_google_api_source#project GoogleEventarcGoogleApiSource#project}
    */
    readonly project?: string;
    /**
    * logging_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_google_api_source#logging_config GoogleEventarcGoogleApiSource#logging_config}
    */
    readonly loggingConfig?: GoogleEventarcGoogleApiSourceLoggingConfig;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_google_api_source#timeouts GoogleEventarcGoogleApiSource#timeouts}
    */
    readonly timeouts?: GoogleEventarcGoogleApiSourceTimeouts;
}
export interface GoogleEventarcGoogleApiSourceLoggingConfig {
    /**
    * The minimum severity of logs that will be sent to Stackdriver/Platform
    * Telemetry. Logs at severitiy ≥ this value will be sent, unless it is NONE. Possible values: ["NONE", "DEBUG", "INFO", "NOTICE", "WARNING", "ERROR", "CRITICAL", "ALERT", "EMERGENCY"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_google_api_source#log_severity GoogleEventarcGoogleApiSource#log_severity}
    */
    readonly logSeverity?: string;
}
export declare function googleEventarcGoogleApiSourceLoggingConfigToTerraform(struct?: GoogleEventarcGoogleApiSourceLoggingConfigOutputReference | GoogleEventarcGoogleApiSourceLoggingConfig): any;
export declare function googleEventarcGoogleApiSourceLoggingConfigToHclTerraform(struct?: GoogleEventarcGoogleApiSourceLoggingConfigOutputReference | GoogleEventarcGoogleApiSourceLoggingConfig): any;
export declare class GoogleEventarcGoogleApiSourceLoggingConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleEventarcGoogleApiSourceLoggingConfig | undefined;
    set internalValue(value: GoogleEventarcGoogleApiSourceLoggingConfig | undefined);
    private _logSeverity?;
    get logSeverity(): string;
    set logSeverity(value: string);
    resetLogSeverity(): void;
    get logSeverityInput(): string | undefined;
}
export interface GoogleEventarcGoogleApiSourceTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_google_api_source#create GoogleEventarcGoogleApiSource#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_google_api_source#delete GoogleEventarcGoogleApiSource#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_google_api_source#update GoogleEventarcGoogleApiSource#update}
    */
    readonly update?: string;
}
export declare function googleEventarcGoogleApiSourceTimeoutsToTerraform(struct?: GoogleEventarcGoogleApiSourceTimeouts | cdktf.IResolvable): any;
export declare function googleEventarcGoogleApiSourceTimeoutsToHclTerraform(struct?: GoogleEventarcGoogleApiSourceTimeouts | cdktf.IResolvable): any;
export declare class GoogleEventarcGoogleApiSourceTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleEventarcGoogleApiSourceTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleEventarcGoogleApiSourceTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_google_api_source google_eventarc_google_api_source}
*/
export declare class GoogleEventarcGoogleApiSource extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_eventarc_google_api_source";
    /**
    * Generates CDKTF code for importing a GoogleEventarcGoogleApiSource resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleEventarcGoogleApiSource to import
    * @param importFromId The id of the existing GoogleEventarcGoogleApiSource that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_google_api_source#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleEventarcGoogleApiSource to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_google_api_source google_eventarc_google_api_source} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleEventarcGoogleApiSourceConfig
    */
    constructor(scope: Construct, id: string, config: GoogleEventarcGoogleApiSourceConfig);
    private _annotations?;
    get annotations(): {
        [key: string]: string;
    };
    set annotations(value: {
        [key: string]: string;
    });
    resetAnnotations(): void;
    get annotationsInput(): {
        [key: string]: string;
    } | undefined;
    get createTime(): string;
    private _cryptoKeyName?;
    get cryptoKeyName(): string;
    set cryptoKeyName(value: string);
    resetCryptoKeyName(): void;
    get cryptoKeyNameInput(): string | undefined;
    private _destination?;
    get destination(): string;
    set destination(value: string);
    get destinationInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _effectiveAnnotations;
    get effectiveAnnotations(): cdktf.StringMap;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    get etag(): string;
    private _googleApiSourceId?;
    get googleApiSourceId(): string;
    set googleApiSourceId(value: string);
    get googleApiSourceIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get uid(): string;
    get updateTime(): string;
    private _loggingConfig;
    get loggingConfig(): GoogleEventarcGoogleApiSourceLoggingConfigOutputReference;
    putLoggingConfig(value: GoogleEventarcGoogleApiSourceLoggingConfig): void;
    resetLoggingConfig(): void;
    get loggingConfigInput(): GoogleEventarcGoogleApiSourceLoggingConfig | undefined;
    private _timeouts;
    get timeouts(): GoogleEventarcGoogleApiSourceTimeoutsOutputReference;
    putTimeouts(value: GoogleEventarcGoogleApiSourceTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleEventarcGoogleApiSourceTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
