/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleEventarcPipelineConfig extends cdktf.TerraformMetaArguments {
    /**
    * User-defined annotations. See https://google.aip.dev/128#annotations.
    *
    * **Note**: This field is non-authoritative, and will only manage the annotations present in your configuration.
    * Please refer to the field 'effective_annotations' for all of the annotations present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#annotations GoogleEventarcPipeline#annotations}
    */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
    * Resource name of a KMS crypto key (managed by the user) used to
    * encrypt/decrypt the event data. If not set, an internal Google-owned key
    * will be used to encrypt messages. It must match the pattern
    * "projects/{project}/locations/{location}/keyRings/{keyring}/cryptoKeys/{key}".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#crypto_key_name GoogleEventarcPipeline#crypto_key_name}
    */
    readonly cryptoKeyName?: string;
    /**
    * Display name of resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#display_name GoogleEventarcPipeline#display_name}
    */
    readonly displayName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#id GoogleEventarcPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * User labels attached to the Pipeline that can be used to group
    * resources. An object containing a list of "key": value pairs. Example: {
    * "name": "wrench", "mass": "1.3kg", "count": "3" }.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#labels GoogleEventarcPipeline#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Resource ID segment making up resource 'name'. It identifies the resource within its parent collection as described in https://google.aip.dev/122.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#location GoogleEventarcPipeline#location}
    */
    readonly location: string;
    /**
    * The user-provided ID to be assigned to the Pipeline. It should match the
    * format '^[a-z]([a-z0-9-]{0,61}[a-z0-9])?$'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#pipeline_id GoogleEventarcPipeline#pipeline_id}
    */
    readonly pipelineId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#project GoogleEventarcPipeline#project}
    */
    readonly project?: string;
    /**
    * destinations block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#destinations GoogleEventarcPipeline#destinations}
    */
    readonly destinations: GoogleEventarcPipelineDestinations[] | cdktf.IResolvable;
    /**
    * input_payload_format block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#input_payload_format GoogleEventarcPipeline#input_payload_format}
    */
    readonly inputPayloadFormat?: GoogleEventarcPipelineInputPayloadFormat;
    /**
    * logging_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#logging_config GoogleEventarcPipeline#logging_config}
    */
    readonly loggingConfig?: GoogleEventarcPipelineLoggingConfig;
    /**
    * mediations block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#mediations GoogleEventarcPipeline#mediations}
    */
    readonly mediations?: GoogleEventarcPipelineMediations[] | cdktf.IResolvable;
    /**
    * retry_policy block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#retry_policy GoogleEventarcPipeline#retry_policy}
    */
    readonly retryPolicy?: GoogleEventarcPipelineRetryPolicy;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#timeouts GoogleEventarcPipeline#timeouts}
    */
    readonly timeouts?: GoogleEventarcPipelineTimeouts;
}
export interface GoogleEventarcPipelineDestinationsAuthenticationConfigGoogleOidc {
    /**
    * Audience to be used to generate the OIDC Token. The audience claim
    * identifies the recipient that the JWT is intended for. If
    * unspecified, the destination URI will be used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#audience GoogleEventarcPipeline#audience}
    */
    readonly audience?: string;
    /**
    * Service account email used to generate the OIDC Token.
    * The principal who calls this API must have
    * iam.serviceAccounts.actAs permission in the service account. See
    * https://cloud.google.com/iam/docs/understanding-service-accounts
    * for more information. Eventarc service agents must have
    * roles/roles/iam.serviceAccountTokenCreator role to allow the
    * Pipeline to create OpenID tokens for authenticated requests.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#service_account GoogleEventarcPipeline#service_account}
    */
    readonly serviceAccount: string;
}
export declare function googleEventarcPipelineDestinationsAuthenticationConfigGoogleOidcToTerraform(struct?: GoogleEventarcPipelineDestinationsAuthenticationConfigGoogleOidcOutputReference | GoogleEventarcPipelineDestinationsAuthenticationConfigGoogleOidc): any;
export declare function googleEventarcPipelineDestinationsAuthenticationConfigGoogleOidcToHclTerraform(struct?: GoogleEventarcPipelineDestinationsAuthenticationConfigGoogleOidcOutputReference | GoogleEventarcPipelineDestinationsAuthenticationConfigGoogleOidc): any;
export declare class GoogleEventarcPipelineDestinationsAuthenticationConfigGoogleOidcOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleEventarcPipelineDestinationsAuthenticationConfigGoogleOidc | undefined;
    set internalValue(value: GoogleEventarcPipelineDestinationsAuthenticationConfigGoogleOidc | undefined);
    private _audience?;
    get audience(): string;
    set audience(value: string);
    resetAudience(): void;
    get audienceInput(): string | undefined;
    private _serviceAccount?;
    get serviceAccount(): string;
    set serviceAccount(value: string);
    get serviceAccountInput(): string | undefined;
}
export interface GoogleEventarcPipelineDestinationsAuthenticationConfigOauthToken {
    /**
    * OAuth scope to be used for generating OAuth access token. If not
    * specified, "https://www.googleapis.com/auth/cloud-platform" will be
    * used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#scope GoogleEventarcPipeline#scope}
    */
    readonly scope?: string;
    /**
    * Service account email used to generate the [OAuth
    * token](https://developers.google.com/identity/protocols/OAuth2).
    * The principal who calls this API must have
    * iam.serviceAccounts.actAs permission in the service account. See
    * https://cloud.google.com/iam/docs/understanding-service-accounts
    * for more information. Eventarc service agents must have
    * roles/roles/iam.serviceAccountTokenCreator role to allow Pipeline
    * to create OAuth2 tokens for authenticated requests.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#service_account GoogleEventarcPipeline#service_account}
    */
    readonly serviceAccount: string;
}
export declare function googleEventarcPipelineDestinationsAuthenticationConfigOauthTokenToTerraform(struct?: GoogleEventarcPipelineDestinationsAuthenticationConfigOauthTokenOutputReference | GoogleEventarcPipelineDestinationsAuthenticationConfigOauthToken): any;
export declare function googleEventarcPipelineDestinationsAuthenticationConfigOauthTokenToHclTerraform(struct?: GoogleEventarcPipelineDestinationsAuthenticationConfigOauthTokenOutputReference | GoogleEventarcPipelineDestinationsAuthenticationConfigOauthToken): any;
export declare class GoogleEventarcPipelineDestinationsAuthenticationConfigOauthTokenOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleEventarcPipelineDestinationsAuthenticationConfigOauthToken | undefined;
    set internalValue(value: GoogleEventarcPipelineDestinationsAuthenticationConfigOauthToken | undefined);
    private _scope?;
    get scope(): string;
    set scope(value: string);
    resetScope(): void;
    get scopeInput(): string | undefined;
    private _serviceAccount?;
    get serviceAccount(): string;
    set serviceAccount(value: string);
    get serviceAccountInput(): string | undefined;
}
export interface GoogleEventarcPipelineDestinationsAuthenticationConfig {
    /**
    * google_oidc block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#google_oidc GoogleEventarcPipeline#google_oidc}
    */
    readonly googleOidc?: GoogleEventarcPipelineDestinationsAuthenticationConfigGoogleOidc;
    /**
    * oauth_token block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#oauth_token GoogleEventarcPipeline#oauth_token}
    */
    readonly oauthToken?: GoogleEventarcPipelineDestinationsAuthenticationConfigOauthToken;
}
export declare function googleEventarcPipelineDestinationsAuthenticationConfigToTerraform(struct?: GoogleEventarcPipelineDestinationsAuthenticationConfigOutputReference | GoogleEventarcPipelineDestinationsAuthenticationConfig): any;
export declare function googleEventarcPipelineDestinationsAuthenticationConfigToHclTerraform(struct?: GoogleEventarcPipelineDestinationsAuthenticationConfigOutputReference | GoogleEventarcPipelineDestinationsAuthenticationConfig): any;
export declare class GoogleEventarcPipelineDestinationsAuthenticationConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleEventarcPipelineDestinationsAuthenticationConfig | undefined;
    set internalValue(value: GoogleEventarcPipelineDestinationsAuthenticationConfig | undefined);
    private _googleOidc;
    get googleOidc(): GoogleEventarcPipelineDestinationsAuthenticationConfigGoogleOidcOutputReference;
    putGoogleOidc(value: GoogleEventarcPipelineDestinationsAuthenticationConfigGoogleOidc): void;
    resetGoogleOidc(): void;
    get googleOidcInput(): GoogleEventarcPipelineDestinationsAuthenticationConfigGoogleOidc | undefined;
    private _oauthToken;
    get oauthToken(): GoogleEventarcPipelineDestinationsAuthenticationConfigOauthTokenOutputReference;
    putOauthToken(value: GoogleEventarcPipelineDestinationsAuthenticationConfigOauthToken): void;
    resetOauthToken(): void;
    get oauthTokenInput(): GoogleEventarcPipelineDestinationsAuthenticationConfigOauthToken | undefined;
}
export interface GoogleEventarcPipelineDestinationsHttpEndpoint {
    /**
    * The CEL expression used to modify how the destination-bound HTTP
    * request is constructed.
    *
    * If a binding expression is not specified here, the message
    * is treated as a CloudEvent and is mapped to the HTTP request according
    * to the CloudEvent HTTP Protocol Binding Binary Content Mode
    * (https://github.com/cloudevents/spec/blob/main/cloudevents/bindings/http-protocol-binding.md#31-binary-content-mode).
    * In this representation, all fields except the 'data' and
    * 'datacontenttype' field on the message are mapped to HTTP request
    * headers with a prefix of 'ce-'.
    *
    * To construct the HTTP request payload and the value of the content-type
    * HTTP header, the payload format is defined as follows:
    * 1) Use the output_payload_format_type on the Pipeline.Destination if it
    * is set, else:
    * 2) Use the input_payload_format_type on the Pipeline if it is set,
    * else:
    * 3) Treat the payload as opaque binary data.
    *
    * The 'data' field of the message is converted to the payload format or
    * left as-is for case 3) and then attached as the payload of the HTTP
    * request. The 'content-type' header on the HTTP request is set to the
    * payload format type or left empty for case 3). However, if a mediation
    * has updated the 'datacontenttype' field on the message so that it is
    * not the same as the payload format type but it is still a prefix of the
    * payload format type, then the 'content-type' header on the HTTP request
    * is set to this 'datacontenttype' value. For example, if the
    * 'datacontenttype' is "application/json" and the payload format type is
    * "application/json; charset=utf-8", then the 'content-type' header on
    * the HTTP request is set to "application/json; charset=utf-8".
    *
    * If a non-empty binding expression is specified then this expression is
    * used to modify the default CloudEvent HTTP Protocol Binding Binary
    * Content representation.
    * The result of the CEL expression must be a map of key/value pairs
    * which is used as follows:
    * - If a map named 'headers' exists on the result of the expression,
    * then its key/value pairs are directly mapped to the HTTP request
    * headers. The headers values are constructed from the corresponding
    * value type's canonical representation. If the 'headers' field doesn't
    * exist then the resulting HTTP request will be the headers of the
    * CloudEvent HTTP Binding Binary Content Mode representation of the final
    * message. Note: If the specified binding expression, has updated the
    * 'datacontenttype' field on the message so that it is not the same as
    * the payload format type but it is still a prefix of the payload format
    * type, then the 'content-type' header in the 'headers' map is set to
    * this 'datacontenttype' value.
    * - If a field named 'body' exists on the result of the expression then
    * its value is directly mapped to the body of the request. If the value
    * of the 'body' field is of type bytes or string then it is used for
    * the HTTP request body as-is, with no conversion. If the body field is
    * of any other type then it is converted to a JSON string. If the body
    * field does not exist then the resulting payload of the HTTP request
    * will be data value of the CloudEvent HTTP Binding Binary Content Mode
    * representation of the final message as described earlier.
    * - Any other fields in the resulting expression will be ignored.
    *
    * The CEL expression may access the incoming CloudEvent message in its
    * definition, as follows:
    * - The 'data' field of the incoming CloudEvent message can be accessed
    * using the 'message.data' value. Subfields of 'message.data' may also be
    * accessed if an input_payload_format has been specified on the Pipeline.
    * - Each attribute of the incoming CloudEvent message can be accessed
    * using the 'message.' value, where  is replaced with the
    * name of the attribute.
    * - Existing headers can be accessed in the CEL expression using the
    * 'headers' variable. The 'headers' variable defines a map of key/value
    * pairs corresponding to the HTTP headers of the CloudEvent HTTP Binding
    * Binary Content Mode representation of the final message as described
    * earlier. For example, the following CEL expression can be used to
    * construct an HTTP request by adding an additional header to the HTTP
    * headers of the CloudEvent HTTP Binding Binary Content Mode
    * representation of the final message and by overwriting the body of the
    * request:
    *
    * ```
    * {
    * "headers": headers.merge({"new-header-key": "new-header-value"}),
    * "body": "new-body"
    * }
    * ```
    * - The default binding for the message payload can be accessed using the
    * 'body' variable. It conatins a string representation of the message
    * payload in the format specified by the 'output_payload_format' field.
    * If the 'input_payload_format' field is not set, the 'body'
    * variable contains the same message payload bytes that were published.
    *
    * Additionally, the following CEL extension functions are provided for
    * use in this CEL expression:
    * - toBase64Url:
    * map.toBase64Url() -> string
    * - Converts a CelValue to a base64url encoded string
    * - toJsonString: map.toJsonString() -> string
    * - Converts a CelValue to a JSON string
    * - merge:
    * map1.merge(map2) -> map3
    * - Merges the passed CEL map with the existing CEL map the
    * function is applied to.
    * - If the same key exists in both maps, if the key's value is type
    * map both maps are merged else the value from the passed map is
    * used.
    * - denormalize:
    * map.denormalize() -> map
    * - Denormalizes a CEL map such that every value of type map or key
    * in the map is expanded to return a single level map.
    * - The resulting keys are "." separated indices of the map keys.
    * - For example:
    * {
    * "a": 1,
    * "b": {
    * "c": 2,
    * "d": 3
    * }
    * "e": [4, 5]
    * }
    * .denormalize()
    * -> {
    * "a": 1,
    * "b.c": 2,
    * "b.d": 3,
    * "e.0": 4,
    * "e.1": 5
    * }
    * - setField:
    * map.setField(key, value) -> message
    * - Sets the field of the message with the given key to the
    * given value.
    * - If the field is not present it will be added.
    * - If the field is present it will be overwritten.
    * - The key can be a dot separated path to set a field in a nested
    * message.
    * - Key must be of type string.
    * - Value may be any valid type.
    * - removeFields:
    * map.removeFields([key1, key2, ...]) -> message
    * - Removes the fields of the map with the given keys.
    * - The keys can be a dot separated path to remove a field in a
    * nested message.
    * - If a key is not found it will be ignored.
    * - Keys must be of type string.
    * - toMap:
    * [map1, map2, ...].toMap() -> map
    * - Converts a CEL list of CEL maps to a single CEL map
    * - toCloudEventJsonWithPayloadFormat:
    * message.toCloudEventJsonWithPayloadFormat() -> map
    * - Converts a message to the corresponding structure of JSON
    * format for CloudEvents.
    * - It converts 'data' to destination payload format
    * specified in 'output_payload_format'. If 'output_payload_format' is
    * not set, the data will remain unchanged.
    * - It also sets the corresponding datacontenttype of
    * the CloudEvent, as indicated by
    * 'output_payload_format'. If no
    * 'output_payload_format' is set it will use the value of the
    * "datacontenttype" attribute on the CloudEvent if present, else
    * remove "datacontenttype" attribute.
    * - This function expects that the content of the message will
    * adhere to the standard CloudEvent format. If it doesn't then this
    * function will fail.
    * - The result is a CEL map that corresponds to the JSON
    * representation of the CloudEvent. To convert that data to a JSON
    * string it can be chained with the toJsonString function.
    *
    * The Pipeline expects that the message it receives adheres to the
    * standard CloudEvent format. If it doesn't then the outgoing message
    * request may fail with a persistent error.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#message_binding_template GoogleEventarcPipeline#message_binding_template}
    */
    readonly messageBindingTemplate?: string;
    /**
    * The URI of the HTTP enpdoint.
    *
    * The value must be a RFC2396 URI string.
    * Examples: 'https://svc.us-central1.p.local:8080/route'.
    * Only the HTTPS protocol is supported.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#uri GoogleEventarcPipeline#uri}
    */
    readonly uri: string;
}
export declare function googleEventarcPipelineDestinationsHttpEndpointToTerraform(struct?: GoogleEventarcPipelineDestinationsHttpEndpointOutputReference | GoogleEventarcPipelineDestinationsHttpEndpoint): any;
export declare function googleEventarcPipelineDestinationsHttpEndpointToHclTerraform(struct?: GoogleEventarcPipelineDestinationsHttpEndpointOutputReference | GoogleEventarcPipelineDestinationsHttpEndpoint): any;
export declare class GoogleEventarcPipelineDestinationsHttpEndpointOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleEventarcPipelineDestinationsHttpEndpoint | undefined;
    set internalValue(value: GoogleEventarcPipelineDestinationsHttpEndpoint | undefined);
    private _messageBindingTemplate?;
    get messageBindingTemplate(): string;
    set messageBindingTemplate(value: string);
    resetMessageBindingTemplate(): void;
    get messageBindingTemplateInput(): string | undefined;
    private _uri?;
    get uri(): string;
    set uri(value: string);
    get uriInput(): string | undefined;
}
export interface GoogleEventarcPipelineDestinationsNetworkConfig {
    /**
    * Name of the NetworkAttachment that allows access to the consumer VPC.
    * Format:
    * 'projects/{PROJECT_ID}/regions/{REGION}/networkAttachments/{NETWORK_ATTACHMENT_NAME}'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#network_attachment GoogleEventarcPipeline#network_attachment}
    */
    readonly networkAttachment: string;
}
export declare function googleEventarcPipelineDestinationsNetworkConfigToTerraform(struct?: GoogleEventarcPipelineDestinationsNetworkConfigOutputReference | GoogleEventarcPipelineDestinationsNetworkConfig): any;
export declare function googleEventarcPipelineDestinationsNetworkConfigToHclTerraform(struct?: GoogleEventarcPipelineDestinationsNetworkConfigOutputReference | GoogleEventarcPipelineDestinationsNetworkConfig): any;
export declare class GoogleEventarcPipelineDestinationsNetworkConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleEventarcPipelineDestinationsNetworkConfig | undefined;
    set internalValue(value: GoogleEventarcPipelineDestinationsNetworkConfig | undefined);
    private _networkAttachment?;
    get networkAttachment(): string;
    set networkAttachment(value: string);
    get networkAttachmentInput(): string | undefined;
}
export interface GoogleEventarcPipelineDestinationsOutputPayloadFormatAvro {
    /**
    * The entire schema definition is stored in this field.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#schema_definition GoogleEventarcPipeline#schema_definition}
    */
    readonly schemaDefinition?: string;
}
export declare function googleEventarcPipelineDestinationsOutputPayloadFormatAvroToTerraform(struct?: GoogleEventarcPipelineDestinationsOutputPayloadFormatAvroOutputReference | GoogleEventarcPipelineDestinationsOutputPayloadFormatAvro): any;
export declare function googleEventarcPipelineDestinationsOutputPayloadFormatAvroToHclTerraform(struct?: GoogleEventarcPipelineDestinationsOutputPayloadFormatAvroOutputReference | GoogleEventarcPipelineDestinationsOutputPayloadFormatAvro): any;
export declare class GoogleEventarcPipelineDestinationsOutputPayloadFormatAvroOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleEventarcPipelineDestinationsOutputPayloadFormatAvro | undefined;
    set internalValue(value: GoogleEventarcPipelineDestinationsOutputPayloadFormatAvro | undefined);
    private _schemaDefinition?;
    get schemaDefinition(): string;
    set schemaDefinition(value: string);
    resetSchemaDefinition(): void;
    get schemaDefinitionInput(): string | undefined;
}
export interface GoogleEventarcPipelineDestinationsOutputPayloadFormatJson {
}
export declare function googleEventarcPipelineDestinationsOutputPayloadFormatJsonToTerraform(struct?: GoogleEventarcPipelineDestinationsOutputPayloadFormatJsonOutputReference | GoogleEventarcPipelineDestinationsOutputPayloadFormatJson): any;
export declare function googleEventarcPipelineDestinationsOutputPayloadFormatJsonToHclTerraform(struct?: GoogleEventarcPipelineDestinationsOutputPayloadFormatJsonOutputReference | GoogleEventarcPipelineDestinationsOutputPayloadFormatJson): any;
export declare class GoogleEventarcPipelineDestinationsOutputPayloadFormatJsonOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleEventarcPipelineDestinationsOutputPayloadFormatJson | undefined;
    set internalValue(value: GoogleEventarcPipelineDestinationsOutputPayloadFormatJson | undefined);
}
export interface GoogleEventarcPipelineDestinationsOutputPayloadFormatProtobuf {
    /**
    * The entire schema definition is stored in this field.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#schema_definition GoogleEventarcPipeline#schema_definition}
    */
    readonly schemaDefinition?: string;
}
export declare function googleEventarcPipelineDestinationsOutputPayloadFormatProtobufToTerraform(struct?: GoogleEventarcPipelineDestinationsOutputPayloadFormatProtobufOutputReference | GoogleEventarcPipelineDestinationsOutputPayloadFormatProtobuf): any;
export declare function googleEventarcPipelineDestinationsOutputPayloadFormatProtobufToHclTerraform(struct?: GoogleEventarcPipelineDestinationsOutputPayloadFormatProtobufOutputReference | GoogleEventarcPipelineDestinationsOutputPayloadFormatProtobuf): any;
export declare class GoogleEventarcPipelineDestinationsOutputPayloadFormatProtobufOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleEventarcPipelineDestinationsOutputPayloadFormatProtobuf | undefined;
    set internalValue(value: GoogleEventarcPipelineDestinationsOutputPayloadFormatProtobuf | undefined);
    private _schemaDefinition?;
    get schemaDefinition(): string;
    set schemaDefinition(value: string);
    resetSchemaDefinition(): void;
    get schemaDefinitionInput(): string | undefined;
}
export interface GoogleEventarcPipelineDestinationsOutputPayloadFormat {
    /**
    * avro block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#avro GoogleEventarcPipeline#avro}
    */
    readonly avro?: GoogleEventarcPipelineDestinationsOutputPayloadFormatAvro;
    /**
    * json block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#json GoogleEventarcPipeline#json}
    */
    readonly json?: GoogleEventarcPipelineDestinationsOutputPayloadFormatJson;
    /**
    * protobuf block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#protobuf GoogleEventarcPipeline#protobuf}
    */
    readonly protobuf?: GoogleEventarcPipelineDestinationsOutputPayloadFormatProtobuf;
}
export declare function googleEventarcPipelineDestinationsOutputPayloadFormatToTerraform(struct?: GoogleEventarcPipelineDestinationsOutputPayloadFormatOutputReference | GoogleEventarcPipelineDestinationsOutputPayloadFormat): any;
export declare function googleEventarcPipelineDestinationsOutputPayloadFormatToHclTerraform(struct?: GoogleEventarcPipelineDestinationsOutputPayloadFormatOutputReference | GoogleEventarcPipelineDestinationsOutputPayloadFormat): any;
export declare class GoogleEventarcPipelineDestinationsOutputPayloadFormatOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleEventarcPipelineDestinationsOutputPayloadFormat | undefined;
    set internalValue(value: GoogleEventarcPipelineDestinationsOutputPayloadFormat | undefined);
    private _avro;
    get avro(): GoogleEventarcPipelineDestinationsOutputPayloadFormatAvroOutputReference;
    putAvro(value: GoogleEventarcPipelineDestinationsOutputPayloadFormatAvro): void;
    resetAvro(): void;
    get avroInput(): GoogleEventarcPipelineDestinationsOutputPayloadFormatAvro | undefined;
    private _json;
    get json(): GoogleEventarcPipelineDestinationsOutputPayloadFormatJsonOutputReference;
    putJson(value: GoogleEventarcPipelineDestinationsOutputPayloadFormatJson): void;
    resetJson(): void;
    get jsonInput(): GoogleEventarcPipelineDestinationsOutputPayloadFormatJson | undefined;
    private _protobuf;
    get protobuf(): GoogleEventarcPipelineDestinationsOutputPayloadFormatProtobufOutputReference;
    putProtobuf(value: GoogleEventarcPipelineDestinationsOutputPayloadFormatProtobuf): void;
    resetProtobuf(): void;
    get protobufInput(): GoogleEventarcPipelineDestinationsOutputPayloadFormatProtobuf | undefined;
}
export interface GoogleEventarcPipelineDestinations {
    /**
    * The resource name of the Message Bus to which events should be
    * published. The Message Bus resource should exist in the same project as
    * the Pipeline. Format:
    * 'projects/{project}/locations/{location}/messageBuses/{message_bus}'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#message_bus GoogleEventarcPipeline#message_bus}
    */
    readonly messageBus?: string;
    /**
    * The resource name of the Pub/Sub topic to which events should be
    * published. Format:
    * 'projects/{project}/locations/{location}/topics/{topic}'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#topic GoogleEventarcPipeline#topic}
    */
    readonly topic?: string;
    /**
    * The resource name of the Workflow whose Executions are triggered by
    * the events. The Workflow resource should be deployed in the same
    * project as the Pipeline. Format:
    * 'projects/{project}/locations/{location}/workflows/{workflow}'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#workflow GoogleEventarcPipeline#workflow}
    */
    readonly workflow?: string;
    /**
    * authentication_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#authentication_config GoogleEventarcPipeline#authentication_config}
    */
    readonly authenticationConfig?: GoogleEventarcPipelineDestinationsAuthenticationConfig;
    /**
    * http_endpoint block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#http_endpoint GoogleEventarcPipeline#http_endpoint}
    */
    readonly httpEndpoint?: GoogleEventarcPipelineDestinationsHttpEndpoint;
    /**
    * network_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#network_config GoogleEventarcPipeline#network_config}
    */
    readonly networkConfig?: GoogleEventarcPipelineDestinationsNetworkConfig;
    /**
    * output_payload_format block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#output_payload_format GoogleEventarcPipeline#output_payload_format}
    */
    readonly outputPayloadFormat?: GoogleEventarcPipelineDestinationsOutputPayloadFormat;
}
export declare function googleEventarcPipelineDestinationsToTerraform(struct?: GoogleEventarcPipelineDestinations | cdktf.IResolvable): any;
export declare function googleEventarcPipelineDestinationsToHclTerraform(struct?: GoogleEventarcPipelineDestinations | cdktf.IResolvable): any;
export declare class GoogleEventarcPipelineDestinationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleEventarcPipelineDestinations | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleEventarcPipelineDestinations | cdktf.IResolvable | undefined);
    private _messageBus?;
    get messageBus(): string;
    set messageBus(value: string);
    resetMessageBus(): void;
    get messageBusInput(): string | undefined;
    private _topic?;
    get topic(): string;
    set topic(value: string);
    resetTopic(): void;
    get topicInput(): string | undefined;
    private _workflow?;
    get workflow(): string;
    set workflow(value: string);
    resetWorkflow(): void;
    get workflowInput(): string | undefined;
    private _authenticationConfig;
    get authenticationConfig(): GoogleEventarcPipelineDestinationsAuthenticationConfigOutputReference;
    putAuthenticationConfig(value: GoogleEventarcPipelineDestinationsAuthenticationConfig): void;
    resetAuthenticationConfig(): void;
    get authenticationConfigInput(): GoogleEventarcPipelineDestinationsAuthenticationConfig | undefined;
    private _httpEndpoint;
    get httpEndpoint(): GoogleEventarcPipelineDestinationsHttpEndpointOutputReference;
    putHttpEndpoint(value: GoogleEventarcPipelineDestinationsHttpEndpoint): void;
    resetHttpEndpoint(): void;
    get httpEndpointInput(): GoogleEventarcPipelineDestinationsHttpEndpoint | undefined;
    private _networkConfig;
    get networkConfig(): GoogleEventarcPipelineDestinationsNetworkConfigOutputReference;
    putNetworkConfig(value: GoogleEventarcPipelineDestinationsNetworkConfig): void;
    resetNetworkConfig(): void;
    get networkConfigInput(): GoogleEventarcPipelineDestinationsNetworkConfig | undefined;
    private _outputPayloadFormat;
    get outputPayloadFormat(): GoogleEventarcPipelineDestinationsOutputPayloadFormatOutputReference;
    putOutputPayloadFormat(value: GoogleEventarcPipelineDestinationsOutputPayloadFormat): void;
    resetOutputPayloadFormat(): void;
    get outputPayloadFormatInput(): GoogleEventarcPipelineDestinationsOutputPayloadFormat | undefined;
}
export declare class GoogleEventarcPipelineDestinationsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleEventarcPipelineDestinations[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleEventarcPipelineDestinationsOutputReference;
}
export interface GoogleEventarcPipelineInputPayloadFormatAvro {
    /**
    * The entire schema definition is stored in this field.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#schema_definition GoogleEventarcPipeline#schema_definition}
    */
    readonly schemaDefinition?: string;
}
export declare function googleEventarcPipelineInputPayloadFormatAvroToTerraform(struct?: GoogleEventarcPipelineInputPayloadFormatAvroOutputReference | GoogleEventarcPipelineInputPayloadFormatAvro): any;
export declare function googleEventarcPipelineInputPayloadFormatAvroToHclTerraform(struct?: GoogleEventarcPipelineInputPayloadFormatAvroOutputReference | GoogleEventarcPipelineInputPayloadFormatAvro): any;
export declare class GoogleEventarcPipelineInputPayloadFormatAvroOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleEventarcPipelineInputPayloadFormatAvro | undefined;
    set internalValue(value: GoogleEventarcPipelineInputPayloadFormatAvro | undefined);
    private _schemaDefinition?;
    get schemaDefinition(): string;
    set schemaDefinition(value: string);
    resetSchemaDefinition(): void;
    get schemaDefinitionInput(): string | undefined;
}
export interface GoogleEventarcPipelineInputPayloadFormatJson {
}
export declare function googleEventarcPipelineInputPayloadFormatJsonToTerraform(struct?: GoogleEventarcPipelineInputPayloadFormatJsonOutputReference | GoogleEventarcPipelineInputPayloadFormatJson): any;
export declare function googleEventarcPipelineInputPayloadFormatJsonToHclTerraform(struct?: GoogleEventarcPipelineInputPayloadFormatJsonOutputReference | GoogleEventarcPipelineInputPayloadFormatJson): any;
export declare class GoogleEventarcPipelineInputPayloadFormatJsonOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleEventarcPipelineInputPayloadFormatJson | undefined;
    set internalValue(value: GoogleEventarcPipelineInputPayloadFormatJson | undefined);
}
export interface GoogleEventarcPipelineInputPayloadFormatProtobuf {
    /**
    * The entire schema definition is stored in this field.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#schema_definition GoogleEventarcPipeline#schema_definition}
    */
    readonly schemaDefinition?: string;
}
export declare function googleEventarcPipelineInputPayloadFormatProtobufToTerraform(struct?: GoogleEventarcPipelineInputPayloadFormatProtobufOutputReference | GoogleEventarcPipelineInputPayloadFormatProtobuf): any;
export declare function googleEventarcPipelineInputPayloadFormatProtobufToHclTerraform(struct?: GoogleEventarcPipelineInputPayloadFormatProtobufOutputReference | GoogleEventarcPipelineInputPayloadFormatProtobuf): any;
export declare class GoogleEventarcPipelineInputPayloadFormatProtobufOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleEventarcPipelineInputPayloadFormatProtobuf | undefined;
    set internalValue(value: GoogleEventarcPipelineInputPayloadFormatProtobuf | undefined);
    private _schemaDefinition?;
    get schemaDefinition(): string;
    set schemaDefinition(value: string);
    resetSchemaDefinition(): void;
    get schemaDefinitionInput(): string | undefined;
}
export interface GoogleEventarcPipelineInputPayloadFormat {
    /**
    * avro block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#avro GoogleEventarcPipeline#avro}
    */
    readonly avro?: GoogleEventarcPipelineInputPayloadFormatAvro;
    /**
    * json block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#json GoogleEventarcPipeline#json}
    */
    readonly json?: GoogleEventarcPipelineInputPayloadFormatJson;
    /**
    * protobuf block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#protobuf GoogleEventarcPipeline#protobuf}
    */
    readonly protobuf?: GoogleEventarcPipelineInputPayloadFormatProtobuf;
}
export declare function googleEventarcPipelineInputPayloadFormatToTerraform(struct?: GoogleEventarcPipelineInputPayloadFormatOutputReference | GoogleEventarcPipelineInputPayloadFormat): any;
export declare function googleEventarcPipelineInputPayloadFormatToHclTerraform(struct?: GoogleEventarcPipelineInputPayloadFormatOutputReference | GoogleEventarcPipelineInputPayloadFormat): any;
export declare class GoogleEventarcPipelineInputPayloadFormatOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleEventarcPipelineInputPayloadFormat | undefined;
    set internalValue(value: GoogleEventarcPipelineInputPayloadFormat | undefined);
    private _avro;
    get avro(): GoogleEventarcPipelineInputPayloadFormatAvroOutputReference;
    putAvro(value: GoogleEventarcPipelineInputPayloadFormatAvro): void;
    resetAvro(): void;
    get avroInput(): GoogleEventarcPipelineInputPayloadFormatAvro | undefined;
    private _json;
    get json(): GoogleEventarcPipelineInputPayloadFormatJsonOutputReference;
    putJson(value: GoogleEventarcPipelineInputPayloadFormatJson): void;
    resetJson(): void;
    get jsonInput(): GoogleEventarcPipelineInputPayloadFormatJson | undefined;
    private _protobuf;
    get protobuf(): GoogleEventarcPipelineInputPayloadFormatProtobufOutputReference;
    putProtobuf(value: GoogleEventarcPipelineInputPayloadFormatProtobuf): void;
    resetProtobuf(): void;
    get protobufInput(): GoogleEventarcPipelineInputPayloadFormatProtobuf | undefined;
}
export interface GoogleEventarcPipelineLoggingConfig {
    /**
    * The minimum severity of logs that will be sent to Stackdriver/Platform
    * Telemetry. Logs at severitiy ≥ this value will be sent, unless it is NONE. Possible values: ["NONE", "DEBUG", "INFO", "NOTICE", "WARNING", "ERROR", "CRITICAL", "ALERT", "EMERGENCY"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#log_severity GoogleEventarcPipeline#log_severity}
    */
    readonly logSeverity?: string;
}
export declare function googleEventarcPipelineLoggingConfigToTerraform(struct?: GoogleEventarcPipelineLoggingConfigOutputReference | GoogleEventarcPipelineLoggingConfig): any;
export declare function googleEventarcPipelineLoggingConfigToHclTerraform(struct?: GoogleEventarcPipelineLoggingConfigOutputReference | GoogleEventarcPipelineLoggingConfig): any;
export declare class GoogleEventarcPipelineLoggingConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleEventarcPipelineLoggingConfig | undefined;
    set internalValue(value: GoogleEventarcPipelineLoggingConfig | undefined);
    private _logSeverity?;
    get logSeverity(): string;
    set logSeverity(value: string);
    resetLogSeverity(): void;
    get logSeverityInput(): string | undefined;
}
export interface GoogleEventarcPipelineMediationsTransformation {
    /**
    * The CEL expression template to apply to transform messages.
    * The following CEL extension functions are provided for
    * use in this CEL expression:
    * - merge:
    * map1.merge(map2) -> map3
    * - Merges the passed CEL map with the existing CEL map the
    * function is applied to.
    * - If the same key exists in both maps, if the key's value is type
    * map both maps are merged else the value from the passed map is
    * used.
    * - denormalize:
    * map.denormalize() -> map
    * - Denormalizes a CEL map such that every value of type map or key
    * in the map is expanded to return a single level map.
    * - The resulting keys are "." separated indices of the map keys.
    * - For example:
    * {
    * "a": 1,
    * "b": {
    * "c": 2,
    * "d": 3
    * }
    * "e": [4, 5]
    * }
    * .denormalize()
    * -> {
    * "a": 1,
    * "b.c": 2,
    * "b.d": 3,
    * "e.0": 4,
    * "e.1": 5
    * }
    * - setField:
    * map.setField(key, value) -> message
    * - Sets the field of the message with the given key to the
    * given value.
    * - If the field is not present it will be added.
    * - If the field is present it will be overwritten.
    * - The key can be a dot separated path to set a field in a nested
    * message.
    * - Key must be of type string.
    * - Value may be any valid type.
    * - removeFields:
    * map.removeFields([key1, key2, ...]) -> message
    * - Removes the fields of the map with the given keys.
    * - The keys can be a dot separated path to remove a field in a
    * nested message.
    * - If a key is not found it will be ignored.
    * - Keys must be of type string.
    * - toMap:
    * [map1, map2, ...].toMap() -> map
    * - Converts a CEL list of CEL maps to a single CEL map
    * - toDestinationPayloadFormat():
    * message.data.toDestinationPayloadFormat() -> string or bytes
    * - Converts the message data to the destination payload format
    * specified in Pipeline.Destination.output_payload_format
    * - This function is meant to be applied to the message.data field.
    * - If the destination payload format is not set, the function will
    * return the message data unchanged.
    * - toCloudEventJsonWithPayloadFormat:
    * message.toCloudEventJsonWithPayloadFormat() -> map
    * - Converts a message to the corresponding structure of JSON
    * format for CloudEvents
    * - This function applies toDestinationPayloadFormat() to the
    * message data. It also sets the corresponding datacontenttype of
    * the CloudEvent, as indicated by
    * Pipeline.Destination.output_payload_format. If no
    * output_payload_format is set it will use the existing
    * datacontenttype on the CloudEvent if present, else leave
    * datacontenttype absent.
    * - This function expects that the content of the message will
    * adhere to the standard CloudEvent format. If it doesn't then this
    * function will fail.
    * - The result is a CEL map that corresponds to the JSON
    * representation of the CloudEvent. To convert that data to a JSON
    * string it can be chained with the toJsonString function.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#transformation_template GoogleEventarcPipeline#transformation_template}
    */
    readonly transformationTemplate?: string;
}
export declare function googleEventarcPipelineMediationsTransformationToTerraform(struct?: GoogleEventarcPipelineMediationsTransformationOutputReference | GoogleEventarcPipelineMediationsTransformation): any;
export declare function googleEventarcPipelineMediationsTransformationToHclTerraform(struct?: GoogleEventarcPipelineMediationsTransformationOutputReference | GoogleEventarcPipelineMediationsTransformation): any;
export declare class GoogleEventarcPipelineMediationsTransformationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleEventarcPipelineMediationsTransformation | undefined;
    set internalValue(value: GoogleEventarcPipelineMediationsTransformation | undefined);
    private _transformationTemplate?;
    get transformationTemplate(): string;
    set transformationTemplate(value: string);
    resetTransformationTemplate(): void;
    get transformationTemplateInput(): string | undefined;
}
export interface GoogleEventarcPipelineMediations {
    /**
    * transformation block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#transformation GoogleEventarcPipeline#transformation}
    */
    readonly transformation?: GoogleEventarcPipelineMediationsTransformation;
}
export declare function googleEventarcPipelineMediationsToTerraform(struct?: GoogleEventarcPipelineMediations | cdktf.IResolvable): any;
export declare function googleEventarcPipelineMediationsToHclTerraform(struct?: GoogleEventarcPipelineMediations | cdktf.IResolvable): any;
export declare class GoogleEventarcPipelineMediationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleEventarcPipelineMediations | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleEventarcPipelineMediations | cdktf.IResolvable | undefined);
    private _transformation;
    get transformation(): GoogleEventarcPipelineMediationsTransformationOutputReference;
    putTransformation(value: GoogleEventarcPipelineMediationsTransformation): void;
    resetTransformation(): void;
    get transformationInput(): GoogleEventarcPipelineMediationsTransformation | undefined;
}
export declare class GoogleEventarcPipelineMediationsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleEventarcPipelineMediations[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleEventarcPipelineMediationsOutputReference;
}
export interface GoogleEventarcPipelineRetryPolicy {
    /**
    * The maximum number of delivery attempts for any message. The value must
    * be between 1 and 100.
    * The default value for this field is 5.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#max_attempts GoogleEventarcPipeline#max_attempts}
    */
    readonly maxAttempts?: number;
    /**
    * The maximum amount of seconds to wait between retry attempts. The value
    * must be between 1 and 600.
    * The default value for this field is 60.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#max_retry_delay GoogleEventarcPipeline#max_retry_delay}
    */
    readonly maxRetryDelay?: string;
    /**
    * The minimum amount of seconds to wait between retry attempts. The value
    * must be between 1 and 600.
    * The default value for this field is 5.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#min_retry_delay GoogleEventarcPipeline#min_retry_delay}
    */
    readonly minRetryDelay?: string;
}
export declare function googleEventarcPipelineRetryPolicyToTerraform(struct?: GoogleEventarcPipelineRetryPolicyOutputReference | GoogleEventarcPipelineRetryPolicy): any;
export declare function googleEventarcPipelineRetryPolicyToHclTerraform(struct?: GoogleEventarcPipelineRetryPolicyOutputReference | GoogleEventarcPipelineRetryPolicy): any;
export declare class GoogleEventarcPipelineRetryPolicyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleEventarcPipelineRetryPolicy | undefined;
    set internalValue(value: GoogleEventarcPipelineRetryPolicy | undefined);
    private _maxAttempts?;
    get maxAttempts(): number;
    set maxAttempts(value: number);
    resetMaxAttempts(): void;
    get maxAttemptsInput(): number | undefined;
    private _maxRetryDelay?;
    get maxRetryDelay(): string;
    set maxRetryDelay(value: string);
    resetMaxRetryDelay(): void;
    get maxRetryDelayInput(): string | undefined;
    private _minRetryDelay?;
    get minRetryDelay(): string;
    set minRetryDelay(value: string);
    resetMinRetryDelay(): void;
    get minRetryDelayInput(): string | undefined;
}
export interface GoogleEventarcPipelineTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#create GoogleEventarcPipeline#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#delete GoogleEventarcPipeline#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#update GoogleEventarcPipeline#update}
    */
    readonly update?: string;
}
export declare function googleEventarcPipelineTimeoutsToTerraform(struct?: GoogleEventarcPipelineTimeouts | cdktf.IResolvable): any;
export declare function googleEventarcPipelineTimeoutsToHclTerraform(struct?: GoogleEventarcPipelineTimeouts | cdktf.IResolvable): any;
export declare class GoogleEventarcPipelineTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleEventarcPipelineTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleEventarcPipelineTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline google_eventarc_pipeline}
*/
export declare class GoogleEventarcPipeline extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_eventarc_pipeline";
    /**
    * Generates CDKTF code for importing a GoogleEventarcPipeline resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleEventarcPipeline to import
    * @param importFromId The id of the existing GoogleEventarcPipeline that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleEventarcPipeline to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_eventarc_pipeline google_eventarc_pipeline} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleEventarcPipelineConfig
    */
    constructor(scope: Construct, id: string, config: GoogleEventarcPipelineConfig);
    private _annotations?;
    get annotations(): {
        [key: string]: string;
    };
    set annotations(value: {
        [key: string]: string;
    });
    resetAnnotations(): void;
    get annotationsInput(): {
        [key: string]: string;
    } | undefined;
    get createTime(): string;
    private _cryptoKeyName?;
    get cryptoKeyName(): string;
    set cryptoKeyName(value: string);
    resetCryptoKeyName(): void;
    get cryptoKeyNameInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _effectiveAnnotations;
    get effectiveAnnotations(): cdktf.StringMap;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    get etag(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _pipelineId?;
    get pipelineId(): string;
    set pipelineId(value: string);
    get pipelineIdInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get uid(): string;
    get updateTime(): string;
    private _destinations;
    get destinations(): GoogleEventarcPipelineDestinationsList;
    putDestinations(value: GoogleEventarcPipelineDestinations[] | cdktf.IResolvable): void;
    get destinationsInput(): cdktf.IResolvable | GoogleEventarcPipelineDestinations[] | undefined;
    private _inputPayloadFormat;
    get inputPayloadFormat(): GoogleEventarcPipelineInputPayloadFormatOutputReference;
    putInputPayloadFormat(value: GoogleEventarcPipelineInputPayloadFormat): void;
    resetInputPayloadFormat(): void;
    get inputPayloadFormatInput(): GoogleEventarcPipelineInputPayloadFormat | undefined;
    private _loggingConfig;
    get loggingConfig(): GoogleEventarcPipelineLoggingConfigOutputReference;
    putLoggingConfig(value: GoogleEventarcPipelineLoggingConfig): void;
    resetLoggingConfig(): void;
    get loggingConfigInput(): GoogleEventarcPipelineLoggingConfig | undefined;
    private _mediations;
    get mediations(): GoogleEventarcPipelineMediationsList;
    putMediations(value: GoogleEventarcPipelineMediations[] | cdktf.IResolvable): void;
    resetMediations(): void;
    get mediationsInput(): cdktf.IResolvable | GoogleEventarcPipelineMediations[] | undefined;
    private _retryPolicy;
    get retryPolicy(): GoogleEventarcPipelineRetryPolicyOutputReference;
    putRetryPolicy(value: GoogleEventarcPipelineRetryPolicy): void;
    resetRetryPolicy(): void;
    get retryPolicyInput(): GoogleEventarcPipelineRetryPolicy | undefined;
    private _timeouts;
    get timeouts(): GoogleEventarcPipelineTimeoutsOutputReference;
    putTimeouts(value: GoogleEventarcPipelineTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleEventarcPipelineTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
