/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleFirebaseAppHostingBuildConfig extends cdktf.TerraformMetaArguments {
    /**
    * Unstructured key value map that may be set by external tools to
    * store and arbitrary metadata. They are not queryable and should be
    * preserved when modifying objects.
    *
    * **Note**: This field is non-authoritative, and will only manage the annotations present in your configuration.
    * Please refer to the field 'effective_annotations' for all of the annotations present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_firebase_app_hosting_build#annotations GoogleFirebaseAppHostingBuild#annotations}
    */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
    * The ID of the Backend that this Build applies to
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_firebase_app_hosting_build#backend GoogleFirebaseAppHostingBuild#backend}
    */
    readonly backend: string;
    /**
    * The user-specified ID of the build being created.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_firebase_app_hosting_build#build_id GoogleFirebaseAppHostingBuild#build_id}
    */
    readonly buildId: string;
    /**
    * Human-readable name. 63 character limit.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_firebase_app_hosting_build#display_name GoogleFirebaseAppHostingBuild#display_name}
    */
    readonly displayName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_firebase_app_hosting_build#id GoogleFirebaseAppHostingBuild#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Unstructured key value map that can be used to organize and categorize
    * objects.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_firebase_app_hosting_build#labels GoogleFirebaseAppHostingBuild#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The location of the Backend that this Build applies to
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_firebase_app_hosting_build#location GoogleFirebaseAppHostingBuild#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_firebase_app_hosting_build#project GoogleFirebaseAppHostingBuild#project}
    */
    readonly project?: string;
    /**
    * source block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_firebase_app_hosting_build#source GoogleFirebaseAppHostingBuild#source}
    */
    readonly source: GoogleFirebaseAppHostingBuildSource;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_firebase_app_hosting_build#timeouts GoogleFirebaseAppHostingBuild#timeouts}
    */
    readonly timeouts?: GoogleFirebaseAppHostingBuildTimeouts;
}
export interface GoogleFirebaseAppHostingBuildError {
}
export declare function googleFirebaseAppHostingBuildErrorToTerraform(struct?: GoogleFirebaseAppHostingBuildError): any;
export declare function googleFirebaseAppHostingBuildErrorToHclTerraform(struct?: GoogleFirebaseAppHostingBuildError): any;
export declare class GoogleFirebaseAppHostingBuildErrorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleFirebaseAppHostingBuildError | undefined;
    set internalValue(value: GoogleFirebaseAppHostingBuildError | undefined);
    get code(): number;
    private _details;
    get details(): cdktf.StringMapList;
    get message(): string;
}
export declare class GoogleFirebaseAppHostingBuildErrorList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleFirebaseAppHostingBuildErrorOutputReference;
}
export interface GoogleFirebaseAppHostingBuildSourceCodebaseAuthor {
}
export declare function googleFirebaseAppHostingBuildSourceCodebaseAuthorToTerraform(struct?: GoogleFirebaseAppHostingBuildSourceCodebaseAuthor): any;
export declare function googleFirebaseAppHostingBuildSourceCodebaseAuthorToHclTerraform(struct?: GoogleFirebaseAppHostingBuildSourceCodebaseAuthor): any;
export declare class GoogleFirebaseAppHostingBuildSourceCodebaseAuthorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleFirebaseAppHostingBuildSourceCodebaseAuthor | undefined;
    set internalValue(value: GoogleFirebaseAppHostingBuildSourceCodebaseAuthor | undefined);
    get displayName(): string;
    get email(): string;
    get imageUri(): string;
}
export declare class GoogleFirebaseAppHostingBuildSourceCodebaseAuthorList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleFirebaseAppHostingBuildSourceCodebaseAuthorOutputReference;
}
export interface GoogleFirebaseAppHostingBuildSourceCodebase {
    /**
    * The branch in the codebase to build from, using the latest commit.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_firebase_app_hosting_build#branch GoogleFirebaseAppHostingBuild#branch}
    */
    readonly branch?: string;
    /**
    * The commit in the codebase to build from.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_firebase_app_hosting_build#commit GoogleFirebaseAppHostingBuild#commit}
    */
    readonly commit?: string;
}
export declare function googleFirebaseAppHostingBuildSourceCodebaseToTerraform(struct?: GoogleFirebaseAppHostingBuildSourceCodebaseOutputReference | GoogleFirebaseAppHostingBuildSourceCodebase): any;
export declare function googleFirebaseAppHostingBuildSourceCodebaseToHclTerraform(struct?: GoogleFirebaseAppHostingBuildSourceCodebaseOutputReference | GoogleFirebaseAppHostingBuildSourceCodebase): any;
export declare class GoogleFirebaseAppHostingBuildSourceCodebaseOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleFirebaseAppHostingBuildSourceCodebase | undefined;
    set internalValue(value: GoogleFirebaseAppHostingBuildSourceCodebase | undefined);
    private _author;
    get author(): GoogleFirebaseAppHostingBuildSourceCodebaseAuthorList;
    private _branch?;
    get branch(): string;
    set branch(value: string);
    resetBranch(): void;
    get branchInput(): string | undefined;
    private _commit?;
    get commit(): string;
    set commit(value: string);
    resetCommit(): void;
    get commitInput(): string | undefined;
    get commitMessage(): string;
    get commitTime(): string;
    get displayName(): string;
    get hash(): string;
    get uri(): string;
}
export interface GoogleFirebaseAppHostingBuildSourceContainer {
    /**
    * A URI representing a container for the backend to use.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_firebase_app_hosting_build#image GoogleFirebaseAppHostingBuild#image}
    */
    readonly image: string;
}
export declare function googleFirebaseAppHostingBuildSourceContainerToTerraform(struct?: GoogleFirebaseAppHostingBuildSourceContainerOutputReference | GoogleFirebaseAppHostingBuildSourceContainer): any;
export declare function googleFirebaseAppHostingBuildSourceContainerToHclTerraform(struct?: GoogleFirebaseAppHostingBuildSourceContainerOutputReference | GoogleFirebaseAppHostingBuildSourceContainer): any;
export declare class GoogleFirebaseAppHostingBuildSourceContainerOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleFirebaseAppHostingBuildSourceContainer | undefined;
    set internalValue(value: GoogleFirebaseAppHostingBuildSourceContainer | undefined);
    private _image?;
    get image(): string;
    set image(value: string);
    get imageInput(): string | undefined;
}
export interface GoogleFirebaseAppHostingBuildSource {
    /**
    * codebase block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_firebase_app_hosting_build#codebase GoogleFirebaseAppHostingBuild#codebase}
    */
    readonly codebase?: GoogleFirebaseAppHostingBuildSourceCodebase;
    /**
    * container block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_firebase_app_hosting_build#container GoogleFirebaseAppHostingBuild#container}
    */
    readonly container?: GoogleFirebaseAppHostingBuildSourceContainer;
}
export declare function googleFirebaseAppHostingBuildSourceToTerraform(struct?: GoogleFirebaseAppHostingBuildSourceOutputReference | GoogleFirebaseAppHostingBuildSource): any;
export declare function googleFirebaseAppHostingBuildSourceToHclTerraform(struct?: GoogleFirebaseAppHostingBuildSourceOutputReference | GoogleFirebaseAppHostingBuildSource): any;
export declare class GoogleFirebaseAppHostingBuildSourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleFirebaseAppHostingBuildSource | undefined;
    set internalValue(value: GoogleFirebaseAppHostingBuildSource | undefined);
    private _codebase;
    get codebase(): GoogleFirebaseAppHostingBuildSourceCodebaseOutputReference;
    putCodebase(value: GoogleFirebaseAppHostingBuildSourceCodebase): void;
    resetCodebase(): void;
    get codebaseInput(): GoogleFirebaseAppHostingBuildSourceCodebase | undefined;
    private _container;
    get container(): GoogleFirebaseAppHostingBuildSourceContainerOutputReference;
    putContainer(value: GoogleFirebaseAppHostingBuildSourceContainer): void;
    resetContainer(): void;
    get containerInput(): GoogleFirebaseAppHostingBuildSourceContainer | undefined;
}
export interface GoogleFirebaseAppHostingBuildTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_firebase_app_hosting_build#create GoogleFirebaseAppHostingBuild#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_firebase_app_hosting_build#delete GoogleFirebaseAppHostingBuild#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_firebase_app_hosting_build#update GoogleFirebaseAppHostingBuild#update}
    */
    readonly update?: string;
}
export declare function googleFirebaseAppHostingBuildTimeoutsToTerraform(struct?: GoogleFirebaseAppHostingBuildTimeouts | cdktf.IResolvable): any;
export declare function googleFirebaseAppHostingBuildTimeoutsToHclTerraform(struct?: GoogleFirebaseAppHostingBuildTimeouts | cdktf.IResolvable): any;
export declare class GoogleFirebaseAppHostingBuildTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleFirebaseAppHostingBuildTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleFirebaseAppHostingBuildTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_firebase_app_hosting_build google_firebase_app_hosting_build}
*/
export declare class GoogleFirebaseAppHostingBuild extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_firebase_app_hosting_build";
    /**
    * Generates CDKTF code for importing a GoogleFirebaseAppHostingBuild resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleFirebaseAppHostingBuild to import
    * @param importFromId The id of the existing GoogleFirebaseAppHostingBuild that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_firebase_app_hosting_build#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleFirebaseAppHostingBuild to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_firebase_app_hosting_build google_firebase_app_hosting_build} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleFirebaseAppHostingBuildConfig
    */
    constructor(scope: Construct, id: string, config: GoogleFirebaseAppHostingBuildConfig);
    private _annotations?;
    get annotations(): {
        [key: string]: string;
    };
    set annotations(value: {
        [key: string]: string;
    });
    resetAnnotations(): void;
    get annotationsInput(): {
        [key: string]: string;
    } | undefined;
    private _backend?;
    get backend(): string;
    set backend(value: string);
    get backendInput(): string | undefined;
    private _buildId?;
    get buildId(): string;
    set buildId(value: string);
    get buildIdInput(): string | undefined;
    get buildLogsUri(): string;
    get createTime(): string;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _effectiveAnnotations;
    get effectiveAnnotations(): cdktf.StringMap;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    get environment(): string;
    private _error;
    get error(): GoogleFirebaseAppHostingBuildErrorList;
    get errorSource(): string;
    get etag(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get image(): string;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get state(): string;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get uid(): string;
    get updateTime(): string;
    private _source;
    get source(): GoogleFirebaseAppHostingBuildSourceOutputReference;
    putSource(value: GoogleFirebaseAppHostingBuildSource): void;
    get sourceInput(): GoogleFirebaseAppHostingBuildSource | undefined;
    private _timeouts;
    get timeouts(): GoogleFirebaseAppHostingBuildTimeoutsOutputReference;
    putTimeouts(value: GoogleFirebaseAppHostingBuildTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleFirebaseAppHostingBuildTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
