/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleGeminiCodeToolsSettingConfig extends cdktf.TerraformMetaArguments {
    /**
    * Id of the Code Tools Setting.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_code_tools_setting#code_tools_setting_id GoogleGeminiCodeToolsSetting#code_tools_setting_id}
    */
    readonly codeToolsSettingId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_code_tools_setting#id GoogleGeminiCodeToolsSetting#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Labels as key value pairs.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_code_tools_setting#labels GoogleGeminiCodeToolsSetting#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Resource ID segment making up resource 'name'. It identifies the resource within its parent collection as described in https://google.aip.dev/122.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_code_tools_setting#location GoogleGeminiCodeToolsSetting#location}
    */
    readonly location?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_code_tools_setting#project GoogleGeminiCodeToolsSetting#project}
    */
    readonly project?: string;
    /**
    * enabled_tool block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_code_tools_setting#enabled_tool GoogleGeminiCodeToolsSetting#enabled_tool}
    */
    readonly enabledTool: GoogleGeminiCodeToolsSettingEnabledTool[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_code_tools_setting#timeouts GoogleGeminiCodeToolsSetting#timeouts}
    */
    readonly timeouts?: GoogleGeminiCodeToolsSettingTimeouts;
}
export interface GoogleGeminiCodeToolsSettingEnabledToolConfig {
    /**
    * Key of the configuration item.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_code_tools_setting#key GoogleGeminiCodeToolsSetting#key}
    */
    readonly key: string;
    /**
    * Value of the configuration item.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_code_tools_setting#value GoogleGeminiCodeToolsSetting#value}
    */
    readonly value: string;
}
export declare function googleGeminiCodeToolsSettingEnabledToolConfigToTerraform(struct?: GoogleGeminiCodeToolsSettingEnabledToolConfig | cdktf.IResolvable): any;
export declare function googleGeminiCodeToolsSettingEnabledToolConfigToHclTerraform(struct?: GoogleGeminiCodeToolsSettingEnabledToolConfig | cdktf.IResolvable): any;
export declare class GoogleGeminiCodeToolsSettingEnabledToolConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleGeminiCodeToolsSettingEnabledToolConfig | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleGeminiCodeToolsSettingEnabledToolConfig | cdktf.IResolvable | undefined);
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    get valueInput(): string | undefined;
}
export declare class GoogleGeminiCodeToolsSettingEnabledToolConfigList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleGeminiCodeToolsSettingEnabledToolConfig[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleGeminiCodeToolsSettingEnabledToolConfigOutputReference;
}
export interface GoogleGeminiCodeToolsSettingEnabledTool {
    /**
    * Link to the Dev Connect Account Connector that holds the user credentials.
    * projects/{project}/locations/{location}/accountConnectors/{account_connector_id}
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_code_tools_setting#account_connector GoogleGeminiCodeToolsSetting#account_connector}
    */
    readonly accountConnector?: string;
    /**
    * Handle used to invoke the tool.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_code_tools_setting#handle GoogleGeminiCodeToolsSetting#handle}
    */
    readonly handle: string;
    /**
    * Link to the Tool
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_code_tools_setting#tool GoogleGeminiCodeToolsSetting#tool}
    */
    readonly tool: string;
    /**
    * Overridden URI, if allowed by Tool.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_code_tools_setting#uri_override GoogleGeminiCodeToolsSetting#uri_override}
    */
    readonly uriOverride?: string;
    /**
    * config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_code_tools_setting#config GoogleGeminiCodeToolsSetting#config}
    */
    readonly config?: GoogleGeminiCodeToolsSettingEnabledToolConfig[] | cdktf.IResolvable;
}
export declare function googleGeminiCodeToolsSettingEnabledToolToTerraform(struct?: GoogleGeminiCodeToolsSettingEnabledTool | cdktf.IResolvable): any;
export declare function googleGeminiCodeToolsSettingEnabledToolToHclTerraform(struct?: GoogleGeminiCodeToolsSettingEnabledTool | cdktf.IResolvable): any;
export declare class GoogleGeminiCodeToolsSettingEnabledToolOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleGeminiCodeToolsSettingEnabledTool | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleGeminiCodeToolsSettingEnabledTool | cdktf.IResolvable | undefined);
    private _accountConnector?;
    get accountConnector(): string;
    set accountConnector(value: string);
    resetAccountConnector(): void;
    get accountConnectorInput(): string | undefined;
    private _handle?;
    get handle(): string;
    set handle(value: string);
    get handleInput(): string | undefined;
    private _tool?;
    get tool(): string;
    set tool(value: string);
    get toolInput(): string | undefined;
    private _uriOverride?;
    get uriOverride(): string;
    set uriOverride(value: string);
    resetUriOverride(): void;
    get uriOverrideInput(): string | undefined;
    private _config;
    get config(): GoogleGeminiCodeToolsSettingEnabledToolConfigList;
    putConfig(value: GoogleGeminiCodeToolsSettingEnabledToolConfig[] | cdktf.IResolvable): void;
    resetConfig(): void;
    get configInput(): cdktf.IResolvable | GoogleGeminiCodeToolsSettingEnabledToolConfig[] | undefined;
}
export declare class GoogleGeminiCodeToolsSettingEnabledToolList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleGeminiCodeToolsSettingEnabledTool[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleGeminiCodeToolsSettingEnabledToolOutputReference;
}
export interface GoogleGeminiCodeToolsSettingTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_code_tools_setting#create GoogleGeminiCodeToolsSetting#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_code_tools_setting#delete GoogleGeminiCodeToolsSetting#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_code_tools_setting#update GoogleGeminiCodeToolsSetting#update}
    */
    readonly update?: string;
}
export declare function googleGeminiCodeToolsSettingTimeoutsToTerraform(struct?: GoogleGeminiCodeToolsSettingTimeouts | cdktf.IResolvable): any;
export declare function googleGeminiCodeToolsSettingTimeoutsToHclTerraform(struct?: GoogleGeminiCodeToolsSettingTimeouts | cdktf.IResolvable): any;
export declare class GoogleGeminiCodeToolsSettingTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleGeminiCodeToolsSettingTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleGeminiCodeToolsSettingTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_code_tools_setting google_gemini_code_tools_setting}
*/
export declare class GoogleGeminiCodeToolsSetting extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_gemini_code_tools_setting";
    /**
    * Generates CDKTF code for importing a GoogleGeminiCodeToolsSetting resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleGeminiCodeToolsSetting to import
    * @param importFromId The id of the existing GoogleGeminiCodeToolsSetting that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_code_tools_setting#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleGeminiCodeToolsSetting to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_code_tools_setting google_gemini_code_tools_setting} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleGeminiCodeToolsSettingConfig
    */
    constructor(scope: Construct, id: string, config: GoogleGeminiCodeToolsSettingConfig);
    private _codeToolsSettingId?;
    get codeToolsSettingId(): string;
    set codeToolsSettingId(value: string);
    get codeToolsSettingIdInput(): string | undefined;
    get createTime(): string;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    resetLocation(): void;
    get locationInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get updateTime(): string;
    private _enabledTool;
    get enabledTool(): GoogleGeminiCodeToolsSettingEnabledToolList;
    putEnabledTool(value: GoogleGeminiCodeToolsSettingEnabledTool[] | cdktf.IResolvable): void;
    get enabledToolInput(): cdktf.IResolvable | GoogleGeminiCodeToolsSettingEnabledTool[] | undefined;
    private _timeouts;
    get timeouts(): GoogleGeminiCodeToolsSettingTimeoutsOutputReference;
    putTimeouts(value: GoogleGeminiCodeToolsSettingTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleGeminiCodeToolsSettingTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
