/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleGeminiLoggingSettingConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_logging_setting#id GoogleGeminiLoggingSetting#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Labels as key value pairs.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_logging_setting#labels GoogleGeminiLoggingSetting#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Resource ID segment making up resource 'name'. It identifies the resource within its parent collection as described in https://google.aip.dev/122.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_logging_setting#location GoogleGeminiLoggingSetting#location}
    */
    readonly location: string;
    /**
    * Whether to log metadata.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_logging_setting#log_metadata GoogleGeminiLoggingSetting#log_metadata}
    */
    readonly logMetadata?: boolean | cdktf.IResolvable;
    /**
    * Whether to log prompts and responses.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_logging_setting#log_prompts_and_responses GoogleGeminiLoggingSetting#log_prompts_and_responses}
    */
    readonly logPromptsAndResponses?: boolean | cdktf.IResolvable;
    /**
    * Id of the Logging Setting.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_logging_setting#logging_setting_id GoogleGeminiLoggingSetting#logging_setting_id}
    */
    readonly loggingSettingId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_logging_setting#project GoogleGeminiLoggingSetting#project}
    */
    readonly project?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_logging_setting#timeouts GoogleGeminiLoggingSetting#timeouts}
    */
    readonly timeouts?: GoogleGeminiLoggingSettingTimeouts;
}
export interface GoogleGeminiLoggingSettingTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_logging_setting#create GoogleGeminiLoggingSetting#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_logging_setting#delete GoogleGeminiLoggingSetting#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_logging_setting#update GoogleGeminiLoggingSetting#update}
    */
    readonly update?: string;
}
export declare function googleGeminiLoggingSettingTimeoutsToTerraform(struct?: GoogleGeminiLoggingSettingTimeouts | cdktf.IResolvable): any;
export declare function googleGeminiLoggingSettingTimeoutsToHclTerraform(struct?: GoogleGeminiLoggingSettingTimeouts | cdktf.IResolvable): any;
export declare class GoogleGeminiLoggingSettingTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleGeminiLoggingSettingTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleGeminiLoggingSettingTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_logging_setting google_gemini_logging_setting}
*/
export declare class GoogleGeminiLoggingSetting extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_gemini_logging_setting";
    /**
    * Generates CDKTF code for importing a GoogleGeminiLoggingSetting resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleGeminiLoggingSetting to import
    * @param importFromId The id of the existing GoogleGeminiLoggingSetting that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_logging_setting#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleGeminiLoggingSetting to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gemini_logging_setting google_gemini_logging_setting} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleGeminiLoggingSettingConfig
    */
    constructor(scope: Construct, id: string, config: GoogleGeminiLoggingSettingConfig);
    get createTime(): string;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _logMetadata?;
    get logMetadata(): boolean | cdktf.IResolvable;
    set logMetadata(value: boolean | cdktf.IResolvable);
    resetLogMetadata(): void;
    get logMetadataInput(): boolean | cdktf.IResolvable | undefined;
    private _logPromptsAndResponses?;
    get logPromptsAndResponses(): boolean | cdktf.IResolvable;
    set logPromptsAndResponses(value: boolean | cdktf.IResolvable);
    resetLogPromptsAndResponses(): void;
    get logPromptsAndResponsesInput(): boolean | cdktf.IResolvable | undefined;
    private _loggingSettingId?;
    get loggingSettingId(): string;
    set loggingSettingId(value: string);
    get loggingSettingIdInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get updateTime(): string;
    private _timeouts;
    get timeouts(): GoogleGeminiLoggingSettingTimeoutsOutputReference;
    putTimeouts(value: GoogleGeminiLoggingSettingTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleGeminiLoggingSettingTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
