/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleGkeBackupBackupChannelConfig extends cdktf.TerraformMetaArguments {
    /**
    * User specified descriptive string for this BackupChannel.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gke_backup_backup_channel#description GoogleGkeBackupBackupChannel#description}
    */
    readonly description?: string;
    /**
    * The project where Backups are allowed to be stored.
    * The format is 'projects/{project}'.
    * {project} can only be a project number.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gke_backup_backup_channel#destination_project GoogleGkeBackupBackupChannel#destination_project}
    */
    readonly destinationProject: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gke_backup_backup_channel#id GoogleGkeBackupBackupChannel#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Description: A set of custom labels supplied by the user.
    * A list of key->value pairs.
    * Example: { "name": "wrench", "mass": "1.3kg", "count": "3" }.
    *
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gke_backup_backup_channel#labels GoogleGkeBackupBackupChannel#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The region of the Backup Channel.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gke_backup_backup_channel#location GoogleGkeBackupBackupChannel#location}
    */
    readonly location: string;
    /**
    * The full name of the BackupChannel Resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gke_backup_backup_channel#name GoogleGkeBackupBackupChannel#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gke_backup_backup_channel#project GoogleGkeBackupBackupChannel#project}
    */
    readonly project?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gke_backup_backup_channel#timeouts GoogleGkeBackupBackupChannel#timeouts}
    */
    readonly timeouts?: GoogleGkeBackupBackupChannelTimeouts;
}
export interface GoogleGkeBackupBackupChannelTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gke_backup_backup_channel#create GoogleGkeBackupBackupChannel#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gke_backup_backup_channel#delete GoogleGkeBackupBackupChannel#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gke_backup_backup_channel#update GoogleGkeBackupBackupChannel#update}
    */
    readonly update?: string;
}
export declare function googleGkeBackupBackupChannelTimeoutsToTerraform(struct?: GoogleGkeBackupBackupChannelTimeouts | cdktf.IResolvable): any;
export declare function googleGkeBackupBackupChannelTimeoutsToHclTerraform(struct?: GoogleGkeBackupBackupChannelTimeouts | cdktf.IResolvable): any;
export declare class GoogleGkeBackupBackupChannelTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleGkeBackupBackupChannelTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleGkeBackupBackupChannelTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gke_backup_backup_channel google_gke_backup_backup_channel}
*/
export declare class GoogleGkeBackupBackupChannel extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_gke_backup_backup_channel";
    /**
    * Generates CDKTF code for importing a GoogleGkeBackupBackupChannel resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleGkeBackupBackupChannel to import
    * @param importFromId The id of the existing GoogleGkeBackupBackupChannel that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gke_backup_backup_channel#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleGkeBackupBackupChannel to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_gke_backup_backup_channel google_gke_backup_backup_channel} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleGkeBackupBackupChannelConfig
    */
    constructor(scope: Construct, id: string, config: GoogleGkeBackupBackupChannelConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _destinationProject?;
    get destinationProject(): string;
    set destinationProject(value: string);
    get destinationProjectInput(): string | undefined;
    get destinationProjectId(): string;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    get etag(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get uid(): string;
    private _timeouts;
    get timeouts(): GoogleGkeBackupBackupChannelTimeoutsOutputReference;
    putTimeouts(value: GoogleGkeBackupBackupChannelTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleGkeBackupBackupChannelTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
