/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleIamProjectsPolicyBindingConfig extends cdktf.TerraformMetaArguments {
    /**
    * Optional. User defined annotations. See https://google.aip.dev/148#annotations for more details such as format and size limitations
    *
    *
    * **Note**: This field is non-authoritative, and will only manage the annotations present in your configuration.
    * Please refer to the field 'effective_annotations' for all of the annotations present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_iam_projects_policy_binding#annotations GoogleIamProjectsPolicyBinding#annotations}
    */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
    * Optional. The description of the policy binding. Must be less than or equal to 63 characters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_iam_projects_policy_binding#display_name GoogleIamProjectsPolicyBinding#display_name}
    */
    readonly displayName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_iam_projects_policy_binding#id GoogleIamProjectsPolicyBinding#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The location of the Policy Binding
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_iam_projects_policy_binding#location GoogleIamProjectsPolicyBinding#location}
    */
    readonly location: string;
    /**
    * Required. Immutable. The resource name of the policy to be bound. The binding parent and policy must belong to the same Organization (or Project).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_iam_projects_policy_binding#policy GoogleIamProjectsPolicyBinding#policy}
    */
    readonly policy: string;
    /**
    * The Policy Binding ID.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_iam_projects_policy_binding#policy_binding_id GoogleIamProjectsPolicyBinding#policy_binding_id}
    */
    readonly policyBindingId: string;
    /**
    * Immutable. The kind of the policy to attach in this binding. This
    * field must be one of the following:  - Left empty (will be automatically set
    * to the policy kind) - The input policy kind   Possible values:  POLICY_KIND_UNSPECIFIED PRINCIPAL_ACCESS_BOUNDARY ACCESS
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_iam_projects_policy_binding#policy_kind GoogleIamProjectsPolicyBinding#policy_kind}
    */
    readonly policyKind?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_iam_projects_policy_binding#project GoogleIamProjectsPolicyBinding#project}
    */
    readonly project?: string;
    /**
    * condition block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_iam_projects_policy_binding#condition GoogleIamProjectsPolicyBinding#condition}
    */
    readonly condition?: GoogleIamProjectsPolicyBindingCondition;
    /**
    * target block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_iam_projects_policy_binding#target GoogleIamProjectsPolicyBinding#target}
    */
    readonly target: GoogleIamProjectsPolicyBindingTarget;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_iam_projects_policy_binding#timeouts GoogleIamProjectsPolicyBinding#timeouts}
    */
    readonly timeouts?: GoogleIamProjectsPolicyBindingTimeouts;
}
export interface GoogleIamProjectsPolicyBindingCondition {
    /**
    * Optional. Description of the expression. This is a longer text which describes the expression, e.g. when hovered over it in a UI.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_iam_projects_policy_binding#description GoogleIamProjectsPolicyBinding#description}
    */
    readonly description?: string;
    /**
    * Textual representation of an expression in Common Expression Language syntax.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_iam_projects_policy_binding#expression GoogleIamProjectsPolicyBinding#expression}
    */
    readonly expression?: string;
    /**
    * Optional. String indicating the location of the expression for error reporting, e.g. a file name and a position in the file.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_iam_projects_policy_binding#location GoogleIamProjectsPolicyBinding#location}
    */
    readonly location?: string;
    /**
    * Optional. Title for the expression, i.e. a short string describing its purpose. This can be used e.g. in UIs which allow to enter the expression.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_iam_projects_policy_binding#title GoogleIamProjectsPolicyBinding#title}
    */
    readonly title?: string;
}
export declare function googleIamProjectsPolicyBindingConditionToTerraform(struct?: GoogleIamProjectsPolicyBindingConditionOutputReference | GoogleIamProjectsPolicyBindingCondition): any;
export declare function googleIamProjectsPolicyBindingConditionToHclTerraform(struct?: GoogleIamProjectsPolicyBindingConditionOutputReference | GoogleIamProjectsPolicyBindingCondition): any;
export declare class GoogleIamProjectsPolicyBindingConditionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIamProjectsPolicyBindingCondition | undefined;
    set internalValue(value: GoogleIamProjectsPolicyBindingCondition | undefined);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _expression?;
    get expression(): string;
    set expression(value: string);
    resetExpression(): void;
    get expressionInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    resetLocation(): void;
    get locationInput(): string | undefined;
    private _title?;
    get title(): string;
    set title(value: string);
    resetTitle(): void;
    get titleInput(): string | undefined;
}
export interface GoogleIamProjectsPolicyBindingTarget {
    /**
    * Required. Immutable. Full Resource Name of the principal set used for principal access boundary policy bindings.
    * Examples for each one of the following supported principal set types:
    * * Project:
    *   * '//cloudresourcemanager.googleapis.com/projects/PROJECT_NUMBER'
    *   * '//cloudresourcemanager.googleapis.com/projects/PROJECT_ID'
    * * Workload Identity Pool: '//iam.googleapis.com/projects/PROJECT_NUMBER/locations/LOCATION/workloadIdentityPools/WORKLOAD_POOL_ID'
    * It must be parent by the policy binding's parent (the project).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_iam_projects_policy_binding#principal_set GoogleIamProjectsPolicyBinding#principal_set}
    */
    readonly principalSet?: string;
}
export declare function googleIamProjectsPolicyBindingTargetToTerraform(struct?: GoogleIamProjectsPolicyBindingTargetOutputReference | GoogleIamProjectsPolicyBindingTarget): any;
export declare function googleIamProjectsPolicyBindingTargetToHclTerraform(struct?: GoogleIamProjectsPolicyBindingTargetOutputReference | GoogleIamProjectsPolicyBindingTarget): any;
export declare class GoogleIamProjectsPolicyBindingTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIamProjectsPolicyBindingTarget | undefined;
    set internalValue(value: GoogleIamProjectsPolicyBindingTarget | undefined);
    private _principalSet?;
    get principalSet(): string;
    set principalSet(value: string);
    resetPrincipalSet(): void;
    get principalSetInput(): string | undefined;
}
export interface GoogleIamProjectsPolicyBindingTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_iam_projects_policy_binding#create GoogleIamProjectsPolicyBinding#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_iam_projects_policy_binding#delete GoogleIamProjectsPolicyBinding#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_iam_projects_policy_binding#update GoogleIamProjectsPolicyBinding#update}
    */
    readonly update?: string;
}
export declare function googleIamProjectsPolicyBindingTimeoutsToTerraform(struct?: GoogleIamProjectsPolicyBindingTimeouts | cdktf.IResolvable): any;
export declare function googleIamProjectsPolicyBindingTimeoutsToHclTerraform(struct?: GoogleIamProjectsPolicyBindingTimeouts | cdktf.IResolvable): any;
export declare class GoogleIamProjectsPolicyBindingTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIamProjectsPolicyBindingTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleIamProjectsPolicyBindingTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_iam_projects_policy_binding google_iam_projects_policy_binding}
*/
export declare class GoogleIamProjectsPolicyBinding extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_iam_projects_policy_binding";
    /**
    * Generates CDKTF code for importing a GoogleIamProjectsPolicyBinding resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleIamProjectsPolicyBinding to import
    * @param importFromId The id of the existing GoogleIamProjectsPolicyBinding that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_iam_projects_policy_binding#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleIamProjectsPolicyBinding to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_iam_projects_policy_binding google_iam_projects_policy_binding} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleIamProjectsPolicyBindingConfig
    */
    constructor(scope: Construct, id: string, config: GoogleIamProjectsPolicyBindingConfig);
    private _annotations?;
    get annotations(): {
        [key: string]: string;
    };
    set annotations(value: {
        [key: string]: string;
    });
    resetAnnotations(): void;
    get annotationsInput(): {
        [key: string]: string;
    } | undefined;
    get createTime(): string;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _effectiveAnnotations;
    get effectiveAnnotations(): cdktf.StringMap;
    get etag(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _policy?;
    get policy(): string;
    set policy(value: string);
    get policyInput(): string | undefined;
    private _policyBindingId?;
    get policyBindingId(): string;
    set policyBindingId(value: string);
    get policyBindingIdInput(): string | undefined;
    private _policyKind?;
    get policyKind(): string;
    set policyKind(value: string);
    resetPolicyKind(): void;
    get policyKindInput(): string | undefined;
    get policyUid(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get uid(): string;
    get updateTime(): string;
    private _condition;
    get condition(): GoogleIamProjectsPolicyBindingConditionOutputReference;
    putCondition(value: GoogleIamProjectsPolicyBindingCondition): void;
    resetCondition(): void;
    get conditionInput(): GoogleIamProjectsPolicyBindingCondition | undefined;
    private _target;
    get target(): GoogleIamProjectsPolicyBindingTargetOutputReference;
    putTarget(value: GoogleIamProjectsPolicyBindingTarget): void;
    get targetInput(): GoogleIamProjectsPolicyBindingTarget | undefined;
    private _timeouts;
    get timeouts(): GoogleIamProjectsPolicyBindingTimeoutsOutputReference;
    putTimeouts(value: GoogleIamProjectsPolicyBindingTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleIamProjectsPolicyBindingTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
