/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleManagedKafkaConnectorConfig extends cdktf.TerraformMetaArguments {
    /**
    * Connector config as keys/values. The keys of the map are connector property names, for example: 'connector.class', 'tasks.max', 'key.converter'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_managed_kafka_connector#configs GoogleManagedKafkaConnector#configs}
    */
    readonly configs?: {
        [key: string]: string;
    };
    /**
    * The connect cluster name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_managed_kafka_connector#connect_cluster GoogleManagedKafkaConnector#connect_cluster}
    */
    readonly connectCluster: string;
    /**
    * The ID to use for the connector, which will become the final component of the connector's name. This value is structured like: 'my-connector-id'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_managed_kafka_connector#connector_id GoogleManagedKafkaConnector#connector_id}
    */
    readonly connectorId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_managed_kafka_connector#id GoogleManagedKafkaConnector#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * ID of the location of the Kafka Connect resource. See https://cloud.google.com/managed-kafka/docs/locations for a list of supported locations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_managed_kafka_connector#location GoogleManagedKafkaConnector#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_managed_kafka_connector#project GoogleManagedKafkaConnector#project}
    */
    readonly project?: string;
    /**
    * task_restart_policy block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_managed_kafka_connector#task_restart_policy GoogleManagedKafkaConnector#task_restart_policy}
    */
    readonly taskRestartPolicy?: GoogleManagedKafkaConnectorTaskRestartPolicy;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_managed_kafka_connector#timeouts GoogleManagedKafkaConnector#timeouts}
    */
    readonly timeouts?: GoogleManagedKafkaConnectorTimeouts;
}
export interface GoogleManagedKafkaConnectorTaskRestartPolicy {
    /**
    * The maximum amount of time to wait before retrying a failed task. This sets an upper bound for the backoff delay.
    * A duration in seconds with up to nine fractional digits, terminated by 's'. Example: "3.5s".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_managed_kafka_connector#maximum_backoff GoogleManagedKafkaConnector#maximum_backoff}
    */
    readonly maximumBackoff?: string;
    /**
    * The minimum amount of time to wait before retrying a failed task. This sets a lower bound for the backoff delay.
    * A duration in seconds with up to nine fractional digits, terminated by 's'. Example: "3.5s".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_managed_kafka_connector#minimum_backoff GoogleManagedKafkaConnector#minimum_backoff}
    */
    readonly minimumBackoff?: string;
}
export declare function googleManagedKafkaConnectorTaskRestartPolicyToTerraform(struct?: GoogleManagedKafkaConnectorTaskRestartPolicyOutputReference | GoogleManagedKafkaConnectorTaskRestartPolicy): any;
export declare function googleManagedKafkaConnectorTaskRestartPolicyToHclTerraform(struct?: GoogleManagedKafkaConnectorTaskRestartPolicyOutputReference | GoogleManagedKafkaConnectorTaskRestartPolicy): any;
export declare class GoogleManagedKafkaConnectorTaskRestartPolicyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleManagedKafkaConnectorTaskRestartPolicy | undefined;
    set internalValue(value: GoogleManagedKafkaConnectorTaskRestartPolicy | undefined);
    private _maximumBackoff?;
    get maximumBackoff(): string;
    set maximumBackoff(value: string);
    resetMaximumBackoff(): void;
    get maximumBackoffInput(): string | undefined;
    private _minimumBackoff?;
    get minimumBackoff(): string;
    set minimumBackoff(value: string);
    resetMinimumBackoff(): void;
    get minimumBackoffInput(): string | undefined;
}
export interface GoogleManagedKafkaConnectorTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_managed_kafka_connector#create GoogleManagedKafkaConnector#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_managed_kafka_connector#delete GoogleManagedKafkaConnector#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_managed_kafka_connector#update GoogleManagedKafkaConnector#update}
    */
    readonly update?: string;
}
export declare function googleManagedKafkaConnectorTimeoutsToTerraform(struct?: GoogleManagedKafkaConnectorTimeouts | cdktf.IResolvable): any;
export declare function googleManagedKafkaConnectorTimeoutsToHclTerraform(struct?: GoogleManagedKafkaConnectorTimeouts | cdktf.IResolvable): any;
export declare class GoogleManagedKafkaConnectorTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleManagedKafkaConnectorTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleManagedKafkaConnectorTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_managed_kafka_connector google_managed_kafka_connector}
*/
export declare class GoogleManagedKafkaConnector extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_managed_kafka_connector";
    /**
    * Generates CDKTF code for importing a GoogleManagedKafkaConnector resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleManagedKafkaConnector to import
    * @param importFromId The id of the existing GoogleManagedKafkaConnector that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_managed_kafka_connector#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleManagedKafkaConnector to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_managed_kafka_connector google_managed_kafka_connector} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleManagedKafkaConnectorConfig
    */
    constructor(scope: Construct, id: string, config: GoogleManagedKafkaConnectorConfig);
    private _configs?;
    get configs(): {
        [key: string]: string;
    };
    set configs(value: {
        [key: string]: string;
    });
    resetConfigs(): void;
    get configsInput(): {
        [key: string]: string;
    } | undefined;
    private _connectCluster?;
    get connectCluster(): string;
    set connectCluster(value: string);
    get connectClusterInput(): string | undefined;
    private _connectorId?;
    get connectorId(): string;
    set connectorId(value: string);
    get connectorIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get state(): string;
    private _taskRestartPolicy;
    get taskRestartPolicy(): GoogleManagedKafkaConnectorTaskRestartPolicyOutputReference;
    putTaskRestartPolicy(value: GoogleManagedKafkaConnectorTaskRestartPolicy): void;
    resetTaskRestartPolicy(): void;
    get taskRestartPolicyInput(): GoogleManagedKafkaConnectorTaskRestartPolicy | undefined;
    private _timeouts;
    get timeouts(): GoogleManagedKafkaConnectorTimeoutsOutputReference;
    putTimeouts(value: GoogleManagedKafkaConnectorTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleManagedKafkaConnectorTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
