/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleNetworkSecurityInterceptEndpointGroupConfig extends cdktf.TerraformMetaArguments {
    /**
    * User-provided description of the endpoint group.
    * Used as additional context for the endpoint group.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_network_security_intercept_endpoint_group#description GoogleNetworkSecurityInterceptEndpointGroup#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_network_security_intercept_endpoint_group#id GoogleNetworkSecurityInterceptEndpointGroup#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The deployment group that this endpoint group is connected to, for example:
    * 'projects/123456789/locations/global/interceptDeploymentGroups/my-dg'.
    * See https://google.aip.dev/124.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_network_security_intercept_endpoint_group#intercept_deployment_group GoogleNetworkSecurityInterceptEndpointGroup#intercept_deployment_group}
    */
    readonly interceptDeploymentGroup: string;
    /**
    * The ID to use for the endpoint group, which will become the final component
    * of the endpoint group's resource name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_network_security_intercept_endpoint_group#intercept_endpoint_group_id GoogleNetworkSecurityInterceptEndpointGroup#intercept_endpoint_group_id}
    */
    readonly interceptEndpointGroupId: string;
    /**
    * Labels are key/value pairs that help to organize and filter resources.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_network_security_intercept_endpoint_group#labels GoogleNetworkSecurityInterceptEndpointGroup#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The cloud location of the endpoint group, currently restricted to 'global'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_network_security_intercept_endpoint_group#location GoogleNetworkSecurityInterceptEndpointGroup#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_network_security_intercept_endpoint_group#project GoogleNetworkSecurityInterceptEndpointGroup#project}
    */
    readonly project?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_network_security_intercept_endpoint_group#timeouts GoogleNetworkSecurityInterceptEndpointGroup#timeouts}
    */
    readonly timeouts?: GoogleNetworkSecurityInterceptEndpointGroupTimeouts;
}
export interface GoogleNetworkSecurityInterceptEndpointGroupAssociations {
}
export declare function googleNetworkSecurityInterceptEndpointGroupAssociationsToTerraform(struct?: GoogleNetworkSecurityInterceptEndpointGroupAssociations): any;
export declare function googleNetworkSecurityInterceptEndpointGroupAssociationsToHclTerraform(struct?: GoogleNetworkSecurityInterceptEndpointGroupAssociations): any;
export declare class GoogleNetworkSecurityInterceptEndpointGroupAssociationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleNetworkSecurityInterceptEndpointGroupAssociations | undefined;
    set internalValue(value: GoogleNetworkSecurityInterceptEndpointGroupAssociations | undefined);
    get name(): string;
    get network(): string;
    get state(): string;
}
export declare class GoogleNetworkSecurityInterceptEndpointGroupAssociationsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleNetworkSecurityInterceptEndpointGroupAssociationsOutputReference;
}
export interface GoogleNetworkSecurityInterceptEndpointGroupConnectedDeploymentGroupLocations {
}
export declare function googleNetworkSecurityInterceptEndpointGroupConnectedDeploymentGroupLocationsToTerraform(struct?: GoogleNetworkSecurityInterceptEndpointGroupConnectedDeploymentGroupLocations): any;
export declare function googleNetworkSecurityInterceptEndpointGroupConnectedDeploymentGroupLocationsToHclTerraform(struct?: GoogleNetworkSecurityInterceptEndpointGroupConnectedDeploymentGroupLocations): any;
export declare class GoogleNetworkSecurityInterceptEndpointGroupConnectedDeploymentGroupLocationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleNetworkSecurityInterceptEndpointGroupConnectedDeploymentGroupLocations | undefined;
    set internalValue(value: GoogleNetworkSecurityInterceptEndpointGroupConnectedDeploymentGroupLocations | undefined);
    get location(): string;
    get state(): string;
}
export declare class GoogleNetworkSecurityInterceptEndpointGroupConnectedDeploymentGroupLocationsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleNetworkSecurityInterceptEndpointGroupConnectedDeploymentGroupLocationsOutputReference;
}
export interface GoogleNetworkSecurityInterceptEndpointGroupConnectedDeploymentGroup {
}
export declare function googleNetworkSecurityInterceptEndpointGroupConnectedDeploymentGroupToTerraform(struct?: GoogleNetworkSecurityInterceptEndpointGroupConnectedDeploymentGroup): any;
export declare function googleNetworkSecurityInterceptEndpointGroupConnectedDeploymentGroupToHclTerraform(struct?: GoogleNetworkSecurityInterceptEndpointGroupConnectedDeploymentGroup): any;
export declare class GoogleNetworkSecurityInterceptEndpointGroupConnectedDeploymentGroupOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleNetworkSecurityInterceptEndpointGroupConnectedDeploymentGroup | undefined;
    set internalValue(value: GoogleNetworkSecurityInterceptEndpointGroupConnectedDeploymentGroup | undefined);
    private _locations;
    get locations(): GoogleNetworkSecurityInterceptEndpointGroupConnectedDeploymentGroupLocationsList;
    get name(): string;
}
export declare class GoogleNetworkSecurityInterceptEndpointGroupConnectedDeploymentGroupList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleNetworkSecurityInterceptEndpointGroupConnectedDeploymentGroupOutputReference;
}
export interface GoogleNetworkSecurityInterceptEndpointGroupTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_network_security_intercept_endpoint_group#create GoogleNetworkSecurityInterceptEndpointGroup#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_network_security_intercept_endpoint_group#delete GoogleNetworkSecurityInterceptEndpointGroup#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_network_security_intercept_endpoint_group#update GoogleNetworkSecurityInterceptEndpointGroup#update}
    */
    readonly update?: string;
}
export declare function googleNetworkSecurityInterceptEndpointGroupTimeoutsToTerraform(struct?: GoogleNetworkSecurityInterceptEndpointGroupTimeouts | cdktf.IResolvable): any;
export declare function googleNetworkSecurityInterceptEndpointGroupTimeoutsToHclTerraform(struct?: GoogleNetworkSecurityInterceptEndpointGroupTimeouts | cdktf.IResolvable): any;
export declare class GoogleNetworkSecurityInterceptEndpointGroupTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleNetworkSecurityInterceptEndpointGroupTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleNetworkSecurityInterceptEndpointGroupTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_network_security_intercept_endpoint_group google_network_security_intercept_endpoint_group}
*/
export declare class GoogleNetworkSecurityInterceptEndpointGroup extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_network_security_intercept_endpoint_group";
    /**
    * Generates CDKTF code for importing a GoogleNetworkSecurityInterceptEndpointGroup resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleNetworkSecurityInterceptEndpointGroup to import
    * @param importFromId The id of the existing GoogleNetworkSecurityInterceptEndpointGroup that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_network_security_intercept_endpoint_group#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleNetworkSecurityInterceptEndpointGroup to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_network_security_intercept_endpoint_group google_network_security_intercept_endpoint_group} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleNetworkSecurityInterceptEndpointGroupConfig
    */
    constructor(scope: Construct, id: string, config: GoogleNetworkSecurityInterceptEndpointGroupConfig);
    private _associations;
    get associations(): GoogleNetworkSecurityInterceptEndpointGroupAssociationsList;
    private _connectedDeploymentGroup;
    get connectedDeploymentGroup(): GoogleNetworkSecurityInterceptEndpointGroupConnectedDeploymentGroupList;
    get createTime(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _interceptDeploymentGroup?;
    get interceptDeploymentGroup(): string;
    set interceptDeploymentGroup(value: string);
    get interceptDeploymentGroupInput(): string | undefined;
    private _interceptEndpointGroupId?;
    get interceptEndpointGroupId(): string;
    set interceptEndpointGroupId(value: string);
    get interceptEndpointGroupIdInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get reconciling(): cdktf.IResolvable;
    get state(): string;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get updateTime(): string;
    private _timeouts;
    get timeouts(): GoogleNetworkSecurityInterceptEndpointGroupTimeoutsOutputReference;
    putTimeouts(value: GoogleNetworkSecurityInterceptEndpointGroupTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleNetworkSecurityInterceptEndpointGroupTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
