/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleParameterManagerRegionalParameterVersionConfig extends cdktf.TerraformMetaArguments {
    /**
    * The current state of Regional Parameter Version. This field is only applicable for updating Regional Parameter Version.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_parameter_manager_regional_parameter_version#disabled GoogleParameterManagerRegionalParameterVersion#disabled}
    */
    readonly disabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_parameter_manager_regional_parameter_version#id GoogleParameterManagerRegionalParameterVersion#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Parameter Manager Regional Parameter resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_parameter_manager_regional_parameter_version#parameter GoogleParameterManagerRegionalParameterVersion#parameter}
    */
    readonly parameter: string;
    /**
    * The Regional Parameter data.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_parameter_manager_regional_parameter_version#parameter_data GoogleParameterManagerRegionalParameterVersion#parameter_data}
    */
    readonly parameterData: string;
    /**
    * Version ID of the Regional Parameter Version Resource. This must be unique within the Regional Parameter.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_parameter_manager_regional_parameter_version#parameter_version_id GoogleParameterManagerRegionalParameterVersion#parameter_version_id}
    */
    readonly parameterVersionId: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_parameter_manager_regional_parameter_version#timeouts GoogleParameterManagerRegionalParameterVersion#timeouts}
    */
    readonly timeouts?: GoogleParameterManagerRegionalParameterVersionTimeouts;
}
export interface GoogleParameterManagerRegionalParameterVersionTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_parameter_manager_regional_parameter_version#create GoogleParameterManagerRegionalParameterVersion#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_parameter_manager_regional_parameter_version#delete GoogleParameterManagerRegionalParameterVersion#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_parameter_manager_regional_parameter_version#update GoogleParameterManagerRegionalParameterVersion#update}
    */
    readonly update?: string;
}
export declare function googleParameterManagerRegionalParameterVersionTimeoutsToTerraform(struct?: GoogleParameterManagerRegionalParameterVersionTimeouts | cdktf.IResolvable): any;
export declare function googleParameterManagerRegionalParameterVersionTimeoutsToHclTerraform(struct?: GoogleParameterManagerRegionalParameterVersionTimeouts | cdktf.IResolvable): any;
export declare class GoogleParameterManagerRegionalParameterVersionTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleParameterManagerRegionalParameterVersionTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleParameterManagerRegionalParameterVersionTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_parameter_manager_regional_parameter_version google_parameter_manager_regional_parameter_version}
*/
export declare class GoogleParameterManagerRegionalParameterVersion extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_parameter_manager_regional_parameter_version";
    /**
    * Generates CDKTF code for importing a GoogleParameterManagerRegionalParameterVersion resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleParameterManagerRegionalParameterVersion to import
    * @param importFromId The id of the existing GoogleParameterManagerRegionalParameterVersion that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_parameter_manager_regional_parameter_version#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleParameterManagerRegionalParameterVersion to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_parameter_manager_regional_parameter_version google_parameter_manager_regional_parameter_version} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleParameterManagerRegionalParameterVersionConfig
    */
    constructor(scope: Construct, id: string, config: GoogleParameterManagerRegionalParameterVersionConfig);
    get createTime(): string;
    private _disabled?;
    get disabled(): boolean | cdktf.IResolvable;
    set disabled(value: boolean | cdktf.IResolvable);
    resetDisabled(): void;
    get disabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get kmsKeyVersion(): string;
    get location(): string;
    get name(): string;
    private _parameter?;
    get parameter(): string;
    set parameter(value: string);
    get parameterInput(): string | undefined;
    private _parameterData?;
    get parameterData(): string;
    set parameterData(value: string);
    get parameterDataInput(): string | undefined;
    private _parameterVersionId?;
    get parameterVersionId(): string;
    set parameterVersionId(value: string);
    get parameterVersionIdInput(): string | undefined;
    get updateTime(): string;
    private _timeouts;
    get timeouts(): GoogleParameterManagerRegionalParameterVersionTimeoutsOutputReference;
    putTimeouts(value: GoogleParameterManagerRegionalParameterVersionTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleParameterManagerRegionalParameterVersionTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
