/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleRedisClusterConfig extends cdktf.TerraformMetaArguments {
    /**
    * Optional. The authorization mode of the Redis cluster. If not provided, auth feature is disabled for the cluster. Default value: "AUTH_MODE_DISABLED" Possible values: ["AUTH_MODE_UNSPECIFIED", "AUTH_MODE_IAM_AUTH", "AUTH_MODE_DISABLED"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#authorization_mode GoogleRedisCluster#authorization_mode}
    */
    readonly authorizationMode?: string;
    /**
    * Optional. Indicates if the cluster is deletion protected or not.
    * If the value if set to true, any delete cluster operation will fail.
    * Default value is true.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#deletion_protection_enabled GoogleRedisCluster#deletion_protection_enabled}
    */
    readonly deletionProtectionEnabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#id GoogleRedisCluster#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The KMS key used to encrypt the at-rest data of the cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#kms_key GoogleRedisCluster#kms_key}
    */
    readonly kmsKey?: string;
    /**
    * Unique name of the resource in this scope including project and location using the form:
    * projects/{projectId}/locations/{locationId}/clusters/{clusterId}
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#name GoogleRedisCluster#name}
    */
    readonly name?: string;
    /**
    * The nodeType for the Redis cluster.
    * If not provided, REDIS_HIGHMEM_MEDIUM will be used as default Possible values: ["REDIS_SHARED_CORE_NANO", "REDIS_HIGHMEM_MEDIUM", "REDIS_HIGHMEM_XLARGE", "REDIS_STANDARD_SMALL"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#node_type GoogleRedisCluster#node_type}
    */
    readonly nodeType?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#project GoogleRedisCluster#project}
    */
    readonly project?: string;
    /**
    * Configure Redis Cluster behavior using a subset of native Redis configuration parameters.
    * Please check Memorystore documentation for the list of supported parameters:
    * https://cloud.google.com/memorystore/docs/cluster/supported-instance-configurations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#redis_configs GoogleRedisCluster#redis_configs}
    */
    readonly redisConfigs?: {
        [key: string]: string;
    };
    /**
    * The name of the region of the Redis cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#region GoogleRedisCluster#region}
    */
    readonly region?: string;
    /**
    * Optional. The number of replica nodes per shard.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#replica_count GoogleRedisCluster#replica_count}
    */
    readonly replicaCount?: number;
    /**
    * Required. Number of shards for the Redis cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#shard_count GoogleRedisCluster#shard_count}
    */
    readonly shardCount: number;
    /**
    * Optional. The in-transit encryption for the Redis cluster.
    * If not provided, encryption is disabled for the cluster. Default value: "TRANSIT_ENCRYPTION_MODE_DISABLED" Possible values: ["TRANSIT_ENCRYPTION_MODE_UNSPECIFIED", "TRANSIT_ENCRYPTION_MODE_DISABLED", "TRANSIT_ENCRYPTION_MODE_SERVER_AUTHENTICATION"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#transit_encryption_mode GoogleRedisCluster#transit_encryption_mode}
    */
    readonly transitEncryptionMode?: string;
    /**
    * automated_backup_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#automated_backup_config GoogleRedisCluster#automated_backup_config}
    */
    readonly automatedBackupConfig?: GoogleRedisClusterAutomatedBackupConfig;
    /**
    * cross_cluster_replication_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#cross_cluster_replication_config GoogleRedisCluster#cross_cluster_replication_config}
    */
    readonly crossClusterReplicationConfig?: GoogleRedisClusterCrossClusterReplicationConfig;
    /**
    * gcs_source block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#gcs_source GoogleRedisCluster#gcs_source}
    */
    readonly gcsSource?: GoogleRedisClusterGcsSource;
    /**
    * maintenance_policy block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#maintenance_policy GoogleRedisCluster#maintenance_policy}
    */
    readonly maintenancePolicy?: GoogleRedisClusterMaintenancePolicy;
    /**
    * managed_backup_source block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#managed_backup_source GoogleRedisCluster#managed_backup_source}
    */
    readonly managedBackupSource?: GoogleRedisClusterManagedBackupSource;
    /**
    * persistence_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#persistence_config GoogleRedisCluster#persistence_config}
    */
    readonly persistenceConfig?: GoogleRedisClusterPersistenceConfig;
    /**
    * psc_configs block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#psc_configs GoogleRedisCluster#psc_configs}
    */
    readonly pscConfigs?: GoogleRedisClusterPscConfigs[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#timeouts GoogleRedisCluster#timeouts}
    */
    readonly timeouts?: GoogleRedisClusterTimeouts;
    /**
    * zone_distribution_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#zone_distribution_config GoogleRedisCluster#zone_distribution_config}
    */
    readonly zoneDistributionConfig?: GoogleRedisClusterZoneDistributionConfig;
}
export interface GoogleRedisClusterDiscoveryEndpointsPscConfig {
}
export declare function googleRedisClusterDiscoveryEndpointsPscConfigToTerraform(struct?: GoogleRedisClusterDiscoveryEndpointsPscConfig): any;
export declare function googleRedisClusterDiscoveryEndpointsPscConfigToHclTerraform(struct?: GoogleRedisClusterDiscoveryEndpointsPscConfig): any;
export declare class GoogleRedisClusterDiscoveryEndpointsPscConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleRedisClusterDiscoveryEndpointsPscConfig | undefined;
    set internalValue(value: GoogleRedisClusterDiscoveryEndpointsPscConfig | undefined);
    get network(): string;
}
export declare class GoogleRedisClusterDiscoveryEndpointsPscConfigList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleRedisClusterDiscoveryEndpointsPscConfigOutputReference;
}
export interface GoogleRedisClusterDiscoveryEndpoints {
}
export declare function googleRedisClusterDiscoveryEndpointsToTerraform(struct?: GoogleRedisClusterDiscoveryEndpoints): any;
export declare function googleRedisClusterDiscoveryEndpointsToHclTerraform(struct?: GoogleRedisClusterDiscoveryEndpoints): any;
export declare class GoogleRedisClusterDiscoveryEndpointsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleRedisClusterDiscoveryEndpoints | undefined;
    set internalValue(value: GoogleRedisClusterDiscoveryEndpoints | undefined);
    get address(): string;
    get port(): number;
    private _pscConfig;
    get pscConfig(): GoogleRedisClusterDiscoveryEndpointsPscConfigList;
}
export declare class GoogleRedisClusterDiscoveryEndpointsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleRedisClusterDiscoveryEndpointsOutputReference;
}
export interface GoogleRedisClusterMaintenanceSchedule {
}
export declare function googleRedisClusterMaintenanceScheduleToTerraform(struct?: GoogleRedisClusterMaintenanceSchedule): any;
export declare function googleRedisClusterMaintenanceScheduleToHclTerraform(struct?: GoogleRedisClusterMaintenanceSchedule): any;
export declare class GoogleRedisClusterMaintenanceScheduleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleRedisClusterMaintenanceSchedule | undefined;
    set internalValue(value: GoogleRedisClusterMaintenanceSchedule | undefined);
    get endTime(): string;
    get scheduleDeadlineTime(): string;
    get startTime(): string;
}
export declare class GoogleRedisClusterMaintenanceScheduleList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleRedisClusterMaintenanceScheduleOutputReference;
}
export interface GoogleRedisClusterPscConnections {
}
export declare function googleRedisClusterPscConnectionsToTerraform(struct?: GoogleRedisClusterPscConnections): any;
export declare function googleRedisClusterPscConnectionsToHclTerraform(struct?: GoogleRedisClusterPscConnections): any;
export declare class GoogleRedisClusterPscConnectionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleRedisClusterPscConnections | undefined;
    set internalValue(value: GoogleRedisClusterPscConnections | undefined);
    get address(): string;
    get forwardingRule(): string;
    get network(): string;
    get projectId(): string;
    get pscConnectionId(): string;
}
export declare class GoogleRedisClusterPscConnectionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleRedisClusterPscConnectionsOutputReference;
}
export interface GoogleRedisClusterPscServiceAttachments {
}
export declare function googleRedisClusterPscServiceAttachmentsToTerraform(struct?: GoogleRedisClusterPscServiceAttachments): any;
export declare function googleRedisClusterPscServiceAttachmentsToHclTerraform(struct?: GoogleRedisClusterPscServiceAttachments): any;
export declare class GoogleRedisClusterPscServiceAttachmentsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleRedisClusterPscServiceAttachments | undefined;
    set internalValue(value: GoogleRedisClusterPscServiceAttachments | undefined);
    get connectionType(): string;
    get serviceAttachment(): string;
}
export declare class GoogleRedisClusterPscServiceAttachmentsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleRedisClusterPscServiceAttachmentsOutputReference;
}
export interface GoogleRedisClusterStateInfoUpdateInfo {
}
export declare function googleRedisClusterStateInfoUpdateInfoToTerraform(struct?: GoogleRedisClusterStateInfoUpdateInfo): any;
export declare function googleRedisClusterStateInfoUpdateInfoToHclTerraform(struct?: GoogleRedisClusterStateInfoUpdateInfo): any;
export declare class GoogleRedisClusterStateInfoUpdateInfoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleRedisClusterStateInfoUpdateInfo | undefined;
    set internalValue(value: GoogleRedisClusterStateInfoUpdateInfo | undefined);
    get targetReplicaCount(): number;
    get targetShardCount(): number;
}
export declare class GoogleRedisClusterStateInfoUpdateInfoList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleRedisClusterStateInfoUpdateInfoOutputReference;
}
export interface GoogleRedisClusterStateInfo {
}
export declare function googleRedisClusterStateInfoToTerraform(struct?: GoogleRedisClusterStateInfo): any;
export declare function googleRedisClusterStateInfoToHclTerraform(struct?: GoogleRedisClusterStateInfo): any;
export declare class GoogleRedisClusterStateInfoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleRedisClusterStateInfo | undefined;
    set internalValue(value: GoogleRedisClusterStateInfo | undefined);
    private _updateInfo;
    get updateInfo(): GoogleRedisClusterStateInfoUpdateInfoList;
}
export declare class GoogleRedisClusterStateInfoList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleRedisClusterStateInfoOutputReference;
}
export interface GoogleRedisClusterAutomatedBackupConfigFixedFrequencyScheduleStartTime {
    /**
    * Hours of a day in 24 hour format. Must be greater than or equal to 0 and typically must be less than or equal to 23.
    * An API may choose to allow the value "24:00:00" for scenarios like business closing time.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#hours GoogleRedisCluster#hours}
    */
    readonly hours: number;
}
export declare function googleRedisClusterAutomatedBackupConfigFixedFrequencyScheduleStartTimeToTerraform(struct?: GoogleRedisClusterAutomatedBackupConfigFixedFrequencyScheduleStartTimeOutputReference | GoogleRedisClusterAutomatedBackupConfigFixedFrequencyScheduleStartTime): any;
export declare function googleRedisClusterAutomatedBackupConfigFixedFrequencyScheduleStartTimeToHclTerraform(struct?: GoogleRedisClusterAutomatedBackupConfigFixedFrequencyScheduleStartTimeOutputReference | GoogleRedisClusterAutomatedBackupConfigFixedFrequencyScheduleStartTime): any;
export declare class GoogleRedisClusterAutomatedBackupConfigFixedFrequencyScheduleStartTimeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleRedisClusterAutomatedBackupConfigFixedFrequencyScheduleStartTime | undefined;
    set internalValue(value: GoogleRedisClusterAutomatedBackupConfigFixedFrequencyScheduleStartTime | undefined);
    private _hours?;
    get hours(): number;
    set hours(value: number);
    get hoursInput(): number | undefined;
}
export interface GoogleRedisClusterAutomatedBackupConfigFixedFrequencySchedule {
    /**
    * start_time block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#start_time GoogleRedisCluster#start_time}
    */
    readonly startTime: GoogleRedisClusterAutomatedBackupConfigFixedFrequencyScheduleStartTime;
}
export declare function googleRedisClusterAutomatedBackupConfigFixedFrequencyScheduleToTerraform(struct?: GoogleRedisClusterAutomatedBackupConfigFixedFrequencyScheduleOutputReference | GoogleRedisClusterAutomatedBackupConfigFixedFrequencySchedule): any;
export declare function googleRedisClusterAutomatedBackupConfigFixedFrequencyScheduleToHclTerraform(struct?: GoogleRedisClusterAutomatedBackupConfigFixedFrequencyScheduleOutputReference | GoogleRedisClusterAutomatedBackupConfigFixedFrequencySchedule): any;
export declare class GoogleRedisClusterAutomatedBackupConfigFixedFrequencyScheduleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleRedisClusterAutomatedBackupConfigFixedFrequencySchedule | undefined;
    set internalValue(value: GoogleRedisClusterAutomatedBackupConfigFixedFrequencySchedule | undefined);
    private _startTime;
    get startTime(): GoogleRedisClusterAutomatedBackupConfigFixedFrequencyScheduleStartTimeOutputReference;
    putStartTime(value: GoogleRedisClusterAutomatedBackupConfigFixedFrequencyScheduleStartTime): void;
    get startTimeInput(): GoogleRedisClusterAutomatedBackupConfigFixedFrequencyScheduleStartTime | undefined;
}
export interface GoogleRedisClusterAutomatedBackupConfig {
    /**
    * How long to keep automated backups before the backups are deleted.
    * The value should be between 1 day and 365 days. If not specified, the default value is 35 days.
    * A duration in seconds with up to nine fractional digits, ending with 's'. Example: "3.5s".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#retention GoogleRedisCluster#retention}
    */
    readonly retention: string;
    /**
    * fixed_frequency_schedule block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#fixed_frequency_schedule GoogleRedisCluster#fixed_frequency_schedule}
    */
    readonly fixedFrequencySchedule: GoogleRedisClusterAutomatedBackupConfigFixedFrequencySchedule;
}
export declare function googleRedisClusterAutomatedBackupConfigToTerraform(struct?: GoogleRedisClusterAutomatedBackupConfigOutputReference | GoogleRedisClusterAutomatedBackupConfig): any;
export declare function googleRedisClusterAutomatedBackupConfigToHclTerraform(struct?: GoogleRedisClusterAutomatedBackupConfigOutputReference | GoogleRedisClusterAutomatedBackupConfig): any;
export declare class GoogleRedisClusterAutomatedBackupConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleRedisClusterAutomatedBackupConfig | undefined;
    set internalValue(value: GoogleRedisClusterAutomatedBackupConfig | undefined);
    private _retention?;
    get retention(): string;
    set retention(value: string);
    get retentionInput(): string | undefined;
    private _fixedFrequencySchedule;
    get fixedFrequencySchedule(): GoogleRedisClusterAutomatedBackupConfigFixedFrequencyScheduleOutputReference;
    putFixedFrequencySchedule(value: GoogleRedisClusterAutomatedBackupConfigFixedFrequencySchedule): void;
    get fixedFrequencyScheduleInput(): GoogleRedisClusterAutomatedBackupConfigFixedFrequencySchedule | undefined;
}
export interface GoogleRedisClusterCrossClusterReplicationConfigMembershipPrimaryCluster {
}
export declare function googleRedisClusterCrossClusterReplicationConfigMembershipPrimaryClusterToTerraform(struct?: GoogleRedisClusterCrossClusterReplicationConfigMembershipPrimaryCluster): any;
export declare function googleRedisClusterCrossClusterReplicationConfigMembershipPrimaryClusterToHclTerraform(struct?: GoogleRedisClusterCrossClusterReplicationConfigMembershipPrimaryCluster): any;
export declare class GoogleRedisClusterCrossClusterReplicationConfigMembershipPrimaryClusterOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleRedisClusterCrossClusterReplicationConfigMembershipPrimaryCluster | undefined;
    set internalValue(value: GoogleRedisClusterCrossClusterReplicationConfigMembershipPrimaryCluster | undefined);
    get cluster(): string;
    get uid(): string;
}
export declare class GoogleRedisClusterCrossClusterReplicationConfigMembershipPrimaryClusterList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleRedisClusterCrossClusterReplicationConfigMembershipPrimaryClusterOutputReference;
}
export interface GoogleRedisClusterCrossClusterReplicationConfigMembershipSecondaryClusters {
}
export declare function googleRedisClusterCrossClusterReplicationConfigMembershipSecondaryClustersToTerraform(struct?: GoogleRedisClusterCrossClusterReplicationConfigMembershipSecondaryClusters): any;
export declare function googleRedisClusterCrossClusterReplicationConfigMembershipSecondaryClustersToHclTerraform(struct?: GoogleRedisClusterCrossClusterReplicationConfigMembershipSecondaryClusters): any;
export declare class GoogleRedisClusterCrossClusterReplicationConfigMembershipSecondaryClustersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleRedisClusterCrossClusterReplicationConfigMembershipSecondaryClusters | undefined;
    set internalValue(value: GoogleRedisClusterCrossClusterReplicationConfigMembershipSecondaryClusters | undefined);
    get cluster(): string;
    get uid(): string;
}
export declare class GoogleRedisClusterCrossClusterReplicationConfigMembershipSecondaryClustersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleRedisClusterCrossClusterReplicationConfigMembershipSecondaryClustersOutputReference;
}
export interface GoogleRedisClusterCrossClusterReplicationConfigMembership {
}
export declare function googleRedisClusterCrossClusterReplicationConfigMembershipToTerraform(struct?: GoogleRedisClusterCrossClusterReplicationConfigMembership): any;
export declare function googleRedisClusterCrossClusterReplicationConfigMembershipToHclTerraform(struct?: GoogleRedisClusterCrossClusterReplicationConfigMembership): any;
export declare class GoogleRedisClusterCrossClusterReplicationConfigMembershipOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleRedisClusterCrossClusterReplicationConfigMembership | undefined;
    set internalValue(value: GoogleRedisClusterCrossClusterReplicationConfigMembership | undefined);
    private _primaryCluster;
    get primaryCluster(): GoogleRedisClusterCrossClusterReplicationConfigMembershipPrimaryClusterList;
    private _secondaryClusters;
    get secondaryClusters(): GoogleRedisClusterCrossClusterReplicationConfigMembershipSecondaryClustersList;
}
export declare class GoogleRedisClusterCrossClusterReplicationConfigMembershipList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleRedisClusterCrossClusterReplicationConfigMembershipOutputReference;
}
export interface GoogleRedisClusterCrossClusterReplicationConfigPrimaryCluster {
    /**
    * The full resource path of the primary cluster in the format: projects/{project}/locations/{region}/clusters/{cluster-id}
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#cluster GoogleRedisCluster#cluster}
    */
    readonly cluster?: string;
}
export declare function googleRedisClusterCrossClusterReplicationConfigPrimaryClusterToTerraform(struct?: GoogleRedisClusterCrossClusterReplicationConfigPrimaryClusterOutputReference | GoogleRedisClusterCrossClusterReplicationConfigPrimaryCluster): any;
export declare function googleRedisClusterCrossClusterReplicationConfigPrimaryClusterToHclTerraform(struct?: GoogleRedisClusterCrossClusterReplicationConfigPrimaryClusterOutputReference | GoogleRedisClusterCrossClusterReplicationConfigPrimaryCluster): any;
export declare class GoogleRedisClusterCrossClusterReplicationConfigPrimaryClusterOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleRedisClusterCrossClusterReplicationConfigPrimaryCluster | undefined;
    set internalValue(value: GoogleRedisClusterCrossClusterReplicationConfigPrimaryCluster | undefined);
    private _cluster?;
    get cluster(): string;
    set cluster(value: string);
    resetCluster(): void;
    get clusterInput(): string | undefined;
    get uid(): string;
}
export interface GoogleRedisClusterCrossClusterReplicationConfigSecondaryClusters {
    /**
    * The full resource path of the secondary cluster in the format: projects/{project}/locations/{region}/clusters/{cluster-id}
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#cluster GoogleRedisCluster#cluster}
    */
    readonly cluster?: string;
}
export declare function googleRedisClusterCrossClusterReplicationConfigSecondaryClustersToTerraform(struct?: GoogleRedisClusterCrossClusterReplicationConfigSecondaryClusters | cdktf.IResolvable): any;
export declare function googleRedisClusterCrossClusterReplicationConfigSecondaryClustersToHclTerraform(struct?: GoogleRedisClusterCrossClusterReplicationConfigSecondaryClusters | cdktf.IResolvable): any;
export declare class GoogleRedisClusterCrossClusterReplicationConfigSecondaryClustersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleRedisClusterCrossClusterReplicationConfigSecondaryClusters | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleRedisClusterCrossClusterReplicationConfigSecondaryClusters | cdktf.IResolvable | undefined);
    private _cluster?;
    get cluster(): string;
    set cluster(value: string);
    resetCluster(): void;
    get clusterInput(): string | undefined;
    get uid(): string;
}
export declare class GoogleRedisClusterCrossClusterReplicationConfigSecondaryClustersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleRedisClusterCrossClusterReplicationConfigSecondaryClusters[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleRedisClusterCrossClusterReplicationConfigSecondaryClustersOutputReference;
}
export interface GoogleRedisClusterCrossClusterReplicationConfig {
    /**
    * The role of the cluster in cross cluster replication. Supported values are:
    *
    * 1. 'CLUSTER_ROLE_UNSPECIFIED': This is an independent cluster that has never participated in cross cluster replication. It allows both reads and writes.
    *
    * 1. 'NONE': This is an independent cluster that previously participated in cross cluster replication(either as a 'PRIMARY' or 'SECONDARY' cluster). It allows both reads and writes.
    *
    * 1. 'PRIMARY': This cluster serves as the replication source for secondary clusters that are replicating from it. Any data written to it is automatically replicated to its secondary clusters. It allows both reads and writes.
    *
    * 1. 'SECONDARY': This cluster replicates data from the primary cluster. It allows only reads. Possible values: ["CLUSTER_ROLE_UNSPECIFIED", "NONE", "PRIMARY", "SECONDARY"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#cluster_role GoogleRedisCluster#cluster_role}
    */
    readonly clusterRole?: string;
    /**
    * primary_cluster block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#primary_cluster GoogleRedisCluster#primary_cluster}
    */
    readonly primaryCluster?: GoogleRedisClusterCrossClusterReplicationConfigPrimaryCluster;
    /**
    * secondary_clusters block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#secondary_clusters GoogleRedisCluster#secondary_clusters}
    */
    readonly secondaryClusters?: GoogleRedisClusterCrossClusterReplicationConfigSecondaryClusters[] | cdktf.IResolvable;
}
export declare function googleRedisClusterCrossClusterReplicationConfigToTerraform(struct?: GoogleRedisClusterCrossClusterReplicationConfigOutputReference | GoogleRedisClusterCrossClusterReplicationConfig): any;
export declare function googleRedisClusterCrossClusterReplicationConfigToHclTerraform(struct?: GoogleRedisClusterCrossClusterReplicationConfigOutputReference | GoogleRedisClusterCrossClusterReplicationConfig): any;
export declare class GoogleRedisClusterCrossClusterReplicationConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleRedisClusterCrossClusterReplicationConfig | undefined;
    set internalValue(value: GoogleRedisClusterCrossClusterReplicationConfig | undefined);
    private _clusterRole?;
    get clusterRole(): string;
    set clusterRole(value: string);
    resetClusterRole(): void;
    get clusterRoleInput(): string | undefined;
    private _membership;
    get membership(): GoogleRedisClusterCrossClusterReplicationConfigMembershipList;
    get updateTime(): string;
    private _primaryCluster;
    get primaryCluster(): GoogleRedisClusterCrossClusterReplicationConfigPrimaryClusterOutputReference;
    putPrimaryCluster(value: GoogleRedisClusterCrossClusterReplicationConfigPrimaryCluster): void;
    resetPrimaryCluster(): void;
    get primaryClusterInput(): GoogleRedisClusterCrossClusterReplicationConfigPrimaryCluster | undefined;
    private _secondaryClusters;
    get secondaryClusters(): GoogleRedisClusterCrossClusterReplicationConfigSecondaryClustersList;
    putSecondaryClusters(value: GoogleRedisClusterCrossClusterReplicationConfigSecondaryClusters[] | cdktf.IResolvable): void;
    resetSecondaryClusters(): void;
    get secondaryClustersInput(): cdktf.IResolvable | GoogleRedisClusterCrossClusterReplicationConfigSecondaryClusters[] | undefined;
}
export interface GoogleRedisClusterGcsSource {
    /**
    * URIs of the GCS objects to import. Example: gs://bucket1/object1, gs://bucket2/folder2/object2
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#uris GoogleRedisCluster#uris}
    */
    readonly uris: string[];
}
export declare function googleRedisClusterGcsSourceToTerraform(struct?: GoogleRedisClusterGcsSourceOutputReference | GoogleRedisClusterGcsSource): any;
export declare function googleRedisClusterGcsSourceToHclTerraform(struct?: GoogleRedisClusterGcsSourceOutputReference | GoogleRedisClusterGcsSource): any;
export declare class GoogleRedisClusterGcsSourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleRedisClusterGcsSource | undefined;
    set internalValue(value: GoogleRedisClusterGcsSource | undefined);
    private _uris?;
    get uris(): string[];
    set uris(value: string[]);
    get urisInput(): string[] | undefined;
}
export interface GoogleRedisClusterMaintenancePolicyWeeklyMaintenanceWindowStartTime {
    /**
    * Hours of day in 24 hour format. Should be from 0 to 23.
    * An API may choose to allow the value "24:00:00" for scenarios like business closing time.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#hours GoogleRedisCluster#hours}
    */
    readonly hours?: number;
    /**
    * Minutes of hour of day. Must be from 0 to 59.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#minutes GoogleRedisCluster#minutes}
    */
    readonly minutes?: number;
    /**
    * Fractions of seconds in nanoseconds. Must be from 0 to 999,999,999.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#nanos GoogleRedisCluster#nanos}
    */
    readonly nanos?: number;
    /**
    * Seconds of minutes of the time. Must normally be from 0 to 59.
    * An API may allow the value 60 if it allows leap-seconds.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#seconds GoogleRedisCluster#seconds}
    */
    readonly seconds?: number;
}
export declare function googleRedisClusterMaintenancePolicyWeeklyMaintenanceWindowStartTimeToTerraform(struct?: GoogleRedisClusterMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference | GoogleRedisClusterMaintenancePolicyWeeklyMaintenanceWindowStartTime): any;
export declare function googleRedisClusterMaintenancePolicyWeeklyMaintenanceWindowStartTimeToHclTerraform(struct?: GoogleRedisClusterMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference | GoogleRedisClusterMaintenancePolicyWeeklyMaintenanceWindowStartTime): any;
export declare class GoogleRedisClusterMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleRedisClusterMaintenancePolicyWeeklyMaintenanceWindowStartTime | undefined;
    set internalValue(value: GoogleRedisClusterMaintenancePolicyWeeklyMaintenanceWindowStartTime | undefined);
    private _hours?;
    get hours(): number;
    set hours(value: number);
    resetHours(): void;
    get hoursInput(): number | undefined;
    private _minutes?;
    get minutes(): number;
    set minutes(value: number);
    resetMinutes(): void;
    get minutesInput(): number | undefined;
    private _nanos?;
    get nanos(): number;
    set nanos(value: number);
    resetNanos(): void;
    get nanosInput(): number | undefined;
    private _seconds?;
    get seconds(): number;
    set seconds(value: number);
    resetSeconds(): void;
    get secondsInput(): number | undefined;
}
export interface GoogleRedisClusterMaintenancePolicyWeeklyMaintenanceWindow {
    /**
    * Required. The day of week that maintenance updates occur.
    *
    * - DAY_OF_WEEK_UNSPECIFIED: The day of the week is unspecified.
    * - MONDAY: Monday
    * - TUESDAY: Tuesday
    * - WEDNESDAY: Wednesday
    * - THURSDAY: Thursday
    * - FRIDAY: Friday
    * - SATURDAY: Saturday
    * - SUNDAY: Sunday Possible values: ["DAY_OF_WEEK_UNSPECIFIED", "MONDAY", "TUESDAY", "WEDNESDAY", "THURSDAY", "FRIDAY", "SATURDAY", "SUNDAY"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#day GoogleRedisCluster#day}
    */
    readonly day: string;
    /**
    * start_time block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#start_time GoogleRedisCluster#start_time}
    */
    readonly startTime: GoogleRedisClusterMaintenancePolicyWeeklyMaintenanceWindowStartTime;
}
export declare function googleRedisClusterMaintenancePolicyWeeklyMaintenanceWindowToTerraform(struct?: GoogleRedisClusterMaintenancePolicyWeeklyMaintenanceWindow | cdktf.IResolvable): any;
export declare function googleRedisClusterMaintenancePolicyWeeklyMaintenanceWindowToHclTerraform(struct?: GoogleRedisClusterMaintenancePolicyWeeklyMaintenanceWindow | cdktf.IResolvable): any;
export declare class GoogleRedisClusterMaintenancePolicyWeeklyMaintenanceWindowOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleRedisClusterMaintenancePolicyWeeklyMaintenanceWindow | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleRedisClusterMaintenancePolicyWeeklyMaintenanceWindow | cdktf.IResolvable | undefined);
    private _day?;
    get day(): string;
    set day(value: string);
    get dayInput(): string | undefined;
    get duration(): string;
    private _startTime;
    get startTime(): GoogleRedisClusterMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference;
    putStartTime(value: GoogleRedisClusterMaintenancePolicyWeeklyMaintenanceWindowStartTime): void;
    get startTimeInput(): GoogleRedisClusterMaintenancePolicyWeeklyMaintenanceWindowStartTime | undefined;
}
export declare class GoogleRedisClusterMaintenancePolicyWeeklyMaintenanceWindowList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleRedisClusterMaintenancePolicyWeeklyMaintenanceWindow[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleRedisClusterMaintenancePolicyWeeklyMaintenanceWindowOutputReference;
}
export interface GoogleRedisClusterMaintenancePolicy {
    /**
    * weekly_maintenance_window block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#weekly_maintenance_window GoogleRedisCluster#weekly_maintenance_window}
    */
    readonly weeklyMaintenanceWindow?: GoogleRedisClusterMaintenancePolicyWeeklyMaintenanceWindow[] | cdktf.IResolvable;
}
export declare function googleRedisClusterMaintenancePolicyToTerraform(struct?: GoogleRedisClusterMaintenancePolicyOutputReference | GoogleRedisClusterMaintenancePolicy): any;
export declare function googleRedisClusterMaintenancePolicyToHclTerraform(struct?: GoogleRedisClusterMaintenancePolicyOutputReference | GoogleRedisClusterMaintenancePolicy): any;
export declare class GoogleRedisClusterMaintenancePolicyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleRedisClusterMaintenancePolicy | undefined;
    set internalValue(value: GoogleRedisClusterMaintenancePolicy | undefined);
    get createTime(): string;
    get updateTime(): string;
    private _weeklyMaintenanceWindow;
    get weeklyMaintenanceWindow(): GoogleRedisClusterMaintenancePolicyWeeklyMaintenanceWindowList;
    putWeeklyMaintenanceWindow(value: GoogleRedisClusterMaintenancePolicyWeeklyMaintenanceWindow[] | cdktf.IResolvable): void;
    resetWeeklyMaintenanceWindow(): void;
    get weeklyMaintenanceWindowInput(): cdktf.IResolvable | GoogleRedisClusterMaintenancePolicyWeeklyMaintenanceWindow[] | undefined;
}
export interface GoogleRedisClusterManagedBackupSource {
    /**
    * Example: //redis.googleapis.com/projects/{project}/locations/{location}/backupCollections/{collection}/backups/{backup} A shorter version (without the prefix) of the backup name is also supported,
    * like projects/{project}/locations/{location}/backupCollections/{collection}/backups/{backupId}. In this case, it assumes the backup is under redis.googleapis.com.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#backup GoogleRedisCluster#backup}
    */
    readonly backup: string;
}
export declare function googleRedisClusterManagedBackupSourceToTerraform(struct?: GoogleRedisClusterManagedBackupSourceOutputReference | GoogleRedisClusterManagedBackupSource): any;
export declare function googleRedisClusterManagedBackupSourceToHclTerraform(struct?: GoogleRedisClusterManagedBackupSourceOutputReference | GoogleRedisClusterManagedBackupSource): any;
export declare class GoogleRedisClusterManagedBackupSourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleRedisClusterManagedBackupSource | undefined;
    set internalValue(value: GoogleRedisClusterManagedBackupSource | undefined);
    private _backup?;
    get backup(): string;
    set backup(value: string);
    get backupInput(): string | undefined;
}
export interface GoogleRedisClusterPersistenceConfigAofConfig {
    /**
    * Optional. Available fsync modes.
    *
    * - NO - Do not explicitly call fsync(). Rely on OS defaults.
    * - EVERYSEC - Call fsync() once per second in a background thread. A balance between performance and durability.
    * - ALWAYS - Call fsync() for earch write command. Possible values: ["APPEND_FSYNC_UNSPECIFIED", "NO", "EVERYSEC", "ALWAYS"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#append_fsync GoogleRedisCluster#append_fsync}
    */
    readonly appendFsync?: string;
}
export declare function googleRedisClusterPersistenceConfigAofConfigToTerraform(struct?: GoogleRedisClusterPersistenceConfigAofConfigOutputReference | GoogleRedisClusterPersistenceConfigAofConfig): any;
export declare function googleRedisClusterPersistenceConfigAofConfigToHclTerraform(struct?: GoogleRedisClusterPersistenceConfigAofConfigOutputReference | GoogleRedisClusterPersistenceConfigAofConfig): any;
export declare class GoogleRedisClusterPersistenceConfigAofConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleRedisClusterPersistenceConfigAofConfig | undefined;
    set internalValue(value: GoogleRedisClusterPersistenceConfigAofConfig | undefined);
    private _appendFsync?;
    get appendFsync(): string;
    set appendFsync(value: string);
    resetAppendFsync(): void;
    get appendFsyncInput(): string | undefined;
}
export interface GoogleRedisClusterPersistenceConfigRdbConfig {
    /**
    * Optional. Available snapshot periods for scheduling.
    *
    * - ONE_HOUR:	Snapshot every 1 hour.
    * - SIX_HOURS:	Snapshot every 6 hours.
    * - TWELVE_HOURS:	Snapshot every 12 hours.
    * - TWENTY_FOUR_HOURS:	Snapshot every 24 hours. Possible values: ["SNAPSHOT_PERIOD_UNSPECIFIED", "ONE_HOUR", "SIX_HOURS", "TWELVE_HOURS", "TWENTY_FOUR_HOURS"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#rdb_snapshot_period GoogleRedisCluster#rdb_snapshot_period}
    */
    readonly rdbSnapshotPeriod?: string;
    /**
    * The time that the first snapshot was/will be attempted, and to which
    * future snapshots will be aligned.
    * If not provided, the current time will be used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#rdb_snapshot_start_time GoogleRedisCluster#rdb_snapshot_start_time}
    */
    readonly rdbSnapshotStartTime?: string;
}
export declare function googleRedisClusterPersistenceConfigRdbConfigToTerraform(struct?: GoogleRedisClusterPersistenceConfigRdbConfigOutputReference | GoogleRedisClusterPersistenceConfigRdbConfig): any;
export declare function googleRedisClusterPersistenceConfigRdbConfigToHclTerraform(struct?: GoogleRedisClusterPersistenceConfigRdbConfigOutputReference | GoogleRedisClusterPersistenceConfigRdbConfig): any;
export declare class GoogleRedisClusterPersistenceConfigRdbConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleRedisClusterPersistenceConfigRdbConfig | undefined;
    set internalValue(value: GoogleRedisClusterPersistenceConfigRdbConfig | undefined);
    private _rdbSnapshotPeriod?;
    get rdbSnapshotPeriod(): string;
    set rdbSnapshotPeriod(value: string);
    resetRdbSnapshotPeriod(): void;
    get rdbSnapshotPeriodInput(): string | undefined;
    private _rdbSnapshotStartTime?;
    get rdbSnapshotStartTime(): string;
    set rdbSnapshotStartTime(value: string);
    resetRdbSnapshotStartTime(): void;
    get rdbSnapshotStartTimeInput(): string | undefined;
}
export interface GoogleRedisClusterPersistenceConfig {
    /**
    * Optional. Controls whether Persistence features are enabled. If not provided, the existing value will be used.
    *
    * - DISABLED: 	Persistence (both backup and restore) is disabled for the cluster.
    * - RDB: RDB based Persistence is enabled.
    * - AOF: AOF based Persistence is enabled. Possible values: ["PERSISTENCE_MODE_UNSPECIFIED", "DISABLED", "RDB", "AOF"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#mode GoogleRedisCluster#mode}
    */
    readonly mode?: string;
    /**
    * aof_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#aof_config GoogleRedisCluster#aof_config}
    */
    readonly aofConfig?: GoogleRedisClusterPersistenceConfigAofConfig;
    /**
    * rdb_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#rdb_config GoogleRedisCluster#rdb_config}
    */
    readonly rdbConfig?: GoogleRedisClusterPersistenceConfigRdbConfig;
}
export declare function googleRedisClusterPersistenceConfigToTerraform(struct?: GoogleRedisClusterPersistenceConfigOutputReference | GoogleRedisClusterPersistenceConfig): any;
export declare function googleRedisClusterPersistenceConfigToHclTerraform(struct?: GoogleRedisClusterPersistenceConfigOutputReference | GoogleRedisClusterPersistenceConfig): any;
export declare class GoogleRedisClusterPersistenceConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleRedisClusterPersistenceConfig | undefined;
    set internalValue(value: GoogleRedisClusterPersistenceConfig | undefined);
    private _mode?;
    get mode(): string;
    set mode(value: string);
    resetMode(): void;
    get modeInput(): string | undefined;
    private _aofConfig;
    get aofConfig(): GoogleRedisClusterPersistenceConfigAofConfigOutputReference;
    putAofConfig(value: GoogleRedisClusterPersistenceConfigAofConfig): void;
    resetAofConfig(): void;
    get aofConfigInput(): GoogleRedisClusterPersistenceConfigAofConfig | undefined;
    private _rdbConfig;
    get rdbConfig(): GoogleRedisClusterPersistenceConfigRdbConfigOutputReference;
    putRdbConfig(value: GoogleRedisClusterPersistenceConfigRdbConfig): void;
    resetRdbConfig(): void;
    get rdbConfigInput(): GoogleRedisClusterPersistenceConfigRdbConfig | undefined;
}
export interface GoogleRedisClusterPscConfigs {
    /**
    * Required. The consumer network where the network address of
    * the discovery endpoint will be reserved, in the form of
    * projects/{network_project_id_or_number}/global/networks/{network_id}.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#network GoogleRedisCluster#network}
    */
    readonly network: string;
}
export declare function googleRedisClusterPscConfigsToTerraform(struct?: GoogleRedisClusterPscConfigs | cdktf.IResolvable): any;
export declare function googleRedisClusterPscConfigsToHclTerraform(struct?: GoogleRedisClusterPscConfigs | cdktf.IResolvable): any;
export declare class GoogleRedisClusterPscConfigsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleRedisClusterPscConfigs | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleRedisClusterPscConfigs | cdktf.IResolvable | undefined);
    private _network?;
    get network(): string;
    set network(value: string);
    get networkInput(): string | undefined;
}
export declare class GoogleRedisClusterPscConfigsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleRedisClusterPscConfigs[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleRedisClusterPscConfigsOutputReference;
}
export interface GoogleRedisClusterTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#create GoogleRedisCluster#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#delete GoogleRedisCluster#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#update GoogleRedisCluster#update}
    */
    readonly update?: string;
}
export declare function googleRedisClusterTimeoutsToTerraform(struct?: GoogleRedisClusterTimeouts | cdktf.IResolvable): any;
export declare function googleRedisClusterTimeoutsToHclTerraform(struct?: GoogleRedisClusterTimeouts | cdktf.IResolvable): any;
export declare class GoogleRedisClusterTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleRedisClusterTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleRedisClusterTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
export interface GoogleRedisClusterZoneDistributionConfig {
    /**
    * Immutable. The mode for zone distribution for Memorystore Redis cluster.
    * If not provided, MULTI_ZONE will be used as default Possible values: ["MULTI_ZONE", "SINGLE_ZONE"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#mode GoogleRedisCluster#mode}
    */
    readonly mode?: string;
    /**
    * Immutable. The zone for single zone Memorystore Redis cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#zone GoogleRedisCluster#zone}
    */
    readonly zone?: string;
}
export declare function googleRedisClusterZoneDistributionConfigToTerraform(struct?: GoogleRedisClusterZoneDistributionConfigOutputReference | GoogleRedisClusterZoneDistributionConfig): any;
export declare function googleRedisClusterZoneDistributionConfigToHclTerraform(struct?: GoogleRedisClusterZoneDistributionConfigOutputReference | GoogleRedisClusterZoneDistributionConfig): any;
export declare class GoogleRedisClusterZoneDistributionConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleRedisClusterZoneDistributionConfig | undefined;
    set internalValue(value: GoogleRedisClusterZoneDistributionConfig | undefined);
    private _mode?;
    get mode(): string;
    set mode(value: string);
    resetMode(): void;
    get modeInput(): string | undefined;
    private _zone?;
    get zone(): string;
    set zone(value: string);
    resetZone(): void;
    get zoneInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster google_redis_cluster}
*/
export declare class GoogleRedisCluster extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_redis_cluster";
    /**
    * Generates CDKTF code for importing a GoogleRedisCluster resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleRedisCluster to import
    * @param importFromId The id of the existing GoogleRedisCluster that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleRedisCluster to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_redis_cluster google_redis_cluster} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleRedisClusterConfig
    */
    constructor(scope: Construct, id: string, config: GoogleRedisClusterConfig);
    private _authorizationMode?;
    get authorizationMode(): string;
    set authorizationMode(value: string);
    resetAuthorizationMode(): void;
    get authorizationModeInput(): string | undefined;
    get backupCollection(): string;
    get createTime(): string;
    private _deletionProtectionEnabled?;
    get deletionProtectionEnabled(): boolean | cdktf.IResolvable;
    set deletionProtectionEnabled(value: boolean | cdktf.IResolvable);
    resetDeletionProtectionEnabled(): void;
    get deletionProtectionEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _discoveryEndpoints;
    get discoveryEndpoints(): GoogleRedisClusterDiscoveryEndpointsList;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _kmsKey?;
    get kmsKey(): string;
    set kmsKey(value: string);
    resetKmsKey(): void;
    get kmsKeyInput(): string | undefined;
    private _maintenanceSchedule;
    get maintenanceSchedule(): GoogleRedisClusterMaintenanceScheduleList;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _nodeType?;
    get nodeType(): string;
    set nodeType(value: string);
    resetNodeType(): void;
    get nodeTypeInput(): string | undefined;
    get preciseSizeGb(): number;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _pscConnections;
    get pscConnections(): GoogleRedisClusterPscConnectionsList;
    private _pscServiceAttachments;
    get pscServiceAttachments(): GoogleRedisClusterPscServiceAttachmentsList;
    private _redisConfigs?;
    get redisConfigs(): {
        [key: string]: string;
    };
    set redisConfigs(value: {
        [key: string]: string;
    });
    resetRedisConfigs(): void;
    get redisConfigsInput(): {
        [key: string]: string;
    } | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    resetRegion(): void;
    get regionInput(): string | undefined;
    private _replicaCount?;
    get replicaCount(): number;
    set replicaCount(value: number);
    resetReplicaCount(): void;
    get replicaCountInput(): number | undefined;
    private _shardCount?;
    get shardCount(): number;
    set shardCount(value: number);
    get shardCountInput(): number | undefined;
    get sizeGb(): number;
    get state(): string;
    private _stateInfo;
    get stateInfo(): GoogleRedisClusterStateInfoList;
    private _transitEncryptionMode?;
    get transitEncryptionMode(): string;
    set transitEncryptionMode(value: string);
    resetTransitEncryptionMode(): void;
    get transitEncryptionModeInput(): string | undefined;
    get uid(): string;
    private _automatedBackupConfig;
    get automatedBackupConfig(): GoogleRedisClusterAutomatedBackupConfigOutputReference;
    putAutomatedBackupConfig(value: GoogleRedisClusterAutomatedBackupConfig): void;
    resetAutomatedBackupConfig(): void;
    get automatedBackupConfigInput(): GoogleRedisClusterAutomatedBackupConfig | undefined;
    private _crossClusterReplicationConfig;
    get crossClusterReplicationConfig(): GoogleRedisClusterCrossClusterReplicationConfigOutputReference;
    putCrossClusterReplicationConfig(value: GoogleRedisClusterCrossClusterReplicationConfig): void;
    resetCrossClusterReplicationConfig(): void;
    get crossClusterReplicationConfigInput(): GoogleRedisClusterCrossClusterReplicationConfig | undefined;
    private _gcsSource;
    get gcsSource(): GoogleRedisClusterGcsSourceOutputReference;
    putGcsSource(value: GoogleRedisClusterGcsSource): void;
    resetGcsSource(): void;
    get gcsSourceInput(): GoogleRedisClusterGcsSource | undefined;
    private _maintenancePolicy;
    get maintenancePolicy(): GoogleRedisClusterMaintenancePolicyOutputReference;
    putMaintenancePolicy(value: GoogleRedisClusterMaintenancePolicy): void;
    resetMaintenancePolicy(): void;
    get maintenancePolicyInput(): GoogleRedisClusterMaintenancePolicy | undefined;
    private _managedBackupSource;
    get managedBackupSource(): GoogleRedisClusterManagedBackupSourceOutputReference;
    putManagedBackupSource(value: GoogleRedisClusterManagedBackupSource): void;
    resetManagedBackupSource(): void;
    get managedBackupSourceInput(): GoogleRedisClusterManagedBackupSource | undefined;
    private _persistenceConfig;
    get persistenceConfig(): GoogleRedisClusterPersistenceConfigOutputReference;
    putPersistenceConfig(value: GoogleRedisClusterPersistenceConfig): void;
    resetPersistenceConfig(): void;
    get persistenceConfigInput(): GoogleRedisClusterPersistenceConfig | undefined;
    private _pscConfigs;
    get pscConfigs(): GoogleRedisClusterPscConfigsList;
    putPscConfigs(value: GoogleRedisClusterPscConfigs[] | cdktf.IResolvable): void;
    resetPscConfigs(): void;
    get pscConfigsInput(): cdktf.IResolvable | GoogleRedisClusterPscConfigs[] | undefined;
    private _timeouts;
    get timeouts(): GoogleRedisClusterTimeoutsOutputReference;
    putTimeouts(value: GoogleRedisClusterTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleRedisClusterTimeouts | undefined;
    private _zoneDistributionConfig;
    get zoneDistributionConfig(): GoogleRedisClusterZoneDistributionConfigOutputReference;
    putZoneDistributionConfig(value: GoogleRedisClusterZoneDistributionConfig): void;
    resetZoneDistributionConfig(): void;
    get zoneDistributionConfigInput(): GoogleRedisClusterZoneDistributionConfig | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
