/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleResourceManagerCapabilityConfig extends cdktf.TerraformMetaArguments {
    /**
    * Capability name that should be updated on the folder.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_resource_manager_capability#capability_name GoogleResourceManagerCapability#capability_name}
    */
    readonly capabilityName: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_resource_manager_capability#id GoogleResourceManagerCapability#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Folder on which Capability needs to be updated in the format folders/folder_id.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_resource_manager_capability#parent GoogleResourceManagerCapability#parent}
    */
    readonly parent: string;
    /**
    * Capability Value.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_resource_manager_capability#value GoogleResourceManagerCapability#value}
    */
    readonly value: boolean | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_resource_manager_capability#timeouts GoogleResourceManagerCapability#timeouts}
    */
    readonly timeouts?: GoogleResourceManagerCapabilityTimeouts;
}
export interface GoogleResourceManagerCapabilityTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_resource_manager_capability#create GoogleResourceManagerCapability#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_resource_manager_capability#delete GoogleResourceManagerCapability#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_resource_manager_capability#update GoogleResourceManagerCapability#update}
    */
    readonly update?: string;
}
export declare function googleResourceManagerCapabilityTimeoutsToTerraform(struct?: GoogleResourceManagerCapabilityTimeouts | cdktf.IResolvable): any;
export declare function googleResourceManagerCapabilityTimeoutsToHclTerraform(struct?: GoogleResourceManagerCapabilityTimeouts | cdktf.IResolvable): any;
export declare class GoogleResourceManagerCapabilityTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleResourceManagerCapabilityTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleResourceManagerCapabilityTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_resource_manager_capability google_resource_manager_capability}
*/
export declare class GoogleResourceManagerCapability extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_resource_manager_capability";
    /**
    * Generates CDKTF code for importing a GoogleResourceManagerCapability resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleResourceManagerCapability to import
    * @param importFromId The id of the existing GoogleResourceManagerCapability that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_resource_manager_capability#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleResourceManagerCapability to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_resource_manager_capability google_resource_manager_capability} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleResourceManagerCapabilityConfig
    */
    constructor(scope: Construct, id: string, config: GoogleResourceManagerCapabilityConfig);
    private _capabilityName?;
    get capabilityName(): string;
    set capabilityName(value: string);
    get capabilityNameInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _parent?;
    get parent(): string;
    set parent(value: string);
    get parentInput(): string | undefined;
    private _value?;
    get value(): boolean | cdktf.IResolvable;
    set value(value: boolean | cdktf.IResolvable);
    get valueInput(): boolean | cdktf.IResolvable | undefined;
    private _timeouts;
    get timeouts(): GoogleResourceManagerCapabilityTimeoutsOutputReference;
    putTimeouts(value: GoogleResourceManagerCapabilityTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleResourceManagerCapabilityTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
