/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleStorageBatchOperationsJobConfig extends cdktf.TerraformMetaArguments {
    /**
    * If set to 'true', the storage batch operation job will not be deleted and new job will be created.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job#delete_protection GoogleStorageBatchOperationsJob#delete_protection}
    */
    readonly deleteProtection?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job#id GoogleStorageBatchOperationsJob#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The ID of the job.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job#job_id GoogleStorageBatchOperationsJob#job_id}
    */
    readonly jobId?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job#project GoogleStorageBatchOperationsJob#project}
    */
    readonly project?: string;
    /**
    * bucket_list block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job#bucket_list GoogleStorageBatchOperationsJob#bucket_list}
    */
    readonly bucketList?: GoogleStorageBatchOperationsJobBucketListStruct;
    /**
    * delete_object block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job#delete_object GoogleStorageBatchOperationsJob#delete_object}
    */
    readonly deleteObject?: GoogleStorageBatchOperationsJobDeleteObject;
    /**
    * put_metadata block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job#put_metadata GoogleStorageBatchOperationsJob#put_metadata}
    */
    readonly putMetadata?: GoogleStorageBatchOperationsJobPutMetadata;
    /**
    * put_object_hold block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job#put_object_hold GoogleStorageBatchOperationsJob#put_object_hold}
    */
    readonly putObjectHold?: GoogleStorageBatchOperationsJobPutObjectHold;
    /**
    * rewrite_object block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job#rewrite_object GoogleStorageBatchOperationsJob#rewrite_object}
    */
    readonly rewriteObject?: GoogleStorageBatchOperationsJobRewriteObject;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job#timeouts GoogleStorageBatchOperationsJob#timeouts}
    */
    readonly timeouts?: GoogleStorageBatchOperationsJobTimeouts;
}
export interface GoogleStorageBatchOperationsJobBucketListBucketsManifest {
    /**
    * Specifies objects in a manifest file.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job#manifest_location GoogleStorageBatchOperationsJob#manifest_location}
    */
    readonly manifestLocation?: string;
}
export declare function googleStorageBatchOperationsJobBucketListBucketsManifestToTerraform(struct?: GoogleStorageBatchOperationsJobBucketListBucketsManifestOutputReference | GoogleStorageBatchOperationsJobBucketListBucketsManifest): any;
export declare function googleStorageBatchOperationsJobBucketListBucketsManifestToHclTerraform(struct?: GoogleStorageBatchOperationsJobBucketListBucketsManifestOutputReference | GoogleStorageBatchOperationsJobBucketListBucketsManifest): any;
export declare class GoogleStorageBatchOperationsJobBucketListBucketsManifestOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleStorageBatchOperationsJobBucketListBucketsManifest | undefined;
    set internalValue(value: GoogleStorageBatchOperationsJobBucketListBucketsManifest | undefined);
    private _manifestLocation?;
    get manifestLocation(): string;
    set manifestLocation(value: string);
    resetManifestLocation(): void;
    get manifestLocationInput(): string | undefined;
}
export interface GoogleStorageBatchOperationsJobBucketListBucketsPrefixListStruct {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job#included_object_prefixes GoogleStorageBatchOperationsJob#included_object_prefixes}
    */
    readonly includedObjectPrefixes?: string[];
}
export declare function googleStorageBatchOperationsJobBucketListBucketsPrefixListStructToTerraform(struct?: GoogleStorageBatchOperationsJobBucketListBucketsPrefixListStructOutputReference | GoogleStorageBatchOperationsJobBucketListBucketsPrefixListStruct): any;
export declare function googleStorageBatchOperationsJobBucketListBucketsPrefixListStructToHclTerraform(struct?: GoogleStorageBatchOperationsJobBucketListBucketsPrefixListStructOutputReference | GoogleStorageBatchOperationsJobBucketListBucketsPrefixListStruct): any;
export declare class GoogleStorageBatchOperationsJobBucketListBucketsPrefixListStructOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleStorageBatchOperationsJobBucketListBucketsPrefixListStruct | undefined;
    set internalValue(value: GoogleStorageBatchOperationsJobBucketListBucketsPrefixListStruct | undefined);
    private _includedObjectPrefixes?;
    get includedObjectPrefixes(): string[];
    set includedObjectPrefixes(value: string[]);
    resetIncludedObjectPrefixes(): void;
    get includedObjectPrefixesInput(): string[] | undefined;
}
export interface GoogleStorageBatchOperationsJobBucketListBuckets {
    /**
    * Bucket name for the objects to be transformed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job#bucket GoogleStorageBatchOperationsJob#bucket}
    */
    readonly bucket: string;
    /**
    * manifest block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job#manifest GoogleStorageBatchOperationsJob#manifest}
    */
    readonly manifest?: GoogleStorageBatchOperationsJobBucketListBucketsManifest;
    /**
    * prefix_list block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job#prefix_list GoogleStorageBatchOperationsJob#prefix_list}
    */
    readonly prefixList?: GoogleStorageBatchOperationsJobBucketListBucketsPrefixListStruct;
}
export declare function googleStorageBatchOperationsJobBucketListBucketsToTerraform(struct?: GoogleStorageBatchOperationsJobBucketListBucketsOutputReference | GoogleStorageBatchOperationsJobBucketListBuckets): any;
export declare function googleStorageBatchOperationsJobBucketListBucketsToHclTerraform(struct?: GoogleStorageBatchOperationsJobBucketListBucketsOutputReference | GoogleStorageBatchOperationsJobBucketListBuckets): any;
export declare class GoogleStorageBatchOperationsJobBucketListBucketsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleStorageBatchOperationsJobBucketListBuckets | undefined;
    set internalValue(value: GoogleStorageBatchOperationsJobBucketListBuckets | undefined);
    private _bucket?;
    get bucket(): string;
    set bucket(value: string);
    get bucketInput(): string | undefined;
    private _manifest;
    get manifest(): GoogleStorageBatchOperationsJobBucketListBucketsManifestOutputReference;
    putManifest(value: GoogleStorageBatchOperationsJobBucketListBucketsManifest): void;
    resetManifest(): void;
    get manifestInput(): GoogleStorageBatchOperationsJobBucketListBucketsManifest | undefined;
    private _prefixList;
    get prefixList(): GoogleStorageBatchOperationsJobBucketListBucketsPrefixListStructOutputReference;
    putPrefixList(value: GoogleStorageBatchOperationsJobBucketListBucketsPrefixListStruct): void;
    resetPrefixList(): void;
    get prefixListInput(): GoogleStorageBatchOperationsJobBucketListBucketsPrefixListStruct | undefined;
}
export interface GoogleStorageBatchOperationsJobBucketListStruct {
    /**
    * buckets block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job#buckets GoogleStorageBatchOperationsJob#buckets}
    */
    readonly buckets: GoogleStorageBatchOperationsJobBucketListBuckets;
}
export declare function googleStorageBatchOperationsJobBucketListStructToTerraform(struct?: GoogleStorageBatchOperationsJobBucketListStructOutputReference | GoogleStorageBatchOperationsJobBucketListStruct): any;
export declare function googleStorageBatchOperationsJobBucketListStructToHclTerraform(struct?: GoogleStorageBatchOperationsJobBucketListStructOutputReference | GoogleStorageBatchOperationsJobBucketListStruct): any;
export declare class GoogleStorageBatchOperationsJobBucketListStructOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleStorageBatchOperationsJobBucketListStruct | undefined;
    set internalValue(value: GoogleStorageBatchOperationsJobBucketListStruct | undefined);
    private _buckets;
    get buckets(): GoogleStorageBatchOperationsJobBucketListBucketsOutputReference;
    putBuckets(value: GoogleStorageBatchOperationsJobBucketListBuckets): void;
    get bucketsInput(): GoogleStorageBatchOperationsJobBucketListBuckets | undefined;
}
export interface GoogleStorageBatchOperationsJobDeleteObject {
    /**
    * enable flag to permanently delete object and all object versions if versioning is enabled on bucket.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job#permanent_object_deletion_enabled GoogleStorageBatchOperationsJob#permanent_object_deletion_enabled}
    */
    readonly permanentObjectDeletionEnabled: boolean | cdktf.IResolvable;
}
export declare function googleStorageBatchOperationsJobDeleteObjectToTerraform(struct?: GoogleStorageBatchOperationsJobDeleteObjectOutputReference | GoogleStorageBatchOperationsJobDeleteObject): any;
export declare function googleStorageBatchOperationsJobDeleteObjectToHclTerraform(struct?: GoogleStorageBatchOperationsJobDeleteObjectOutputReference | GoogleStorageBatchOperationsJobDeleteObject): any;
export declare class GoogleStorageBatchOperationsJobDeleteObjectOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleStorageBatchOperationsJobDeleteObject | undefined;
    set internalValue(value: GoogleStorageBatchOperationsJobDeleteObject | undefined);
    private _permanentObjectDeletionEnabled?;
    get permanentObjectDeletionEnabled(): boolean | cdktf.IResolvable;
    set permanentObjectDeletionEnabled(value: boolean | cdktf.IResolvable);
    get permanentObjectDeletionEnabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface GoogleStorageBatchOperationsJobPutMetadata {
    /**
    * Cache-Control directive to specify caching behavior of object data. If omitted and object is accessible to all anonymous users, the default will be public, max-age=3600
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job#cache_control GoogleStorageBatchOperationsJob#cache_control}
    */
    readonly cacheControl?: string;
    /**
    * Content-Disposition of the object data.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job#content_disposition GoogleStorageBatchOperationsJob#content_disposition}
    */
    readonly contentDisposition?: string;
    /**
    * Content Encoding of the object data.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job#content_encoding GoogleStorageBatchOperationsJob#content_encoding}
    */
    readonly contentEncoding?: string;
    /**
    * Content-Language of the object data.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job#content_language GoogleStorageBatchOperationsJob#content_language}
    */
    readonly contentLanguage?: string;
    /**
    * Content-Type of the object data.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job#content_type GoogleStorageBatchOperationsJob#content_type}
    */
    readonly contentType?: string;
    /**
    * User-provided metadata, in key/value pairs.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job#custom_metadata GoogleStorageBatchOperationsJob#custom_metadata}
    */
    readonly customMetadata?: {
        [key: string]: string;
    };
    /**
    * Updates the objects fixed custom time metadata.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job#custom_time GoogleStorageBatchOperationsJob#custom_time}
    */
    readonly customTime?: string;
}
export declare function googleStorageBatchOperationsJobPutMetadataToTerraform(struct?: GoogleStorageBatchOperationsJobPutMetadataOutputReference | GoogleStorageBatchOperationsJobPutMetadata): any;
export declare function googleStorageBatchOperationsJobPutMetadataToHclTerraform(struct?: GoogleStorageBatchOperationsJobPutMetadataOutputReference | GoogleStorageBatchOperationsJobPutMetadata): any;
export declare class GoogleStorageBatchOperationsJobPutMetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleStorageBatchOperationsJobPutMetadata | undefined;
    set internalValue(value: GoogleStorageBatchOperationsJobPutMetadata | undefined);
    private _cacheControl?;
    get cacheControl(): string;
    set cacheControl(value: string);
    resetCacheControl(): void;
    get cacheControlInput(): string | undefined;
    private _contentDisposition?;
    get contentDisposition(): string;
    set contentDisposition(value: string);
    resetContentDisposition(): void;
    get contentDispositionInput(): string | undefined;
    private _contentEncoding?;
    get contentEncoding(): string;
    set contentEncoding(value: string);
    resetContentEncoding(): void;
    get contentEncodingInput(): string | undefined;
    private _contentLanguage?;
    get contentLanguage(): string;
    set contentLanguage(value: string);
    resetContentLanguage(): void;
    get contentLanguageInput(): string | undefined;
    private _contentType?;
    get contentType(): string;
    set contentType(value: string);
    resetContentType(): void;
    get contentTypeInput(): string | undefined;
    private _customMetadata?;
    get customMetadata(): {
        [key: string]: string;
    };
    set customMetadata(value: {
        [key: string]: string;
    });
    resetCustomMetadata(): void;
    get customMetadataInput(): {
        [key: string]: string;
    } | undefined;
    private _customTime?;
    get customTime(): string;
    set customTime(value: string);
    resetCustomTime(): void;
    get customTimeInput(): string | undefined;
}
export interface GoogleStorageBatchOperationsJobPutObjectHold {
    /**
    * set/unset to update event based hold for objects.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job#event_based_hold GoogleStorageBatchOperationsJob#event_based_hold}
    */
    readonly eventBasedHold?: string;
    /**
    * set/unset to update temporary based hold for objects.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job#temporary_hold GoogleStorageBatchOperationsJob#temporary_hold}
    */
    readonly temporaryHold?: string;
}
export declare function googleStorageBatchOperationsJobPutObjectHoldToTerraform(struct?: GoogleStorageBatchOperationsJobPutObjectHoldOutputReference | GoogleStorageBatchOperationsJobPutObjectHold): any;
export declare function googleStorageBatchOperationsJobPutObjectHoldToHclTerraform(struct?: GoogleStorageBatchOperationsJobPutObjectHoldOutputReference | GoogleStorageBatchOperationsJobPutObjectHold): any;
export declare class GoogleStorageBatchOperationsJobPutObjectHoldOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleStorageBatchOperationsJobPutObjectHold | undefined;
    set internalValue(value: GoogleStorageBatchOperationsJobPutObjectHold | undefined);
    private _eventBasedHold?;
    get eventBasedHold(): string;
    set eventBasedHold(value: string);
    resetEventBasedHold(): void;
    get eventBasedHoldInput(): string | undefined;
    private _temporaryHold?;
    get temporaryHold(): string;
    set temporaryHold(value: string);
    resetTemporaryHold(): void;
    get temporaryHoldInput(): string | undefined;
}
export interface GoogleStorageBatchOperationsJobRewriteObject {
    /**
    * valid kms key
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job#kms_key GoogleStorageBatchOperationsJob#kms_key}
    */
    readonly kmsKey: string;
}
export declare function googleStorageBatchOperationsJobRewriteObjectToTerraform(struct?: GoogleStorageBatchOperationsJobRewriteObjectOutputReference | GoogleStorageBatchOperationsJobRewriteObject): any;
export declare function googleStorageBatchOperationsJobRewriteObjectToHclTerraform(struct?: GoogleStorageBatchOperationsJobRewriteObjectOutputReference | GoogleStorageBatchOperationsJobRewriteObject): any;
export declare class GoogleStorageBatchOperationsJobRewriteObjectOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleStorageBatchOperationsJobRewriteObject | undefined;
    set internalValue(value: GoogleStorageBatchOperationsJobRewriteObject | undefined);
    private _kmsKey?;
    get kmsKey(): string;
    set kmsKey(value: string);
    get kmsKeyInput(): string | undefined;
}
export interface GoogleStorageBatchOperationsJobTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job#create GoogleStorageBatchOperationsJob#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job#delete GoogleStorageBatchOperationsJob#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job#update GoogleStorageBatchOperationsJob#update}
    */
    readonly update?: string;
}
export declare function googleStorageBatchOperationsJobTimeoutsToTerraform(struct?: GoogleStorageBatchOperationsJobTimeouts | cdktf.IResolvable): any;
export declare function googleStorageBatchOperationsJobTimeoutsToHclTerraform(struct?: GoogleStorageBatchOperationsJobTimeouts | cdktf.IResolvable): any;
export declare class GoogleStorageBatchOperationsJobTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleStorageBatchOperationsJobTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleStorageBatchOperationsJobTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job google_storage_batch_operations_job}
*/
export declare class GoogleStorageBatchOperationsJob extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_storage_batch_operations_job";
    /**
    * Generates CDKTF code for importing a GoogleStorageBatchOperationsJob resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleStorageBatchOperationsJob to import
    * @param importFromId The id of the existing GoogleStorageBatchOperationsJob that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleStorageBatchOperationsJob to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_batch_operations_job google_storage_batch_operations_job} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleStorageBatchOperationsJobConfig = {}
    */
    constructor(scope: Construct, id: string, config?: GoogleStorageBatchOperationsJobConfig);
    get completeTime(): string;
    get createTime(): string;
    private _deleteProtection?;
    get deleteProtection(): boolean | cdktf.IResolvable;
    set deleteProtection(value: boolean | cdktf.IResolvable);
    resetDeleteProtection(): void;
    get deleteProtectionInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _jobId?;
    get jobId(): string;
    set jobId(value: string);
    resetJobId(): void;
    get jobIdInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get scheduleTime(): string;
    get state(): string;
    get updateTime(): string;
    private _bucketList;
    get bucketList(): GoogleStorageBatchOperationsJobBucketListStructOutputReference;
    putBucketList(value: GoogleStorageBatchOperationsJobBucketListStruct): void;
    resetBucketList(): void;
    get bucketListInput(): GoogleStorageBatchOperationsJobBucketListStruct | undefined;
    private _deleteObject;
    get deleteObject(): GoogleStorageBatchOperationsJobDeleteObjectOutputReference;
    putDeleteObject(value: GoogleStorageBatchOperationsJobDeleteObject): void;
    resetDeleteObject(): void;
    get deleteObjectInput(): GoogleStorageBatchOperationsJobDeleteObject | undefined;
    private _putMetadata;
    get putMetadata(): GoogleStorageBatchOperationsJobPutMetadataOutputReference;
    putPutMetadata(value: GoogleStorageBatchOperationsJobPutMetadata): void;
    resetPutMetadata(): void;
    get putMetadataInput(): GoogleStorageBatchOperationsJobPutMetadata | undefined;
    private _putObjectHold;
    get putObjectHold(): GoogleStorageBatchOperationsJobPutObjectHoldOutputReference;
    putPutObjectHold(value: GoogleStorageBatchOperationsJobPutObjectHold): void;
    resetPutObjectHold(): void;
    get putObjectHoldInput(): GoogleStorageBatchOperationsJobPutObjectHold | undefined;
    private _rewriteObject;
    get rewriteObject(): GoogleStorageBatchOperationsJobRewriteObjectOutputReference;
    putRewriteObject(value: GoogleStorageBatchOperationsJobRewriteObject): void;
    resetRewriteObject(): void;
    get rewriteObjectInput(): GoogleStorageBatchOperationsJobRewriteObject | undefined;
    private _timeouts;
    get timeouts(): GoogleStorageBatchOperationsJobTimeoutsOutputReference;
    putTimeouts(value: GoogleStorageBatchOperationsJobTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleStorageBatchOperationsJobTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
