/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleStorageControlFolderIntelligenceConfigConfig extends cdktf.TerraformMetaArguments {
    /**
    * Edition configuration of the Storage Intelligence resource. Valid values are INHERIT, TRIAL, DISABLED and STANDARD.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_control_folder_intelligence_config#edition_config GoogleStorageControlFolderIntelligenceConfig#edition_config}
    */
    readonly editionConfig?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_control_folder_intelligence_config#id GoogleStorageControlFolderIntelligenceConfig#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Identifier of the GCP Folder. For GCP Folder, this field can be folder number.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_control_folder_intelligence_config#name GoogleStorageControlFolderIntelligenceConfig#name}
    */
    readonly name: string;
    /**
    * filter block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_control_folder_intelligence_config#filter GoogleStorageControlFolderIntelligenceConfig#filter}
    */
    readonly filter?: GoogleStorageControlFolderIntelligenceConfigFilter;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_control_folder_intelligence_config#timeouts GoogleStorageControlFolderIntelligenceConfig#timeouts}
    */
    readonly timeouts?: GoogleStorageControlFolderIntelligenceConfigTimeouts;
}
export interface GoogleStorageControlFolderIntelligenceConfigEffectiveIntelligenceConfig {
}
export declare function googleStorageControlFolderIntelligenceConfigEffectiveIntelligenceConfigToTerraform(struct?: GoogleStorageControlFolderIntelligenceConfigEffectiveIntelligenceConfig): any;
export declare function googleStorageControlFolderIntelligenceConfigEffectiveIntelligenceConfigToHclTerraform(struct?: GoogleStorageControlFolderIntelligenceConfigEffectiveIntelligenceConfig): any;
export declare class GoogleStorageControlFolderIntelligenceConfigEffectiveIntelligenceConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleStorageControlFolderIntelligenceConfigEffectiveIntelligenceConfig | undefined;
    set internalValue(value: GoogleStorageControlFolderIntelligenceConfigEffectiveIntelligenceConfig | undefined);
    get effectiveEdition(): string;
    get intelligenceConfig(): string;
}
export declare class GoogleStorageControlFolderIntelligenceConfigEffectiveIntelligenceConfigList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleStorageControlFolderIntelligenceConfigEffectiveIntelligenceConfigOutputReference;
}
export interface GoogleStorageControlFolderIntelligenceConfigTrialConfig {
}
export declare function googleStorageControlFolderIntelligenceConfigTrialConfigToTerraform(struct?: GoogleStorageControlFolderIntelligenceConfigTrialConfig): any;
export declare function googleStorageControlFolderIntelligenceConfigTrialConfigToHclTerraform(struct?: GoogleStorageControlFolderIntelligenceConfigTrialConfig): any;
export declare class GoogleStorageControlFolderIntelligenceConfigTrialConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleStorageControlFolderIntelligenceConfigTrialConfig | undefined;
    set internalValue(value: GoogleStorageControlFolderIntelligenceConfigTrialConfig | undefined);
    get expireTime(): string;
}
export declare class GoogleStorageControlFolderIntelligenceConfigTrialConfigList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleStorageControlFolderIntelligenceConfigTrialConfigOutputReference;
}
export interface GoogleStorageControlFolderIntelligenceConfigFilterExcludedCloudStorageBuckets {
    /**
    * List of bucket id regexes to exclude in the storage intelligence plan.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_control_folder_intelligence_config#bucket_id_regexes GoogleStorageControlFolderIntelligenceConfig#bucket_id_regexes}
    */
    readonly bucketIdRegexes: string[];
}
export declare function googleStorageControlFolderIntelligenceConfigFilterExcludedCloudStorageBucketsToTerraform(struct?: GoogleStorageControlFolderIntelligenceConfigFilterExcludedCloudStorageBucketsOutputReference | GoogleStorageControlFolderIntelligenceConfigFilterExcludedCloudStorageBuckets): any;
export declare function googleStorageControlFolderIntelligenceConfigFilterExcludedCloudStorageBucketsToHclTerraform(struct?: GoogleStorageControlFolderIntelligenceConfigFilterExcludedCloudStorageBucketsOutputReference | GoogleStorageControlFolderIntelligenceConfigFilterExcludedCloudStorageBuckets): any;
export declare class GoogleStorageControlFolderIntelligenceConfigFilterExcludedCloudStorageBucketsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleStorageControlFolderIntelligenceConfigFilterExcludedCloudStorageBuckets | undefined;
    set internalValue(value: GoogleStorageControlFolderIntelligenceConfigFilterExcludedCloudStorageBuckets | undefined);
    private _bucketIdRegexes?;
    get bucketIdRegexes(): string[];
    set bucketIdRegexes(value: string[]);
    get bucketIdRegexesInput(): string[] | undefined;
}
export interface GoogleStorageControlFolderIntelligenceConfigFilterExcludedCloudStorageLocations {
    /**
    * List of locations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_control_folder_intelligence_config#locations GoogleStorageControlFolderIntelligenceConfig#locations}
    */
    readonly locations: string[];
}
export declare function googleStorageControlFolderIntelligenceConfigFilterExcludedCloudStorageLocationsToTerraform(struct?: GoogleStorageControlFolderIntelligenceConfigFilterExcludedCloudStorageLocationsOutputReference | GoogleStorageControlFolderIntelligenceConfigFilterExcludedCloudStorageLocations): any;
export declare function googleStorageControlFolderIntelligenceConfigFilterExcludedCloudStorageLocationsToHclTerraform(struct?: GoogleStorageControlFolderIntelligenceConfigFilterExcludedCloudStorageLocationsOutputReference | GoogleStorageControlFolderIntelligenceConfigFilterExcludedCloudStorageLocations): any;
export declare class GoogleStorageControlFolderIntelligenceConfigFilterExcludedCloudStorageLocationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleStorageControlFolderIntelligenceConfigFilterExcludedCloudStorageLocations | undefined;
    set internalValue(value: GoogleStorageControlFolderIntelligenceConfigFilterExcludedCloudStorageLocations | undefined);
    private _locations?;
    get locations(): string[];
    set locations(value: string[]);
    get locationsInput(): string[] | undefined;
}
export interface GoogleStorageControlFolderIntelligenceConfigFilterIncludedCloudStorageBuckets {
    /**
    * List of bucket id regexes to exclude in the storage intelligence plan.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_control_folder_intelligence_config#bucket_id_regexes GoogleStorageControlFolderIntelligenceConfig#bucket_id_regexes}
    */
    readonly bucketIdRegexes: string[];
}
export declare function googleStorageControlFolderIntelligenceConfigFilterIncludedCloudStorageBucketsToTerraform(struct?: GoogleStorageControlFolderIntelligenceConfigFilterIncludedCloudStorageBucketsOutputReference | GoogleStorageControlFolderIntelligenceConfigFilterIncludedCloudStorageBuckets): any;
export declare function googleStorageControlFolderIntelligenceConfigFilterIncludedCloudStorageBucketsToHclTerraform(struct?: GoogleStorageControlFolderIntelligenceConfigFilterIncludedCloudStorageBucketsOutputReference | GoogleStorageControlFolderIntelligenceConfigFilterIncludedCloudStorageBuckets): any;
export declare class GoogleStorageControlFolderIntelligenceConfigFilterIncludedCloudStorageBucketsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleStorageControlFolderIntelligenceConfigFilterIncludedCloudStorageBuckets | undefined;
    set internalValue(value: GoogleStorageControlFolderIntelligenceConfigFilterIncludedCloudStorageBuckets | undefined);
    private _bucketIdRegexes?;
    get bucketIdRegexes(): string[];
    set bucketIdRegexes(value: string[]);
    get bucketIdRegexesInput(): string[] | undefined;
}
export interface GoogleStorageControlFolderIntelligenceConfigFilterIncludedCloudStorageLocations {
    /**
    * List of locations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_control_folder_intelligence_config#locations GoogleStorageControlFolderIntelligenceConfig#locations}
    */
    readonly locations: string[];
}
export declare function googleStorageControlFolderIntelligenceConfigFilterIncludedCloudStorageLocationsToTerraform(struct?: GoogleStorageControlFolderIntelligenceConfigFilterIncludedCloudStorageLocationsOutputReference | GoogleStorageControlFolderIntelligenceConfigFilterIncludedCloudStorageLocations): any;
export declare function googleStorageControlFolderIntelligenceConfigFilterIncludedCloudStorageLocationsToHclTerraform(struct?: GoogleStorageControlFolderIntelligenceConfigFilterIncludedCloudStorageLocationsOutputReference | GoogleStorageControlFolderIntelligenceConfigFilterIncludedCloudStorageLocations): any;
export declare class GoogleStorageControlFolderIntelligenceConfigFilterIncludedCloudStorageLocationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleStorageControlFolderIntelligenceConfigFilterIncludedCloudStorageLocations | undefined;
    set internalValue(value: GoogleStorageControlFolderIntelligenceConfigFilterIncludedCloudStorageLocations | undefined);
    private _locations?;
    get locations(): string[];
    set locations(value: string[]);
    get locationsInput(): string[] | undefined;
}
export interface GoogleStorageControlFolderIntelligenceConfigFilter {
    /**
    * excluded_cloud_storage_buckets block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_control_folder_intelligence_config#excluded_cloud_storage_buckets GoogleStorageControlFolderIntelligenceConfig#excluded_cloud_storage_buckets}
    */
    readonly excludedCloudStorageBuckets?: GoogleStorageControlFolderIntelligenceConfigFilterExcludedCloudStorageBuckets;
    /**
    * excluded_cloud_storage_locations block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_control_folder_intelligence_config#excluded_cloud_storage_locations GoogleStorageControlFolderIntelligenceConfig#excluded_cloud_storage_locations}
    */
    readonly excludedCloudStorageLocations?: GoogleStorageControlFolderIntelligenceConfigFilterExcludedCloudStorageLocations;
    /**
    * included_cloud_storage_buckets block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_control_folder_intelligence_config#included_cloud_storage_buckets GoogleStorageControlFolderIntelligenceConfig#included_cloud_storage_buckets}
    */
    readonly includedCloudStorageBuckets?: GoogleStorageControlFolderIntelligenceConfigFilterIncludedCloudStorageBuckets;
    /**
    * included_cloud_storage_locations block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_control_folder_intelligence_config#included_cloud_storage_locations GoogleStorageControlFolderIntelligenceConfig#included_cloud_storage_locations}
    */
    readonly includedCloudStorageLocations?: GoogleStorageControlFolderIntelligenceConfigFilterIncludedCloudStorageLocations;
}
export declare function googleStorageControlFolderIntelligenceConfigFilterToTerraform(struct?: GoogleStorageControlFolderIntelligenceConfigFilterOutputReference | GoogleStorageControlFolderIntelligenceConfigFilter): any;
export declare function googleStorageControlFolderIntelligenceConfigFilterToHclTerraform(struct?: GoogleStorageControlFolderIntelligenceConfigFilterOutputReference | GoogleStorageControlFolderIntelligenceConfigFilter): any;
export declare class GoogleStorageControlFolderIntelligenceConfigFilterOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleStorageControlFolderIntelligenceConfigFilter | undefined;
    set internalValue(value: GoogleStorageControlFolderIntelligenceConfigFilter | undefined);
    private _excludedCloudStorageBuckets;
    get excludedCloudStorageBuckets(): GoogleStorageControlFolderIntelligenceConfigFilterExcludedCloudStorageBucketsOutputReference;
    putExcludedCloudStorageBuckets(value: GoogleStorageControlFolderIntelligenceConfigFilterExcludedCloudStorageBuckets): void;
    resetExcludedCloudStorageBuckets(): void;
    get excludedCloudStorageBucketsInput(): GoogleStorageControlFolderIntelligenceConfigFilterExcludedCloudStorageBuckets | undefined;
    private _excludedCloudStorageLocations;
    get excludedCloudStorageLocations(): GoogleStorageControlFolderIntelligenceConfigFilterExcludedCloudStorageLocationsOutputReference;
    putExcludedCloudStorageLocations(value: GoogleStorageControlFolderIntelligenceConfigFilterExcludedCloudStorageLocations): void;
    resetExcludedCloudStorageLocations(): void;
    get excludedCloudStorageLocationsInput(): GoogleStorageControlFolderIntelligenceConfigFilterExcludedCloudStorageLocations | undefined;
    private _includedCloudStorageBuckets;
    get includedCloudStorageBuckets(): GoogleStorageControlFolderIntelligenceConfigFilterIncludedCloudStorageBucketsOutputReference;
    putIncludedCloudStorageBuckets(value: GoogleStorageControlFolderIntelligenceConfigFilterIncludedCloudStorageBuckets): void;
    resetIncludedCloudStorageBuckets(): void;
    get includedCloudStorageBucketsInput(): GoogleStorageControlFolderIntelligenceConfigFilterIncludedCloudStorageBuckets | undefined;
    private _includedCloudStorageLocations;
    get includedCloudStorageLocations(): GoogleStorageControlFolderIntelligenceConfigFilterIncludedCloudStorageLocationsOutputReference;
    putIncludedCloudStorageLocations(value: GoogleStorageControlFolderIntelligenceConfigFilterIncludedCloudStorageLocations): void;
    resetIncludedCloudStorageLocations(): void;
    get includedCloudStorageLocationsInput(): GoogleStorageControlFolderIntelligenceConfigFilterIncludedCloudStorageLocations | undefined;
}
export interface GoogleStorageControlFolderIntelligenceConfigTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_control_folder_intelligence_config#create GoogleStorageControlFolderIntelligenceConfig#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_control_folder_intelligence_config#delete GoogleStorageControlFolderIntelligenceConfig#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_control_folder_intelligence_config#update GoogleStorageControlFolderIntelligenceConfig#update}
    */
    readonly update?: string;
}
export declare function googleStorageControlFolderIntelligenceConfigTimeoutsToTerraform(struct?: GoogleStorageControlFolderIntelligenceConfigTimeouts | cdktf.IResolvable): any;
export declare function googleStorageControlFolderIntelligenceConfigTimeoutsToHclTerraform(struct?: GoogleStorageControlFolderIntelligenceConfigTimeouts | cdktf.IResolvable): any;
export declare class GoogleStorageControlFolderIntelligenceConfigTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleStorageControlFolderIntelligenceConfigTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleStorageControlFolderIntelligenceConfigTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_control_folder_intelligence_config google_storage_control_folder_intelligence_config}
*/
export declare class GoogleStorageControlFolderIntelligenceConfig extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_storage_control_folder_intelligence_config";
    /**
    * Generates CDKTF code for importing a GoogleStorageControlFolderIntelligenceConfig resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleStorageControlFolderIntelligenceConfig to import
    * @param importFromId The id of the existing GoogleStorageControlFolderIntelligenceConfig that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_control_folder_intelligence_config#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleStorageControlFolderIntelligenceConfig to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.34.1/docs/resources/google_storage_control_folder_intelligence_config google_storage_control_folder_intelligence_config} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleStorageControlFolderIntelligenceConfigConfig
    */
    constructor(scope: Construct, id: string, config: GoogleStorageControlFolderIntelligenceConfigConfig);
    private _editionConfig?;
    get editionConfig(): string;
    set editionConfig(value: string);
    resetEditionConfig(): void;
    get editionConfigInput(): string | undefined;
    private _effectiveIntelligenceConfig;
    get effectiveIntelligenceConfig(): GoogleStorageControlFolderIntelligenceConfigEffectiveIntelligenceConfigList;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _trialConfig;
    get trialConfig(): GoogleStorageControlFolderIntelligenceConfigTrialConfigList;
    get updateTime(): string;
    private _filter;
    get filter(): GoogleStorageControlFolderIntelligenceConfigFilterOutputReference;
    putFilter(value: GoogleStorageControlFolderIntelligenceConfigFilter): void;
    resetFilter(): void;
    get filterInput(): GoogleStorageControlFolderIntelligenceConfigFilter | undefined;
    private _timeouts;
    get timeouts(): GoogleStorageControlFolderIntelligenceConfigTimeoutsOutputReference;
    putTimeouts(value: GoogleStorageControlFolderIntelligenceConfigTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleStorageControlFolderIntelligenceConfigTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
